# USER SETTINGS FOR BI DAT TOOL
#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'BI_dat_tool.ps1'
#   2. This script must be located in the same folder as script 'BI_dat_tool.ps1'
#   3. This script is suitable for 'BI_dat_tool.ps1' versions V2+
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# [REQUIRED] ENTER BLUE IRIS ALERTS FOLDER PATH
	# ... [string] like "D:\BlueIris\Alerts"
	# ... KEY POINT: If using a network share for Blue Iris storage, note that the BI service may
	#     not understand your file system designations like 'H:' etc. as these are user-specific. 
	#     Per the BI Help PDF, you should always use UNC names where possible (\\server\share).
	$bi_alerts_folder_path = "YOUR_BLUE_IRIS_ALERTS_FOLDER_PATH"

	# [REQUIRED] ENTER BLUE IRIS DATABASE FOLDER PATH
	# ... [string] like, "C:\BlueIris\db"
	$bi_db_path = 'YOUR_BLUE_IRIS_DATABASE_FOLDER_PATH'

	# [REQUIRED] ENTER DESTINATION PATH FOR EXTRACTED JPG & JSON FILES
	# ... [string] like, "D:\BI_dat_tool"
	$app_path = 'YOUR_APPLICATION_PATH'

	# BLUE IRIS WEBSERVER

		# [REQUIRED] ENTER YOUR WEBSERVER'S ADDRESS & PORT
		# ... [string] like '192.168.1.3:81'
		$bi_webserver = "YOUR_BI_SERVER_ADDRESS:PORT"

		# [REQUIRED] ENTER YOUR WEBSERVER'S USERNAME & PASSWORD CREDENTIALS
		# ... CREDENTIALS ARE REQUIRED TO ACCESS THE BLUE IRIS WEBSERVER VIA THE JSON INTERFACE
		# ... NOTE: ACCOUNT MUST BE ADMIN to use argument -Delete (which requires a database rebuild HTTP command)
		# ... NOTE: ACCOUNT MUST BE ADMIN if setting $post_to_BI_logfile_flg (below) is $true
		# ... NOTE: to use credentials, be sure to uncheck 'Use secure session keys and login page' 
		#     in Blue Iris settings: click Settings > Web server > Advanced
		# ... [string] 
		$bi_user_name = "YOUR_BI_USER_NAME"
		$bi_user_pw = "YOUR_BI_USER_PASSORD"

# OPTIONAL SETTINGS

	# BLUE IRIS WEBSERVER

		# OPT-IN TO USING CREDENTIALS FOR HTTP INTERFACE COMMANDS
		# ... expecting $false or $true (default = $false)
		# ... Currently used for these HTTP commands: '/admin?log', '/admin?db=rebuild'
		$use_bi_creds = $false
		#$use_bi_creds = $true

	# DISPLAYING THE OUTPUT CSV FILE

		# AUTO-OPEN OUTPUT CSV FILE
		# ... Default is $false
		#$auto_open_csv_file = $false
		$auto_open_csv_file = $true

		# AUTO-OPEN OUTPUT CSV FILE IN DEFAULT WINDOWS APPLICATION
		# ... $false displays the output CSV file in the Powershell Out-GridView Cmdlet UI
		# ... Default is $false
		# ... Learn more: https://learn.microsoft.com/en-us/powershell/module/microsoft.powershell.utility/out-gridview?view=powershell-7.3
		$auto_open_csv_file_in_def_app = $false
		#$auto_open_csv_file_in_def_app = $true

		# AUTO-OPEN OUTPUT CSV FILE IF OUTPUT HAS MORE THAN N ROWS
		# ... 0 (zero) always displays the Powershell Out-GridView Cmdlet UI
		# ... Default is 0
		$auto_open_csv_file_min_rows = 0
		#$auto_open_csv_file_min_rows = 20

	# OPT OUT OF WARNING
	# ... You may find this setting useful if any of your cameras have the following setting checked:
	#     --> Camera settings > Trigger > 'Artificial Intelligence' > 'Begin analysis with motion-leading image'
	#     For these images, the corresponding JSON string is always empty. This is a condition for which 
	#     'bi_dat_tool.ps1' always issues warnings (b/c it suggests a structural issue with the DAT file).
	# ... Default is $false
	$ignore_img1_json_zero_length_warnings = $false
	#$ignore_img1_json_zero_length_warnings = $true

	# SUBSTITUTE 'ipcam-' IN MODEL NAMES
	# ... If you use AI models that are prefixed by the substring 'ipcam-', the you can shorten their names in the output
	# ... For example, for 'ipcam-combined', show instead '.combined'
	# ... Default is $null (no substitution)
	$shorten_model_name = $null
	#$shorten_model_name = "."

	# POSTING TO THE BLUE IRIS LOGFILE
	
		# This logging functionality is provided as a means to document automated actions.
		# FURTHERMORE, a setting is provided to limit logging to when 'bi_dat_tool.ps1' is executed from the background 
		# (e.g., via Task Scheduler, Blue Iris actions).
		
		# BTW, even if you've enabled logging by default (via user setting $post_to_BI_logfile_flg below), 
		# logging can still be disabled on-demand -- via the script's -NoBiLog argument.

		# OPT-IN TO POSTING CUSTOM MESSAGES TO THE BLUE IRIS LOG
		# ... expecting $false or $true (default = $false)
		# ... NOTE: if value is $true, setting $bi_user_name (above) MUST BE ADMIN
		# ... NOTE: script parameter -NoBiLog can be used to temporarily override this setting (if $true)
		$post_to_BI_logfile_flg = $false
		#$post_to_BI_logfile_flg = $true

			# The following settings apply only if setting $post_to_BI_logfile_flg = $true

			# OPT-IN TO POSTING TO THE BLUE IRIS LOG ONLY FROM BACKGROUND
			# ... expecting $false or $true (default = $false)
			# ... $true avoids logging to Blue Iris logfile when using script from Console
			$post_to_BI_logfile_in_background_only_flg = $false
			#$post_to_BI_logfile_in_background_only_flg = $true

# END USER SETTINGS
# ================================================
