# BI DAT TOOL - FOR BLUE IRIS GENERATED AI 'DAT' FILES
# FEATURES:
# FILTERS DAT FILES BASED ON FILENAMES, NAMING PATTERN, IMAGE COUNT, AGE, AND/OR ALERT MEMO
# AND PERFORM ANY/ALL OF THE FOLLOWING ACTIONS: 
#    * LIST (FOR INSPECTION BEFORE PERFORMING THE FOLLOWING ACTIONS)
#    * SET DAT (AND ASSOCIATED JPG, IF FOUND) FILE'S READ-ONLY ATTRIBUTE
#    * MATCH DAT'S ASSOCIATED JPG METADATA TO ALERT'S CURRENT MEMO
#    * REMOVE DAT FILE FROM BLUE IRIS STORAGE (TO RECYCLE BIN, OR PERMANENTLY DELETE)
#    * EXTRACT/SAVE *ALL* EMBEDDED JSON STRINGS
#    * EXTRACT/SAVE *ALL* EMBEDDED JPG IMAGES
#      OR OPTIONALLY SAVE ONLY A SUBSET OF THE EMBEDDED JPG IMAGES BASED ON AI PARAMETERS:
#      -  THE AI ANALYSIS MODELS USED, AND/OR 
#      -  THE AI LABELS FOUND
#
# Version: 2
# Created by jaydeel at ipcamtalk.com
#
# Updates:
# V2 - 2024-03-22   - BREAKING CHANGE: must replace old user-settings file 
#                   - NEW: output column 'Flags' now shows if alerts have the 'Confirmed' flag set 
#                   - NEW: script can now identify the confirmed image in a Blue Iris DAT file
#                   - NEW: new output column 'ConfImg' shows which DAT image number was confirmed (if any)
#                   - NEW: new output column 'ConfImgMemo' shows the AI memo for the confirmed image (e.g., 'person:94%')
#                   - NEW: argument -DevMode now exports each camera's JSON alertlist data to 'app_folder\_devmode' 
#                     Note: if -DevMode is used with -Files or -Patterns, script will save only the JSON 
#                     alertlist data for applicable cameras 
#                   - NEW: script provides feedback if commandline includes unsupported arguments 
#                   - CHANGED: output columns 'AlertMemo' and 'JpgExifMemo' renamed'AlertMemoLabels' AND 'JpgExifMemoLabels'
#                   - FIXED: fixed output table column alignment errors when values are $null (to avoid $null.toString())
#                   - FIXED: fixed untrapped error if Blue Iris service is not running
#                   - FIXED: fixed extraction of AI labels from Alert memos when prefixed with ONVIF tag, like "RuleEngine..."
#                   - FIXED: fixed handling of JPG and JSON files saved with arguments -IfAi*, -SaveJPGS -SaveJSON
#                   - FIXED: fixed handling of malformed DAT files that contain no JPG images; 'ImgsCnt' column value now shows -1
#                   - FIXED: fixed handling of 'Invalid session' in function BIJsonCall()
#                   - FIXED: fixed handling of large outputs from JSON 'alertlist' cmd
#                   - IMPROVED: updated functions BIJsonCall(), BIJsonGetAlertList()
#                   - IMPROVED: updated function FindBytes()
#                   - IMPROVED: function BIJsonAlertListParse() is now more tolerant of database issues
# V1.2 - 2023-10-08 - NEW: added new 'RO' column to output to show if the DAT (and associated Alert JPG) 
#                     files have their read-only
#                     attributes set
#                   - NEW: added new 'JpgExifMemo' column to output; shows if the JPG's Exif metadata 
#                     contains the same memo as the Alert's db entry
#                   - NEW: argument -ReadOnly sets the read-only attribute for found DAT files 
#                     (and associated Alert JPG files, if present)
#                   - NEW: argument -FixJpgMetadata forces found DAT files Alert JPGs Exif metadata 
#                     to match the Alert's database memo
#                   - CHANGE: argument -Delete now ALWAYS performs a database Repair/Regenerate 
#                     (as required, per Blue Iris support)
#                   - NEW: argument -Delete now automatically backs up the Blue Iris database folder to 
#                     the '\_backup*' subfolder; the purpose to facilitate recovery of the Blue Iris 
#                     database, if ever needed)
#                   - NEW: added function BIHttpCall() to support database Repair/Regenerate actions
#                   - NEW: added new user-setting to optionally use BI user credentials with Blue Iris 
#                     HTTP interface commands
#                   - NEW: added new user-setting to optionally open the output CSV file in the default 
#                     Windows application
#                   - NEW: added descriptive/explanatory '_README.txt' files to all programmatically created folders
#                   - IMPROVED: warning now issued when a Blue Iris JSON interface command requires 
#                      an administrative account
#                   - IMPROVED: warning now issued when attempting to post to the Blue Iris logfile when 
#                     using a non-administrative account
#                   - CHANGE: reworked handling of failed JSON interface calls in function BiJsonCall()
#                   - CHANGE: reworked posting to the Blue Iris logfile; eliminated function PostCustomBiLogEntry()
# V1.1 - 2023-09-07 - NEW: added new argument -ChgAlMemoTags to change/clear Alert memo tag characters (like "!")
#                   - NEW: added new 'Flags' column to output to show if the associated Alert is 'flagged' 
#                     or 'protected' in the BI database
#                   - NEW: added new user-setting to automatically open the output CSV file in a Powershell 
#                     utility UI (Out-GridView cmdlet)
#                   - NEW: added new argument -Archive to copy filtered DAT files to \_archive* subfolder 
#                     in script's destination folder
#                   - CHANGE: replaced argument -AlertMemos with -AlMemoTags (-AlertMemos remains supported)
#                   - CHANGE: in the output, non-existent DAT files now assigned 'AgeHrs' and 'ImgsCnt' 
#                     column values of -1 (previously 0)
#                   - CHANGE: in the output, -NoInspect DAT files now assigns 'ImgsCnt' column values 
#                     of -1 (previously 0)
#                   - IMPROVED: script now recognizes unedited BI webserver address & credentials in 
#                     the user-settings file
#                   - IMPROVED: more efficient JSON 'alertlist' GET when using arg -AlMemoTags 
#                    (uses 'search' parameter)
#                   - DISABLED: argument -Delete has been disabled until Blue Iris provides a safe method 
#                     to delete DAT files
# V1.0 - 2023-08-25 - initial release
#
# *** BEFORE USING THIS SCRIPT ***
# *** EDIT ALL REQUIRED VARIABLES IN THE ESSENTIAL COMPANION FILE '{this_script_name}_user_settings.ps1' ***
#
# USAGE: {this_script.name).ps1 [arg1]
# ARGS:  -Files            = (list) Blue Iris Files, (comma-delimited), like 'file1.dat','file2.dat'
#                            or 'D:/path/file1.dat','D:/path/file2.dat'
#                          = (filespec) *.txt filespec with list of *.dat files, one per line 
#                            will use if -SourcePath if *.dat files in file lack a path
#        -SourcePath       = (string) alternate path to *.dat files (typically the Blue Iris Alerts folder path);
#                            overrides default user-setting '$bi_alerts_folder_path'
#        -NoInspect        = (switch) disable default inspection of JPG images & JSON strings in DAT files
#        -MinImages        = (int) filter DAT files that contain N or more JPGs
#        -MaxImages        = (int) filter DAT files that contain N or fewer JPGs
#        -Patterns         = (string) filter DAT files with specified patterns; comma-delimited
#        -AgeHours         = (int) filter DAT files that older than specified hours
#        -AlertMemos       = (array) DEPRECATED for -AlMemoTags
#        -AlMemoTags       = (array) filter results for ALERTS with specified memo 'tags' (substrings)
#        -ChgAlMemoTags    = (array) change/clear 'tags' from Alert memos (must be used with -AlMemoTags); use "" to clear tag
#        -FilterFlags      = (strings) filter output table for Alerts w/ specified flags, comma-delimited; like "C" or "P","!C"
#        -SortAsc          = (switch) sort output table ascending on specified column number (default is descending)
#        -SortHours        = (switch) sort output table by DAT file age in hours (default is descending)
#        -SaveJPGs         = (switch) extract the embedded JPG files, and their associated AI Results (JSON)
#        -SaveJSON         = (switch) save AI Results JSON strings for all images in the DAT file
#        -Destination      = (switch) destination folder for extracted JPGs (default is 'C:\temp');
#                             overrides default user-setting '$app_path'
#        -SingleFolder     = (switch) save JPGs to -Destination root (vs to one subfolder per DAT file)
#        -IfAiModel        = (string) filter JPGs if analyzed by a specified model
#        -IfAiLabels       = (array) filter JPGs if specified labels are confirmed (comma-delimited)
#        -IfAiNothingAny   = (switch) filter JPGs if 'Nothing found' is a result in ANY model used
#        -IfAiNothingAll   = (switch) filter JPGs if 'Nothing found' is a result in EVERY model used
#        -IfAiSomethingAny = (switch) filter JPGs if JPGs have something found (any AI label) in ANY model used
#        -IfAiSomethingAll = (switch) filter JPGs if JPGs have something found (any AI label) in EVERY model used
#	     -Archive          = (switch) copy filtered DAT files to \_archive* subfolder (via in user-setting or -SourcePath)
#	     -ReadOnly         = (switch) set read-only attribute for filtered DAT files and their associated JPG files
#	     -FixJpgMetadata   = (switch) force Alert JPG file's metadata to match the Alert's memo (in the database)
#	     -Delete           = (switch) move filtered DAT files from Blue Iris storage to the Windows Recycle bin (unless protected)
#	     -NoRecycle        = (switch) use w/ -Delete; PERMANENTLY deletes filtered DAT files
#	     -Force            = (switch) use w/ -Delete; remove read-only DAT files, and protected Alert DAT files"
#        -Quiet            = (switch) disable Console status messaging EXCEPT results table, warnings and return object
#        -NoTable          = (switch) disable display of table of all DAT files found/processed
#        -NoBiLog          = (switch) disable/override logging to the Blue Iris logfile
#        -Help             = (switch) disable display of Console usage guide
#        -ShowCLI          = (switch) display output returned when the script is executed in the background
#        -DevMode          = (switch) display developer output (including -ShowCLI)
#        -NoRegen          = (switch) prevent script from auto-performing a Blue Iris database Repair/Regenerate action (w/ -DevMode only)
# RETURNS: (arrays of arrays) @( 
#                                @(DAT filespecs), @(alert flags), @(ages in hours), @(number of images), 
#                                @(AI models used), @(AI labels found), @(alert memos) 
#                             )
#          From the console ... shows a table summarizing all the DAT files found
#
# ATTRIBUTIONS:
#    1) Received the following assistance via Ken @blueirissupport... 
#       "The DAT file is custom serialized format. 
#       To extract JPGs: search the byte content for blocks that start with 'FF D8 FF E0' and go through 'FF D9'. 
#       To extract the JSON string: after the bitmap there are 2 QWORDs (8 bytes each), then the STRING for the JSON 
#       (comprised of a DWORD length then the characters)."
#
#    2) Thanks to EvanVanVan@ipcamtalk for identifying the confirmed JPG's memo in the DAT file
#
# ABOUT JPGS
#    Per the JPEG Interchange Format... any JPEG file or stream is written according to the JPEG Interchange 
#    Format must start with a SOI (Start-of-Image) marker (the two bytes 0xFF, 0xD8) and end with the 
#    EOI (End-of-Image) marker (two bytes, 0xFF, 0xD9). 
#    These two markers will not be found anywhere else in a JPEG file/stream.
#    REFS: https://stackoverflow.com/a/46809226
#          https://en.wikipedia.org/wiki/JPEG
#
# KEY POINT: 
#    JPG images in the Blue Iris DAT file are stored in reverse chronological order
#
# HOW TO AUTOMATE THIS SCRIPT VIA TASK SCHEDULER
#   Open Task Scheduler and create an appropriately named task with one trigger and one action:
#   Task Scheduler
#   'Triggers' tab:
#       'At startup'
#       'Daily' or 'One time' (e.g., at 12:05 AM, every 168 hours)
#       (Note: I find 'One time' to be more reliable)
#   'Actions' tab:
#       Program/script: powershell.exe
#       Add arguments: {your_powershell_scripts_path)\{script_file_name}.ps1 args
#       EXAMPLES:
#       To delete DAT files older than 168 hours (1 week)
#       ... C:\ps_scripts\BI_DAT_file_utility.ps1 -AgeHours 168 -Delete
#       To delete DAT files older with 4 or fewer images
#       ... C:\ps_scripts\BI_DAT_file_utility.ps1 -MaxImages 4 -Delete
#
# DEVELOPER'S TO DO LIST:
# [x] Trap script hangs when the Blue Iris username is not an Admin account
# [x] Import/output Exif metadata (alert memo) from Alert JPG files
# [x] Match memo entries in alert JPG files to Alert's database memo 
#     Refs: https://exiftool.org/, https://abdus.dev/posts/powershell-file-metadata-guide/
#
# MUST BE THE FIRST UNCOMMENTED LINE IN A SCRIPT
param(
	[string[]]$Files,          # [OPTIONAL] list of Blue Iris DAT file(s), or *.txt file with list of *.dat files
	[string]$SourcePath,       # [OPTIONAL] Blue Iris Alerts folder path
	[Switch]$NoInspect,        # [OPTIONAL] disable default inspection of images & JSON in DAT files
	[int]$MinImages,           # [OPTIONAL] filter DAT files that contain N or more JPGs
	[int]$MaxImages,           # [OPTIONAL] filter DAT files that contain N or more JPGs
	[string[]]$Patterns,       # [OPTIONAL] filter DAT files for specified patterns; comma-delimited
	[string[]]$AlertMemos,     # [OPTIONAL] DEPRECATED for -AlMemoTags
	[string[]]$AlMemoTags,     # [OPTIONAL] filter DAT files where associated ALERTS have memo with specified memo substrings ('tags')
	[string[]]$ChgAlMemoTags,  # [OPTIONAL] change/clear 'tags' specified in -AlMemoTags (must be used with -AlMemoTags)
	[int[]]$AgeHours,          # [OPTIONAL] filter DAT files that are older than specified hour, or in range [comma-delimited)
	[string[]]$FilterFlags,    # [OPTIONAL] filter output table for Alerts w/ specified flags, comma-delimited
	[Switch]$SortAsc,          # [OPTIONAL] sort output table ascending (default is descending)
	[Switch]$SortHours,        # [OPTIONAL] sort output table by DAT file age in hours (default is descending)
	[Switch]$SaveJPGs,         # [OPTIONAL] extract the embedded JPG files, and their associated AI Results (JSON)
	[Switch]$SaveJSON,         # [OPTIONAL] save AI Results JSON strings with associated files when using -SaveJPGs
	[string]$Destination,      # [OPTIONAL] destination folder for extracted JPGs (default is 'C:\dat_file_utility')
	[Switch]$SingleFolder,     # [OPTIONAL] save JPGs to -Destination root (vs to one subfolder per DAT file)
	[string]$IfAiModel,        # [OPTIONAL] filter JPGs if analyzed by a specified model
	[array]$IfAiLabels,        # [OPTIONAL] filter JPGs with a confirmed 'find' for the specified labels (comma-delimited)
	[Switch]$IfAiNothingAny,   # [OPTIONAL] filter JPGs if 'Nothing found' is a result in ANY model used
	[Switch]$IfAiNothingAll,   # [OPTIONAL] filter JPGs if 'Nothing found' is a result in EVERY model used
	[Switch]$IfAiSomethingAny, # [OPTIONAL] filter JPGs if JPGs have something found (any AI label) in ANY model used
	[Switch]$IfAiSomethingAll, # [OPTIONAL] filter JPGs if JPGs have something found (any AI label) in EVERY model used
	[Switch]$Archive,          # [OPTIONAL] copy filtered DAT files to \_archive* subfolder in user-setting '$bi_alerts_folder_path' (or -SourcePath)
	[Switch]$ReadOnly,         # [OPTIONAL] set read-only attribute for filtered DAT files and their associated JPG files
	[Switch]$FixJpgMetadata,   # [OPTIONAL] force Alert JPG file's metadata to match the Alert's memo (in the database)
	[Switch]$Delete,           # [OPTIONAL] deletes filtered DAT files to the Windows Recycle bin
	[Switch]$NoRecycle,        # [OPTIONAL] use w/ -Delete; PERMANENTLY deletes DAT files
	[Switch]$Force,            # [OPTIONAL] use w/ -Delete; remove read-only DAT files, and protected Alert DAT files
	[Switch]$Quiet,            # [OPTIONAL] disable Console status messaging EXCEPT results table, warnings and return object
	[Switch]$NoTable,          # [OPTIONAL] disable display of table of all DAT files found/processed
	[Switch]$NoBiLog,          # [OPTIONAL] disable/override logging to the Blue Iris logfile
	[Switch]$Help,             # [OPTIONAL] disable display of Console usage guide
	[Switch]$ShowCLI,          # [OPTIONAL] display output returned when the script executed in the background
	[Switch]$DevMode,          # [OPTIONAL] display developer output
	[Switch]$NoRegen,          # [OPTIONAL] prevent script from auto-performing a Blue Iris database Repair/Regenerate action (w/ -DevMode only)
	[Switch]$Sim1,  # [OPTIONAL] remove ALL 'memo':'value' pairs from raw JSON 'alertlist' response
	[Switch]$Sim2,  # [OPTIONAL] remove 'memo':'value' pairs for 3 random alerts from JSON 'alertlist' response (per iteration)
	[Switch]$Sim3,  # [OPTIONAL] simulate BIJsonGetAlertList() response w/ all 'memo'='NA' params
	[Switch]$Sim4,  # [OPTIONAL] simulate BIJsonGetAlertList() response w/ 3 random 'memo'='NA' params (per iteration)
	[String]$Sim5   # [OPTIONAL] simulate BIJsonGetAlertList() response w/ zero date values; arg value is CamName
)

#Set-StrictMode  -Version 3
#Start-Transcript  # default destination is C:\Users\{user}l\Documents

# GATHER SCRIPT INFO 
$ScriptVersion = 'V2'
#$ScriptName = $MyInvocation.MyCommand.Name
$ScriptName = Split-Path -leaf $PSCommandpath
$ScriptPath = $PSCommandPath.Replace("\$ScriptName", '')
$ScriptBaseName = $ScriptName.Replace('.ps1', '')
$ScriptPath = $PSCommandPath.Replace("\$ScriptName", '')

# For debugging
#Write-Host "ScriptName = $ScriptName"
#Write-Host "ScriptPath = $ScriptPath"
#Write-Host "ScriptBaseName = $ScriptBaseName"
#Write-Host "ScriptPath = $ScriptPath"

# INITIALIZE VARS
$PsVersion = $PSVersionTable.PSVersion.Major
# For testing
#Write-Host "ScriptName = $ScriptName"
#Write-Host "PsVersion = $PsVersion"

# NOTE: Scripts running from the following hosts have process names as follows:
#       Task Scheduler is 'svchost', Powershell-ISE is 'explorer', Windows Terminal is 'WindowsTerminal'
#       https://stackoverflow.com/a/65894924
$ParentProcess = (Get-Process -Id (Get-CimInstance Win32_Process -Filter "ProcessID = $pid").ParentProcessId).Name

# For testing
#Write-Host "ParentProcess = $ParentProcess"

# NOTE: Scripts called by another script have a 'PSCommandPath'.
#       Method 'PSCommandPath' returns null if script is executed via the terminal
#       https://stackoverflow.com/a/23370618/13499984
$CallingScript = $MyInvocation.PSCommandPath

# For testing
#Write-Host "CallingScript = $CallingScript"

# DETERMINE IF RUNNING IN BACKGROUND (IN CLI MODE, OR FROM BLUE IRIS)
if ($ParentProcess -eq 'BlueIris') {
	$fromConsole = $false
} else {
	$fromConsole = ($null -eq $CallingScript)
}

# Get the current server domain (hostname) and username
# Used for background messaging via msg.exe
# ... tip: from the console, you can type 'hostname' or 'whoami'
$server_name = (whoami).Split('\')[0]
$server_username = (whoami).Split('\')[1]

# For testing
#msg.exe $server_username /TIME:5 "From script... $ScriptName`n-----`nPowerShell version is... $PsVersion`nParent process is... '$ParentProcess'`nCalling script name... $CallingScript"
#msg.exe $server_username /TIME:5 "From script... $ScriptName`n-----`nfromConsole = $fromConsole"

# CHECK IF SCRIPT'S PATH IS IN ENVIRONMENT 'SYSTEM PATH' VARIABLE
$EnvPath = [Environment]::GetEnvironmentVariable('Path', 'Machine')
if ($null -ne $EnvPath) {
	if (!($EnvPath -split ';' -contains $ScriptPath)) {

		# For debugging
		#Write-Host "ScriptPath = $ScriptPath"
		#Write-Host ("EnvPath = " + (($EnvPath -Split ';') | ConvertTo-Json))

		return "ERR/this script's path '$ScriptPath' does not exist in the Environment System Path variable"
		
		# Attempt repair
		# NOTE: when I tried this it added MANY other/duplicate entries
		#[Environment]::SetEnvironmentVariable("Path", $EnvPath + ";$ScriptPath", "Machine")
		#Write-Warning "Added this script's path '$ScriptPath' to the Environment Path"
	}
} else {
	Write-Warning "Unable to inspect Environment variable; be sure script's path is in the Environment Path"
}
# For debugging
#Write-Host ("EnvPath = " + (($EnvPath -Split ';') | ConvertTo-Json))

# Make string of params (used for logging to the Blue Iris logfile)
$arr = @()
foreach ($key in $MyInvocation.BoundParameters.keys){
    $value = (get-variable $key).Value 
	if ($value -eq $true) {
		$arr += "-$key"
	} else {
		$arr += "-$key $value"
	}
}
$params_str = $arr -Join " "
#Write-Host "params_str = $params_str"

# For debugging
#Write-Host "Entered script: $ScriptName"	
#Write-Host "NoInspect = '$NoInspect'"
#Write-Host "Files = $Files"
#Write-Host "SourcePath = '$SourcePath'"
#Write-Host "MinImages = $MinImages"
#Write-Host "MaxImages = $MinImages"
#Write-Host "Patterns = $Patterns"
#Write-Host ("AlertMemos cnt = " + $AlertMemos.Count)
#Write-Host "AlertMemos = $AlertMemos"
#Write-Host ("AlMemoTags cnt = " + $AlMemoTags.Count)
#Write-Host "AlMemoTags = $AlMemoTags"
#Write-Host ("ChgAlMemoTags cnt = " + $ChgAlMemoTags.Count)
#Write-Host "ChgAlMemoTags = $ChgAlMemoTags"
#Write-Host "AgeHours = $AgeHours"
#Write-Host "FilterFlags = $FilterFlags"
#Write-Host "SortAsc = $SortAsc"
#Write-Host "SortHours = $SortHours"
#Write-Host "CSV = $CSV"
#Write-Host "SaveJPGs = $SaveJPGs"
#Write-Host "IfAiModel = $IfAiModel"
#Write-Host ("IfAiLabels type = " + $IfAiLabels.GetType())
#Write-Host ("IfAiLabels cnt = " + $IfAiLabels.Count)
#Write-Host "IfAiLabels = $IfAiLabels"
#Write-Host "IfAiNothingAny = $IfAiNothingAny"
#Write-Host "IfAiNothingAll = $IfAiNothingAll"
#Write-Host "IfAiSomethingAny = $IfAiSomethingAny"
#Write-Host "IfAiSomethingAll = $IfAiSomethingAll"
#Write-Host "SaveJSON = $SaveJSON"
#Write-Host "Destination = '$Destination'"
#Write-Host "SingleFolder = $SingleFolder"
#Write-Host "Archive = $Archive"
#Write-Host "Delete = $Delete"
#Write-Host "NoRecycle = $NoRecycle"
#Write-Host "Force = $Force"
#Write-Host "Help = $Help"
#Write-Host "NoTable = $NoTable"
#Write-Host "ShowCLI = $ShowCLI"
#Write-Host "PsVersion = $PsVersion"

# ==============================================================
# IMPORT USER SETTINGS...
# Note: The 'user settings' script is expected to be in same folder as this script
$user_settings_filename = $ScriptName.Replace(".ps1", "_user_settings.ps1")
try {
	. $user_settings_filename
	
	# For debugging
	#Write-Host "Loaded user settings from '$user_settings_filename'"
}
catch {
	$err_msg = "ERR/failed to load user settings file '$user_settings_filename'`nTip: try executing it directly to confirm it exists and reveal syntax errors"
	return $err_msg
}
# ----------------------------
# VALIDATE USER SETTINGS
if (1 -eq 1) {  # Use to collapse this lengthy code section while editing
	# ... Handle REQUIRED user settings
	$variable_test = Get-Variable -Name bi_alerts_folder_path -Scope Local -ErrorAction SilentlyContinue
	if ($null -eq $variable_test) {
		$err_msg = "ERR/User-settings file is missing setting `$bi_alerts_folder_path"
		return $err_msg
	} else {
		if ($bi_alerts_folder_path.StartsWith('YOUR')) {  
			$err_msg = "ERR/user-setting file setting 'bi_alerts_folder_path' is not set"
			return $err_msg
		}
	}
	$bi_alerts_folder_path = $bi_alerts_folder_path.TrimEnd('\')

	$variable_test = Get-Variable -Name bi_db_path -Scope Local -ErrorAction SilentlyContinue
	if ($null -eq $variable_test) {
		$err_msg = "ERR/User-settings file is missing setting `$bi_db_path"
		return $err_msg
	} else {
		if ($bi_db_path.StartsWith('YOUR')) {  
			$err_msg = "ERR/user-setting file setting 'bi_db_path' is not set"
			return $err_msg
		}
	}
	$bi_db_path = $bi_db_path.TrimEnd('\')

	$variable_test = Get-Variable -Name app_path -Scope Local -ErrorAction SilentlyContinue
	if ($null -eq $variable_test) {
		$err_msg = "ERR/User-settings file is missing setting `$app_path"
		return $err_msg
		if ($app_path.StartsWith('YOUR')) {  
			$err_msg = "ERR/user-setting file setting 'app_path' is not set"
			return $err_msg
		}
	}
	$app_path = $app_path.TrimEnd('\')

	$variable_test = Get-Variable -Name bi_webserver -Scope Local -ErrorAction SilentlyContinue
	if ($null -eq $variable_test) {
		$err_msg = "ERR/User-settings file is missing setting `$bi_webserver"
		return $err_msg
	} else {
		if ($bi_webserver.StartsWith('YOUR')) {  
			$err_msg = "ERR/user-setting file setting 'bi_webserver' is not set"
			return $err_msg
		}
	}

	$variable_test = Get-Variable -Name bi_user_name -Scope Local -ErrorAction SilentlyContinue
	if ($null -eq $variable_test) {
		$err_msg = "ERR/User-settings file is missing setting `$bi_user_name"
		return $err_msg
	} else {
		if ($bi_user_name.StartsWith('YOUR')) {
			$err_msg = "ERR/user-setting file setting 'bi_user_name' is not set"
			return $err_msg
		}
	}

	$variable_test = Get-Variable -Name bi_user_pw -Scope Local -ErrorAction SilentlyContinue
	if ($null -eq $variable_test) {
		$err_msg = "ERR/User-settings file is missing setting `$bi_user_pw"
		return $err_msg
	} else {
		if ($bi_user_pw.StartsWith('YOUR')) {
			$err_msg = "ERR/user-setting file setting 'bi_user_pw' is not set"
			return $err_msg
		}
	}

	# ... Handle OPTIONAL user settings
	if (!$use_bi_creds) {
		$use_bi_creds = $false
	}
	if (!$auto_open_csv_file) {
		$auto_open_csv_file = $false
	}
	if (!$auto_open_csv_file_in_def_app) {
		$auto_open_csv_file_in_def_app = $false
	}
	if (!$auto_open_csv_file_min_rows) {
		$auto_open_csv_file_min_rows = 0
	}
	if (!$ignore_img1_json_zero_length_warnings) {
		$ignore_img1_json_zero_length_warnings = $false
	}
	if (!$shorten_model_name) {
		$shorten_model_name = $null
	}
	if (!$post_to_BI_logfile_flg) {
		$post_to_BI_logfile_flg = $false
	}
	if (!$post_to_BI_logfile_in_background_only_flg) {
		$post_to_BI_logfile_in_background_only_flg = $false
	}
}
# ----------------------------

function BIHttpCall() {
# PURPOSE: Send Blue Iris HTTP Interface command to the Blue Iris web server.
#          Intended to be called by other PowerShell scripts.
# ARGS:    -HttpCmd  = (string) like '/admin?camera=x&trigger=1'
# RETURNS: (string) web server plain text output, or error message
#
# Version: X
# Created by jaydeel at ipcamtalk.com

	# MUST BE THE FIRST LINE
	param (
		[string]$HttpCmd
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging
	#Write-Host "Entered $fn_name() ..."
	#Write-Host "$fn_name() -HttpCmd = '$HttpCmd'"

	# INITIALIZE VARS
	$PsVersion = $PSVersionTable.PSVersion.Major

	# PARSE COMMANDLINE ARGS
	if ($null -eq $HttpCmdl) {
		if ($fromConsole) {
			Write-Host "ERR/expecting an argument: HttpCmd`n"
			exit
		} else {
			$err_msg = "ERR/expecting an argument: HttpCmd"
			return $err_msg
		}
	}

	# ========================
	# PERFORM API CALLS

	# Make the URL
	if ($use_bi_creds) {
		$uri = "http://" + $bi_webserver + $HttpCmd + "&user=" + $bi_user_name + "&pw=" + $bi_user_pw
	} else {
		$uri = "http://" + $bi_webserver + $HttpCmd	
	}
	# For debugging
	#Write-Host "uri = '$uri'"

	# ================================================================
	# EXECUTE THE REQUESTED HTTP COMMAND 
	try {
		#$web_response_obj = Invoke-WebRequest -Uri $uri -UseBasicParsing
		$web_response_obj = Invoke-WebRequest -Uri $uri
	} 
	catch {

		# For debugging
		#Write-Host $error
		#Write-Host $_.ScriptStackTrace
		#Write-Host $PSitem

		Write-Host $_.Exception.Message -ForegroundColor Red
		$err_msg = "ERR/unexpected HTTP Interface command response"
		return $err_msg
	}

	# For debugging
	# REF: https://4sysops.com/archives/powershell-invoke-webrequest-parse-and-scrape-a-web-page/
	if ($web_response_obj) {
		#Write-Host ("Web Response type = " + $web_response_obj.GetType())
		#$web_response_obj| Get-Member
		#$web_response_obj.Content
		#$web_response_obj.Headers
		#$web_response_obj.StatusCode
		#$web_response_obj.StatusDescription	
	} 

	# @@@ DEV - Retain for error testing
	#$web_response_obj = $null
	#$web_response_obj = ''

	if ($null -eq $web_response_obj) {
		$err_msg = "ERR/null response from Blue Iris HTTP interface"
		return $err_msg
	} 
	if ($web_response_obj -eq '') {
		$err_msg = "ERR/empty response from Blue Iris HTTP interface"
		return $err_msg
	}
	If ($web_response_obj -match "<!DOCTYPE html>") {

		# For debugging
		#$HTML = New-Object -Com "HTMLFile"
		#$HTML.write([ref]$web_response_obj)
		#$TextOnly = $Html.body.innerText
		#Write-Host $TextOnly -ForegroundColor Cyan

		$err_msg = "ERR/unexpected response"
		return $err_msg
	}
	
	# For debugging
	#Write-Host $web_response_obj.Content
	
	return "success"


}

function BIJsonCall() {
# PURPOSE:   To get a Blue Iris JSON interface response from the Blue Iris web server.
#            Intended to be called by other PowerShell scripts.
# ARGUMENTS: -JsonCmd        = (hashtable) like '@{cmd=xxx},@{cmd=xxx,camera=name},...'
#            -ForceFlg       = [OPTIONAL] (boolean) forces new login (gets a new authenticated session id)
#            -RetryNo        = [OPTIONAL] (int) if -gt 0, this call is a retry attempt
#            -QuietFlg       = [OPTIONAL] (boolean) $true suppresses verbose output to the console
#            -FromConsoleFlg = [OPTIONAL] (boolean) $true notifies function that calling command was executed from the console
# RETURNS:   (object) PowerShell PSCustomObject
# REFS:      1) Blue Iris Help PDF: chapter 'Administration', section 'JSON Interface'
#            2) https://www.houselogix.com/docs/blue-iris/BlueIris/json.htm  (old!)
#            3) https://ipcamtalk.com/threads/json-interface.21491/
#            4) https://ipcamtalk.com/threads/json-help-please.40381/#post-372770
# NOTES:
# 1) Saves the BI API session id to a file for reuse (to avoid unnecessary repeated 
#    logins while the session is still active); the file stored in folder'c:\temp\$ScriptBaseName' (created if necessary)
# 2) In the event that the JSON call fails with reason 'Invalid session', the script will automatically attempt to repeat 
#    the call up to $max_retries
#
# Version: 3 (2024-02-17)
# Created by jaydeel at ipcamtalk.com

	param (
		[Hashtable]$JsonCmd,
		[Boolean]$ForceFlg,
		[Int]$RetryNo,
		[Boolean]$QuietFlg,
		[Boolean]$FromConsoleFlg
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging
	#Write-Host "Entered function: $fn_name() ..."	
	#Write-Host "`Entered function $fn_name()`n-----------------------------"
	#Write-Host ("$fn_name() JsonCmd = " + ($JsonCmd | ConvertTo-Json))
	#Write-Host "$fn_name() PsVersion = $PsVersion"	
	#Write-Host "$fn_name() FromConsoleFlg = $FromConsoleFlg"

	# For debugging
	#Write-Host "$fn_name() retry_cntr = $retry_cntr"	

	# System vars
	$ScriptName = Split-Path -leaf $PSCommandpath
	$ScriptBaseName = $ScriptName.Replace('.ps1', '')
	$ParentProcess = (Get-Process -Id (Get-CimInstance Win32_Process -Filter "ProcessID = $pid").ParentProcessId).Name
	$PsVersion = $PSVersionTable.PSVersion.Major
	# Get the current server domain (hostname) and username
	# Used for background messaging via msg.exe
	# ... tip: from the console, you can type 'hostname' or 'whoami'
	$server_name = (whoami).Split('\')[0]
	$server_username = (whoami).Split('\')[1]

	function encryptMD5($str) {
	# PURPOSE: Get MD5 hash for a string.
	# ARGS:    $str = (string) string to be encrypted
	# RETURNS: (string) MD5 encrypted string... like, '0753a0e20c9027ccab70f4291a21aa08'
	# REF:     https://infosecscout.com/get-md5-hash-in-powershell/
	# NOTES:   (from REF)
	#	Unfortunately, PowerShell provides no direct function to generate a hash from a string.
	#	However, PowerShell offers a cmdlet to generate MD5 hash for a file: Get-FileHash. 
	# 	The cmdlet can also be used to get the MD5 hash for a string, by opening a stream and hashing it.
	# UTILITY: https://www.md5hashgenerator.com/
	# ... Example: 'MD5string' returns '0753a0e20c9027ccab70f4291a21aa08'

		$stringAsStream = [System.IO.MemoryStream]::new()
		$writer = [System.IO.StreamWriter]::new($stringAsStream)
		$writer.write($str)
		$writer.Flush()
		$stringAsStream.Position = 0
		$hash_obj = Get-FileHash -InputStream $stringAsStream -Algorithm MD5
		
		# For debugging
		#$str = $hash_obj | Out-String
		#Write-Host "hash_obj = $str"

		return $hash_obj.Hash
	}
	
	# MAX RETRIES FOR JSON CMD
	# ... This function will recursively call itself if a JSON cmd's previous
	#     $json_response.result value is 'fail' and the reason is 'Invalid session'
	$max_retries = 3
	# ... Wait time before attempting a 'Invalid session' recursive call 
	$retry_delay_ms = 100
	
	if (!$RetryNo) {
		$retry_cntr = 0
	} else {
		$retry_cntr = $RetryNo
	}

	# Abort if we've exceeded the retries 'Invalid session' break variable
	if ($retry_cntr -ge $max_retries) {
		$err_msg ="ERR/JsonCmd '" + $JsonCmd.cmd + "' unable to create a valid session"
		return $err_msg
	}
		
	# Show progress bar as a heads-up visualization that retries are being attempted
	<# if ($retry_cntr -gt 0) {
		if ($fromConsole) {
			$WriteProgressParams = @{
				Activity         = "Retrying BI JSON Call..."
				Status           = "Progress: retry $retry_cntr of $max_retries max"
				PercentComplete  = (($retry_cntr / $max_retries) * 100)
			}
			Write-Progress @WriteProgressParams
			# Note: If loop is too fast, you might need a delay to get the progress bar to show
			Start-Sleep -Milliseconds 2000				
		}
	} #>

	# HANDLE FILES FOR SAVED SESSION IDS AND RETRY COUNTER
	# ... Perform existence test for the *.txt file used to save session ids
	#     Create its path if it does not exist
	#     NOTE: if a path is not specified, the default Windows location is 'C:\Users\<username>"
	$path = "c:\temp\$ScriptBaseName"
	if (!(Test-Path -LiteralPath $path)) {
		New-Item -ItemType Directory -Force -Path $path
	}
	# ... NOTE: we use a different filename when running the script via different processes;
	#     this avoids collisions with scripts running via:
	#     'scvhost' (Task Scheduler), 'WindowsTerminal', 'explorer' (Powershell ISE)
	$base_name = "$path\bi_session_id"
	$session_filespec = $base_name + "_" + $ParentProcess + ".txt"
	$found_saved_session_file_flg = (Test-Path -LiteralPath "$session_filespec")

	# PARSE COMMANDLINE ARGS
	if ($JsonCmd -eq $null) {
		$err_msg = "ERR/expecting an argument: JsonCmd (PowerShell hashtable)"
		return $err_msg
	} else {
		# For debugging
		#Write-Host ("requested JsonCmd type = " + ($JsonCmd.GetType()))
	}
	# ... Save original JsonCmd (in case we need to make a recursive call)
	$json_cmd_orig = $JsonCmd
	# ... Override reuse of saved session_id
	if ($ForceFlg) {
		$found_saved_session_file_flg = $false
	}

	# ========================
	# PERFORM API CALLS

	# Make the URL
	$uri = "http://" + $script:bi_webserver + "/json";

	# For debugging
	#Write-Host "$fn_name() uri = $uri"

	# Flag 'logout' JSON cmd requests
	# ... NOTE: All JSON 'logout' cmds should be performed by the calling script!
	if ($JsonCmd.cmd -eq 'logout') {
		$logging_out_flg = $true
	} else {
		$logging_out_flg = $false
	}
	
	# For debugging
	if ($logging_out_flg) {
		#Write-Host "$fn_name() detected JSON cmd to log out of BI API session"
	} else {
		#Write-Host "$fn_name() found_saved_session_file_flg... $found_saved_session_file_flg"
		#msg.exe * /TIME:5 "$fn_name() found_saved_session_file_flg... $found_saved_session_file_flg"
	}

	# SPECIAL HANDLING FOR 'geofence' JSON COMMAND REQUESTS
	$dev_uuid = $null  # Default
	$json_cmd_keys = $JsonCmd.Keys
	if ($json_cmd_keys -contains 'uuid') {
		if ($JsonCmd.uuid -ne $null) {
			$dev_uuid = $JsonCmd.uuid
		}
	}

	# For debugging
	if ($dev_uuid) {
		#Write-Host "$fn_name() dev_uuid = $dev_uuid"
	}

	# EXECUTE API CALL
	
	if (!$found_saved_session_file_flg) {
		
		# ================================================================
		# 1.1 PRELIMINARY LOGIN
		
		# Create, then encode the JSON 'login' command
		$parameters = @{
			cmd = 'login'
		}
		$json_params = $parameters | ConvertTo-Json

		# For debugging
		#Write-host "$fn_name() (1.1) login #1 json_params... `n$json_params"
		#msg.exe $server_username /TIME:15 "$fn_name() (1.1) login #1 json_params... `n$json_params"

		# Execute the JSON request
		$jsonResponseObj = $json_params | Invoke-RestMethod -Uri $uri -Method Post

		# For debugging
		#msg.exe $server_username /TIME:15 "$fn_name() (1.1) login #1 jsonResponse... `n$jsonResponseObj"
		
		# Get the session id
		$session = $jsonResponseObj.session
		
		# ================================================================
		# 1.2 AUTHENTICATE THE LOGIN

		# Create MD5 hash-encoded credentials string
		$response_str = $bi_user_name + ":" + $session + ":" + $bi_user_pw
		$response_hash = encryptMD5 $response_str

		# Create, then encode a modified JSON 'login' command
		if ($dev_uuid) {
			$parameters = @{
				cmd = 'login'
				session = $session
				response = $response_hash
				uuid = $dev_uuid
			}
		} else {
			$parameters = @{
				cmd = 'login'
				session = $session
				response = $response_hash
			}
		}
		$json_params = $parameters | ConvertTo-Json

		# For debugging
		#Write-Host "$fn_name() (1.2) authorizing json login... `n$json_params"
		#msg.exe $server_username /TIME:15 "$fn_name() (1.2) authorizing json login ... `n$json_params"
		
		# Execute the JSON request
		$jsonResponseObj = $json_params | Invoke-RestMethod -Uri $uri -Method Post

		# For debugging
		#Write-Host ("$fn_name() (1.2) jsonResponse... `n" + ($jsonResponseObj  | ConvertTo-Json))
		#msg.exe $server_username /TIME:15 "$fn_name() (1.2) jsonResponse... `n$jsonResponseObj"
		
		# Handle failure
		if ($jsonResponseObj.result -eq 'fail') {
			$err_msg = "ERR/unable to authenticate Blue Iris JSON interface`n"
			return $err_msg
		}
		
		# Get the authenticated session id
		$auth_session_id = $jsonResponseObj.session

		# For debugging
		#msg.exe $server_username /TIME:5 "$fn_name() auth_session_id... $auth_session_id"
	
		# Save the authenticated session id
		# NOTE: the session id is always saved, whether used or not
		$auth_session_id | Set-Content "$session_filespec" -NoNewline

	} else {
	
		# Retrieve the saved session id
		# KEY POINT: 
		#   Force typing the output of 'Get-Content' to [String] was essential when running script in
		#   in Powershell ISE. Otherwise the output was similar to an object.
		#   *** But in actuality it is more complicated ***
		#   Per https://stackoverflow.com/a/55881978/13499984
		#      When 'Get-Content' is assigned to a variable, its output is an array of .NET [String] objects, 
		#      each representing a line from the input file. However, Get-Content also decorates these string 
		#      objects with additional properties that provide helpful metadata about where the strings came from.
		$saved_session_id = [String](Get-Content -Path "$session_filespec")

		$auth_session_id = $saved_session_id

		# For debugging
		if (!$logging_out_flg) {
			#Write-Host ("$fn_name() saved_session_id type = " + $saved_session_id.GetType())
			#Write-Host "$fn_name() saved_session_id... $saved_session_id"
			#msg.exe * /TIME:5 "$fn_name() saved_session_id... $saved_session_id"
		}
		
	}

	# ================================================================
	# 1.3 EXECUTE THE REQUESTED JSON COMMAND

	if ($dev_uuid -eq $null) {
		
		# In the event that this JSON call fails with reason 'Invalid session',
		# the script will automatically attempt up to $max_retries
	
		# Modify, then encode the requested JSON login command
		$JsonCmd.session = $auth_session_id
		$json_params = $JsonCmd | ConvertTo-Json

		# Execute the JSON request
		$params = @{
			Uri                = $uri
			#Headers            = @{"Content-Type"  = "application/json"}
			Method             = 'POST'
			#Body               = $JsonCmd | ConvertTo-Json
			Body               = $json_params
			ContentType        = 'application/json'
		}
		
		$json_response_obj = Invoke-RestMethod @params

		# Alternate syntaxes (pick one)
		#$json_response_obj = Invoke-RestMethod -Uri $uri -Method Post -Body ($JsonCmd | ConvertTo-Json) #>
		#$json_response_obj = ($JsonCmd | ConvertTo-Json) | Invoke-RestMethod -Uri $uri -Method Post

		# For debugging
		#if ($JsonCmd.cmd -match 'update') {
			#Write-Host ("$fn_name() (1.3) requested JsonCmd '" + $JsonCmd.cmd + "'")
			#Write-Host ("$fn_name() (1.3) requested JsonCmd '" + $JsonCmd.cmd + "' ...`n" + $json_params)
			#Write-Host ("$fn_name() json_response_obj = `n" + ($json_response_obj | ConvertTo-Json))
		#}

		if ($json_response_obj.result -eq 'fail') {
			
			# For debugging
			#Write-Host ("$fn_name() (1.3) JsonCmd '" + $JsonCmd.cmd + "' response.result = fail")
			#Write-Host ("$fn_name() (1.3) JsonCmd '" + $JsonCmd.cmd + "' response = `n" + ($json_response_obj | ConvertTo-Json))

			# Try to determine reason
			if ($json_response_obj.data) {

				$data_obj = $json_response_obj.data

				# For debugging
				#Write-Host ("$fn_name() JsonCmd '" + $JsonCmd.cmd + "' response.data = " + ($data_obj | ConvertTo-Json))
				
				if ($data_obj.reason) {
					$reason = $data_obj.reason
				
					# For debugging
					#Write-Host ("$fn_name() JsonCmd '" + $JsonCmd.cmd + "' response.data.reason = $reason")

					if ($reason -match 'Invalid session') {
						# Update retry counter
						$retry_cntr++
						
						# RECURSIVE CALL
						#Start-Sleep -Milliseconds 500
						$json_response_obj = `
							BIJsonCall `
							-JsonCmd $JsonCmd `
							-ForceFlg $true `
							-RetryNo $retry_cntr `
							-QuietFlg $QuietFlg `
							-FromConsoleFlg $FromConsoleFlg
						
					} elseif ($reason -match 'Access denied') {
						$err_msg ="ERR/JsonCmd '" + $JsonCmd.cmd + "' requires an Administrator account"
						return $err_msg
						
					} else {
						$err_msg = "ERR/JsonCmd '" + $JsonCmd.cmd + "' failed with reason '" + $reason + "'"
						return $err_msg
					}
					
				} else {
					$err_msg = "ERR/JsonCmd '" + $JsonCmd.cmd + "' failed without a reason"
					return $err_msg
				}
			}
		} 
	}

	# For debugging
	if ($json_response_obj) {
		#Write-Host ("$fn_name() (1.3) jsonResponse type = " + $json_response_obj.GetType())
		#Write-Host ("$fn_name() (1.3) jsonResponse... `n" + ($json_response_obj  | ConvertTo-Json))
		#msg.exe $server_username /TIME:5 "$fn_name() (1.3) jsonResponse... $json_response_obj"
	} 

	# Retain for error testing
	#$json_response_obj = $null
	#$json_response_obj = ''

	if ($json_response_obj -eq $null) {
		$err_msg ="ERR/null response from Blue Iris JSON interface"
		return $err_msg
	} 
	if ($json_response_obj -eq '') {
		$err_msg = "ERR/empty response from Blue Iris JSON interface"
		return $err_msg
	}
	if ($json_response_obj.result -ne $null) {

		# For debugging
		#Write-Host ("$fn_name() (1.3) json_response_obj.result... " + ($json_response_obj.result))
		
		if ($json_response_obj.result -eq 'fail') {
			
			# Show the contents of the $json_response_obj 'data' key

			$json_data_obj = $json_response_obj.data
			
			# For debugging
			#Write-Host ("$fn_name() (1.3) json_response_obj.data... " + ($json_response_obj.data))

			if ($PsVersion -ge 7) {
				# Avoids the following WARNING...
				# "Resulting JSON is truncated as serialization has exceeded the set depth of N"
				$jdo_str = $json_data_obj | ConvertTo-Json -Depth 16
			} else {
				$jdo_str = $json_data_obj | ConvertTo-Json
			}
			
			# 'Minify' the json string.
			if ($jdo_str) {
				if (!($jdo_str -match 'null')) {
					$err_msg = "ERR/JSON response for cmd '" + $JsonCmd.cmd + "' is 'result:fail'"
					return $err_msg
				} else {					
					$err_msg = "ERR/JSON response for cmd '" + $JsonCmd.cmd + "' is null (DB record not found)"
					return $err_msg
				}
			}
		}
	}

	return $json_response_obj

}

function MakeBitArray() {
# PURPOSE:    To factor a decimal number to a specified number of bits N (i.e., 2^0, 2^1 ... 2^N).
# PARAMS:     -DecValue = base 10 number
#             -NoBits   = size of return array (NOTE: index starts at zero)
# RETURNS:    (integer array) of 0's and 1's for each bit (1 if set, 0 if not).
#             Example: dec 403767296 to bin returns 29 bits 11000000100010000000000000000
#                      but we want 32 bits               00011000000100010000000000000000

	param (
		[Int64]$DecValue, 
		[Int]$NoBits
	)

	$bin_str = [convert]::ToString($DecValue,2)

	# For debugging
	#Write-Host "$DecValue to bin = $bin_str"

	if ($bin_str.length -le $NoBits) {
		$str = $bin_str.PadLeft($NoBits,'0')
	} else {
		$str = $bin_str.Substring(0,$NoBits)
	}
	$bin_ary = $str.ToCharArray()
	
	# Reverse the array
	[array]::Reverse($bin_ary)
	
	# Convert string array to integer array
	$rtn_ary = @()
	foreach($item in $bin_ary) {
		if ($item -match "1") {
			$rtn_ary += 1
		} else {
			$rtn_ary += 0
		}
	}

	# For debugging
	#Write-Host ("str = " + $str)
	#Write-Host ("rtn_ary cnt = " + $rtn_ary.Count)
	#Write-Host ("rtn_ary = " + $rtn_ary)
	
	return $rtn_ary;
}

function IsBiVersion() {
# PURPOSE:   To confirm if the current Blue Iris version exceeds a specified version
# ARGUMENTS: $CompareVersion = [REQUIRED] (string) compare version, like '5.7.2.3'
#            Note: supports version strings 'X.000.000.000' to 'X.999.999.999'            
# REQUIRES:  function BIJsonCall()
	
	param (
		[String]$CompareVersion,
		[Boolean]$QuietFlg,       # used by BIJsonCall()
		[Boolean]$FromConsoleFlg  # used by BIJsonCall()
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	#Write-Host "Entered $fn_name()..."
	#Write-Host "$fn_name() CompareVersion = $CompareVersion"
	
	$rtn_flg = $false  # Assume failure

	# GET CURRENT VERSION
	$jsonCmd = @{
		cmd = 'login'
	}
	# Returns a powershell PSCustomObject
	$json_response_obj = `
		BIJsonCall `
		-JsonCmd $jsonCmd `
		-QuietFlg $QuietFlg `
		-FromConsoleFlg $FromConsoleFlg

	# For debugging
	#Write-Host ("$fn_name() BIJsonCall() json_response_obj type = " + $json_response_obj.GetType())
	#Write-Host ("$fn_name() BIJsonCall() json_response_obj = " + ($json_response_obj | ConvertTo-Json))

	# Abort if GET failed
	if ($json_response_obj -match 'ERR/') {
		if ($FromConsoleFlg) {
			Write-Host "$fn_name() ERR/JSON request failed"
			Write-Host "$fn_name() BIJsonCall() json_response_obj = $json_response_obj`n"
		}
		return $false
	}
	if ($json_response_obj.result -eq 'fail') {
		$x  = $json_response_obj.result
		if ($FromConsoleFlg) {
			Write-Host "$fn_name() ERR/JSON request failed ('result' = fail)"
			Write-Host "$fn_name() BIJsonCall() json_response_obj.result = $x`n"
		}
		return $false
	}

	# Extract data from the JSON command response
	if (Get-Member -InputObject $json_response_obj -name "data" -Membertype Properties) {

		$data_obj = $json_response_obj.data

		# Get the current version
		$bi_version = $data_obj.version
		
		# Make comparator integer arrays
		[int[]]$my_ver_ary = $CompareVersion.Split('.')
		[int[]]$bi_ver_ary = $bi_version.Split('.')

		# Make 'prime.subprime' version comparators, like 5.8 vs 5.7
		$my_ver_prime_dot = $my_ver_ary[0] + $my_ver_ary[1]/1000
		$bi_ver_prime_dot = $bi_ver_ary[0] + $bi_ver_ary[1]/1000

		# For debugging
		#Write-Host "bi_version = $bi_version"
		#Write-Host ("my_ver_ary = " + ($my_ver_ary | ConvertTo-Json))
		#Write-Host ("bi_version_ary = " + ($bi_ver_ary | ConvertTo-Json))
		#Write-Host "my_ver_prime_dot = $my_ver_prime_dot"
		#Write-Host "bi_ver_prime_dot = $bi_ver_prime_dot"
		
		if ($my_ver_prime_dot -eq $bi_ver_prime_dot) {

			# Make sub-subprime version comparators, 5.001 for 5.8.5.1, 999.020 for 5.8.999.20

			if ($my_ver_ary[2] -eq 0 -and $my_ver_ary[3] -eq 0) {
				$my_ver_sub = 0.000
			} else {
				$my_ver_sub = $my_ver_ary[2] + $my_ver_ary[3]/1000
			}

			if ($bi_ver_ary[2] -eq 0 -and $bi_ver_ary[3] -eq 0) {
				$bi_ver_sub = 0.000
			} else {
				$bi_ver_sub = $bi_ver_ary[2] + $bi_ver_ary[3]/1000
			}

			# For debugging
			#Write-Host ("my_ver_sub = " + ("{0:n3}" -f $my_ver_sub))
			#Write-Host ("bi_ver_sub = " + ("{0:n3}" -f $bi_ver_sub))

			$rtn_flg = ($bi_ver_sub -ge $my_ver_sub) 

		} else {
			$rtn_flg = ($bi_ver_prime_dot -ge $my_ver_prime_dot)
		}
	}

	return $rtn_flg
}

function BIJsonAlertListParse() {
# PURPOSE:   To get and parse the Blue Iris JSON interface cmd 'alertlist' response for a single camera
#            To retrieve all or, if requested, a subset of 'alertlist' properties for each Alert
#            NOTE: returns non-existent requested 'alertlist' properties as 'alert_prop':'NA'
# PARAMS:    -CamName        = [REQUIRED] camera shortname
#            -Pattern        = process Alerts with descriptor substring; must be used w/ -CamName
#            -AlertProps     = (array) like 'memo,offset', comma delimited
#              			       options: camera, clip, color, date, file, filesize, flags memo, 
#                                       newalerts, newalerttime, offset, path, res, zones
#            -MemoTag        = (string) process only those protected Alerts with descriptor substring
#            -AlertPath      = (string) process single Alert with alertlist [path] like '@123456789'
#            -DatabaseView   = (string) default is 'alerts'
#                              options: all, new, stored, alerts, aux1, aux2, aux3, aux4, aux5, aux6, aux7,
#                                       flagged, export, archive, people, vehicles, confirmed, or canceled                             
#                              Note: When view='flagged', clip items are included too, but they don't have msec metadata.
#            -FromConsoleFlg = (boolean) $true notifies function that calling command was executed from the console
#            -QuietFlg       = (boolean) true suppresses verbose informational output to the console
#            -SilentFlg      = (boolean) true suppresses all output to the console, including warnings
#            -DevModeFlg     = (boolean) true performs devmode actions
#            -DevModePath    = (string) destination full path for devmode actions
# RETURNS:  (object) PowerShell hashtable, @('cam':camName,'alert_prop':value}
# REQUIRES: Functions: BIJsonCall(), IsBiVersion()
#
# Created by jaydeel at ipcamtalk.com
# Version: 4 (2024-02-18)
#
# Description of JSON cmd 'camlist' from the Blue Iris Help PDF:
#    "returns a list of cameras on the system ordered by group. Cameras not belonging to any
#    group are shown beneath the "all cameras" group. Disabled cameras are placed at the end of
#    the list. An array of objects is returned in data (note the [] surrounding a JSON array), each
#    describing a camera or a camera group."

	param(
		[String]$CamName,           # [REQUIRED] camera shortname
		[String]$Pattern,           # must be used with -CamName
		[String[]]$AlertProps,      # list of BI JSON 'alertlist' cmd properties (parameters)
		[String]$MemoTag,           # substring in Alert's memo
		[String]$DatabaseView,      # default is 'alerts'
		[String]$AlertPath,         # like '@123456789' (JSON alertlist [path] value)
		[Boolean]$FromConsoleFlg,
		[Boolean]$QuietFlg,
		[Boolean]$SilentFlg,
		[Boolean]$DevModeFlg,
		[String]$DevModePath
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging
	#Write-Host "Entered $fn_name() ..."
	#Write-Host "$fn_name() CamName = $CamName"
	#Write-Host "$fn_name() Pattern = $Pattern"
	#Write-Host ("$fn_name() AlertProps type = " + $AlertProps.GetType())
	#Write-Host ("$fn_name() AlertProps = " + ($AlertProps | ConvertTo-Json))
	#Write-Host "$fn_name() MemoTag = $MemoTag"
	#Write-Host "$fn_name() DatabaseView = $DatabaseView"
	#Write-Host "$fn_name() AlertPath = $AlertPath"
	#Write-Host "$fn_name() FromConsoleFlg = $FromConsoleFlg"
	#Write-Host "$fn_name() QuietFlg = $QuietFlg"
	#Write-Host "$fn_name() DevModeFlg = $DevModeFlg"
	#Write-Host "$fn_name() DevModePath = $DevModePath"

	#Set-StrictMode  -Version 3
	# PARSE ARGS
	if ($Pattern -and !$CamName) {
		$err_msg = "ERR/argument -Pattern must be used with -CamName [$fn_name]"
		return $err_msg
	}
	if (!$CamName) {
		$err_msg = "ERR/expecting at least 1 argument (-CamName) [$fn_name]"
		return $err_msg
	}

	# If searching only a single AlertMemo, we can avoid GETTING all alerts 
	# via the JSON 'alertlist' cmd parameter 'search'
	$search_param_val = $null
	if ($MemoTag) {
		$search_param_val = $MemoTag
	}
	#Write-Host "$fn_name() search_param_val = $search_param_val"
	
	if (!$DatabaseView) {
		$DatabaseView = 'all'
	}
	if (!$AlertPath) {
		$AlertPath = "*"
	}

	# Initialize master collector for all alerts in database 
	$al_props_obj = @{}
	$al_props_obj.Add( 'cameras', @() )
	$al_props_obj.Add( 'paths', @() )
	$al_props_obj.Add( 'clips', @() )
	$al_props_obj.Add( 'files', @() )
	$al_props_obj.Add( 'memos', @() )
	$al_props_obj.Add( 'offsets', @() )
	$al_props_obj.Add( 'flagss', @() )  # double 's' intentional!
	$al_props_obj.Add( 'ress', @() )    # double 's' intentional!
	$al_props_obj.Add( 'zoness', @() )  # double 's' intentional!
	$al_props_obj.Add( 'dates', @() )
	$al_props_obj.Add( 'colors', @() )
	$al_props_obj.Add( 'filesizes', @() )
	
	# For debugging
	#Write-Host ("$fn_name() al_props_obj type = " + $al_props_obj.GetType())
	#Write-Host ("$fn_name() al_props = " + ($al_props_obj | ConvertTo-Json))

	# ---------------------------------------------------------------------------------------
	# KEY POINT: Prior to version 5.7.9.3 BI's 'alertlist' json cmd returned only 1000 items; 
	#            As of version 5.7.9.3 BI's 'alertlist' json cmd returns 2048 items; 
	#            so we must re-send the json cmd until we have retrieved all alerts.
	#            REF: https://ipcamtalk.com/threads/blue-iris-ui3.23528/post-788744
	
	# For debugging
	#Write-Host ("BI version > 5.7.9.3 = " + (IsBiVersion '5.7.9.3'))

	if (IsBiVersion '5.7.9.3') {
		$json_alertlist_max = 2048;
		#$json_cliplist_max = 4096;
	} else {
		$json_alertlist_max = 1000;  # Default (tested against a BI 5.6.3.7 server by bp2008@ipcamtalk)
		#$json_cliplist_max = 1200;   # Default (tested against a BI 5.6.3.7 server by bp2008@ipcamtalk)
	}
	# ---------------------------------------------------------------------------------------

	# Initialize WHILE LOOP variables
	[Array]$paths_ary = @('x')	# primary break loop variable... starts with a dummy value
	$oldest_date = 0  # oldest date found 
	$newest_date = 0  # newest date found 
	$skipped_next_json_call_flg = $false
	
	# Initialize WHILE LOOP break variables
	$prev_loop_alerts_cnt = 0
	$max_tries = 10
	$iter = 1;

	# WHILE LOOP - Get JSON 'alertlist' data in batches until the cmd returns no new data
	while ($paths_ary.Count -gt 0) {
		
		if ($DevModeFlg) {
			if ($FromConsoleFlg) {
				if ($iter -eq 1) {
					Write-Host ""
					Write-Host "(dev mode) ----- $CamName" -ForegroundColor Cyan
				} else {
					Write-Host "(dev mode) -----" -ForegroundColor Cyan
				}
				Write-Host "(dev mode) JSON alertlist iter #$iter" -ForegroundColor Cyan
			}
		}

		# Initialize collector this JSON 'alertlist' call
		$tmp_obj = @{}
		$tmp_obj.Add( 'cameras', @() )
		$tmp_obj.Add( 'paths', @() )
		$tmp_obj.Add( 'clips', @() )
		$tmp_obj.Add( 'files', @() )
		$tmp_obj.Add( 'memos', @() )
		$tmp_obj.Add( 'offsets', @() )
		$tmp_obj.Add( 'flagss', @() )  # double 's' intentional!
		$tmp_obj.Add( 'ress', @() )    # double 's' intentional!
		$tmp_obj.Add( 'zoness', @() )  # double 's' intentional!
		$tmp_obj.Add( 'dates', @() )
		$tmp_obj.Add( 'colors', @() )
		$tmp_obj.Add( 'filesizes', @() )
		#$tmp_obj.Add( 'AAAA', @() )
		
		# For debugging
		#Write-Host ("$fn_name() tmp_obj type = " + $tmp_obj.GetType())
		#Write-Host ("$fn_name() tmp_obj = " + ($tmp_obj | ConvertTo-Json))
		#Write-Host ("$fn_name() tmp_obj.paths type  = " + ($tmp_obj.paths).GetType())

		# GET JSON DATA FROM THE BLUE IRIS WEB SERVER

		# First call params - Default
		$jsonCmd = @{
			cmd = 'alertlist'
			camera = $CamName
			search = $search_param_val
			view = $DatabaseView
		}
		
		# Subsequent call params
		if ($iter -gt 1) {
			
			# For debugging
			#Write-Host ("$fn_name() oldest_date type = " + $oldest_date.GetType())
			#Write-Host "$fn_name() oldest_date = $oldest_date"
			
			if ($oldest_date -gt 0) {  #Just in case
				# Params for the next set of 'alertlist' data
				$jsonCmd = @{
					cmd = 'alertlist'
					camera = $CamName
					search = $search_param_val
					view = $DatabaseView
					enddate = $oldest_date   # oldest time found (so far); per Ken @ Blue Iris Support 
				}
			}
		}
		
		# For debugging
		#Write-Host ("$fn_name() jsonCmd = " + ($jsonCmd | ConvertTo-Json))

		# FIRST JSON CALL
		# Returns a powershell PSCustomObject
		$json_response_obj = `
			BIJsonCall `
			-JsonCmd $jsonCmd `
			-QuietFlg $QuietFlg `
			-FromConsoleFlg $FromConsoleFlg

		if ($FromConsoleFlg) {
			if ($iter -gt 1) {
				#Write-Host ("$fn_name() jsonCmd response type = " + $json_response_obj.GetType())
				#Write-Host ("$fn_name() jsonCmd response = " + ($json_response_obj | ConvertTo-Json))
			}
		}

		if ($json_response_obj -match 'success') {

			# Test for $json_response_obj.data object
			if (Get-Member -InputObject $json_response_obj -name "data" -Membertype Properties) {

				$data_obj = $json_response_obj.data

				if ($data_obj) {
					
					# For debugging
					#Write-Host ("$fn_name() data_obj = " + ($data_obj | ConvertTo-Json))
					#Write-Host ("$fn_name() data_obj cnt = " + ($data_obj.Count))
					#Write-Host ("$fn_name() data_obj.path type = " + ($data_obj.path).GetType())
					#Write-Host ("$fn_name() data_obj.memo type = " + ($data_obj.memo).GetType())

					# KEY POINT: $paths_ary is the WHILE LOOP's primary break variable
					try {
						$paths_ary = [String[]]$data_obj.path  					
					}
					catch {
						$err_msg = "ERR/JSON 'alertlist' response for '$CamName' contains no 'path' entries (database corrupt?)"
						return $err_msg
					}
					
					# Get the alertlist dates array
					# KEY POINT: using try:catch as a redundant quality test
					try {
						$dates_ary = [int[]]$data_obj.date  					
					}
					catch {
						$err_msg = "ERR/JSON 'alertlist' response for '$CamName' contains no 'date' entries (database corrupt?)"
						return $err_msg
					}

					# PERFORM SPECIAL HANDLING FOR THE 'MEMO' PARAMETER
					# WHY? Per Blue Iris support...
					#     Prior to version 5.8.2.4, the alertlist 'memo' field was included only if it was not blank.
					#     Starting with version 5.8.3.4 it is now always included (REF: 12/18/2023 email from Ken)
						
					# For debugging
					#Write-Host ("$fn_name() BI version > 5.8.2.4 = " + (IsBiVersion '5.8.2.4'))
					#Write-Host ("$fn_name() data_obj.memo = " + ($data_obj.memo | ConvertTo-Json))
					
					$memo_fix_cntr = 0

					if (IsBiVersion '5.8.2.4') {
						$memos_ary = [String[]]$data_obj.memo
						#Write-Host ("$fn_name() memos_ary** = " + ($memos_ary | ConvertTo-Json))
					} else {
						# For debugging
						#Write-Host "$fn_name() Special handling of Alert memos" 
						
						try {
							# KEY POINT: This code line fails if ANY Alert in the JSON 'alertlist' response lacks a 'memo'
							$memos_ary = [String[]]$data_obj.memo  
						} 
						catch {
							# REPAIR THE 'BAD' ALERTS
							
							# For debugging
							Write-Warning "$fn_name() Found alerts w/ empty memos; preparing to change values to 'NA'..." 
							
							$i = 0
							foreach ($item in $data_obj) {
								try {
									$x = $item.memo
								}
								Catch {
									$data_obj[$i] | Add-Member -MemberType NoteProperty -Name "memo" -Value "NA"
									$memo_fix_cntr++
								}
								$i++
							}
							$memos_ary = [String[]]$data_obj.memo
							
							if ($data_obj['memos'].Count -ne $tmp_obj['paths'].Count) {
								$err_msg = "ERR/unable to fix missing 'memo':'value' pairs in the JSON 'alertlist' response"
								return $err_msg
							}
							
							if ($FromConsoleFlg -and !$SilentFlg) {
								Write-Warning "repaired $memo_fix_cntr Alerts in the JSON 'alertlist' response that lacked a 'memo' key; now 'memo':'NA'"
							}
						}
					}

					# For debugging
					if ($memo_fix_cntr -gt 0) {
						Write-Host ("$fn_name() memos_ary cnt AFTER repair = " + $memos_ary.Count)
						Write-Host ("$fn_name() memos_ary AFTER repair = " + ($memos_ary | ConvertTo-Json))
					}

					# For debugging
					#Write-Host ("$fn_name() memos_ary = " + ($memos_ary | ConvertTo-Json))

					# Initialize vars
					$this_loop_alerts_cnt = $paths_ary.Count
					$this_loop_dates_cnt = $dates_ary.Count
					
					# Shows $dates_ary endpoints
					if ($DevModeFlg -and  $FromConsoleFlg) {
						Write-Host ("(dev mode) fist date = dates_ary[0] = " + $dates_ary[0]) -ForegroundColor Cyan 
						Write-Host ("(dev mode) last date = dates_ary[" + ($this_loop_dates_cnt-1) + "] = " + $dates_ary[$this_loop_dates_cnt-1]) -ForegroundColor Cyan
					}

					# Break loop if this iteration is a single result with same oldest date
					# THIS IN AN EDGE CASE where item #2048 has 'date' X, and item #2049 also has 'date' X
					if ($this_loop_alerts_cnt -eq 1) {
						if ($dates_ary[$this_loop_dates_cnt-1] -eq $oldest_date) {
							
							if ($DevModeFlg) {
								if ($FromConsoleFlg) {
									Write-Host ("(dev mode) JSON alertlist this_loop_alerts_cnt = " + $this_loop_alerts_cnt) -ForegroundColor Cyan
									Write-Host ""
								}
							}
							break
						}
					}

					# Break loop if item's 'path' and 'date' parameter counts do not match
					# SOMETHING'S WRONG
					if ($this_loop_alerts_cnt -ne $this_loop_alerts_cnt) {
						if ($DevModeFlg -and $FromConsoleFlg) {
							Write-Host "(dev mode) terminating 'alertlist' call; response is unexpected ('path' & 'date' counts unequal)" -ForegroundColor Cyan
						}
						break
					}

					# Break loop if JSON 'alertlist' call returns the same number of alerts as the 
					# previous result (<2048 items)
					if ($this_loop_alerts_cnt -lt $json_alertlist_max -and ($this_loop_alerts_cnt -eq $prev_loop_alerts_cnt)) {
						if ($al_props_obj['paths'] -contains $paths_ary[0]) {
							if ($DevModeFlg -and $FromConsoleFlg) {
								Write-Host "(dev mode) ignoring JSON alertlist response w/ same alert count as previous response" -ForegroundColor Cyan
							}
							break
						}
					}
					
					$prev_loop_alerts_cnt = $this_loop_alerts_cnt
					
					if ($DevModeFlg -and $FromConsoleFlg) {
						Write-Host "(dev mode) JSON alertlist this_loop_alerts_cnt = $this_loop_alerts_cnt" -ForegroundColor Cyan
					}

					# For iterations > 1, remove the first alert in the response
					# THIS IN AN EDGE CASE where item #2048 has 'date' X, and item #2049 also has 'date' X
					if ($iter -gt 1) {
						
						if ($this_loop_alerts_cnt -ge 1 -and $this_loop_alerts_cnt -le $json_alertlist_max) {
							
							# REMOVE THE FIRST OBJECT ELEMENT 
							$data_obj = $data_obj[1 .. ($data_obj.Count - 1)]

							# SPECIAL HANDLING FOR THE 'MEMO' PARAMETER
							$memos_ary = $memos_ary[1 .. ($memos_ary.Count - 1)]
							
							# KEY POINT: 
							# Note that we do not update var $paths_ary at this point
							# Why? Because it is the while loop's break variable and we still have work to do
							
							# For debugging
							#Write-Host ("$fn_name() data_obj cnt AFTER = " + ($data_obj.Count))
						}
					}

					# For debugging
					#if ($iter -eq 2) {
						#$data_obj_keys += $($data_obj[0] | Get-Member -MemberType *Property).Name
						#Write-Host ("$fn_name() data_obj type = " + $data_obj.GetType())
						#Write-Host ("$fn_name() data_obj keys = " + ($data_obj_keys | ConvertTo-Json))
						#Write-Host ("$fn_name() data_obj = " + ($data_obj | ConvertTo-Json))
						#Write-Host ("$fn_name() data_obj.date type = " + ($data_obj.date).GetType())
					#}

					# Get all dates for this set of Alerts
					# ... This SHOULD BE an array of UTC timestamps, ordered largest to smallest
					# ... NOTE: this array is also used for QUALITY testing
					[Int[]]$dates_ary = $data_obj.date
					$dates_cnt = $dates_ary.Count

					# HANDLE SIMULATIONS
					if ($script:Sim5) {  #simulate response w/ zero-date (timestamp) values; arg value is CamName
						if ($Cameras -contains $script:Sim5) {
							# Set first date to zero
							#$dates_ary[0] = 0
							#$data_obj[0].date = 0

							# Set last date to zero
							#$dates_ary[$dates_cnt-1] = 0
							#$data_obj[$dates_cnt-1].date = 0
						
							# Set 2nd date to zero
							$dates_ary[1] = 0
							$data_obj[1].date = 0

							# Set 2nd to last date to zero
							$dates_ary[$dates_cnt-2] = 0						
							$data_obj[$dates_cnt-2].date = 0
						
							# For debugging
							Write-Host ("SIM5 fist date = dates_ary[0] = " + $dates_ary[0])
							Write-Host ("SIM5 last date = dates_ary[" + ($dates_cnt-1) + "] = " + $dates_ary[$dates_cnt-1])
						}
					}
					
					# Get the oldest/newest dates for this set of Alerts 
					# ... The oldest date is needed for the next JSON 'alertlist' call, if necessary
					$newest_date = $dates_ary[0]
					$oldest_date = $dates_ary[$dates_cnt-1]
					$max_date = ($dates_ary | Measure-Object -Maximum).Maximum
					$min_date = ($dates_ary | Measure-Object -Minimum).Minimum
					$dates_sum = ($dates_ary | Measure-Object -Sum).Sum
					
					# For debugging
					#Write-Host ("$fn_name() dates_ary type = " + $dates_ary.GetType())
					#Write-Host "$fn_name() dates_cnt = $dates_cnt"
					#Write-Host "$fn_name() dates_ary = $dates_ary"
					#Write-Host ("$fn_name() newest_date type = " + $newest_date.GetType())
					#Write-Host "$fn_name() newest_date = $newest_date"
					#Write-Host ("$fn_name() oldest_date type = " + $oldest_date.GetType())
					#Write-Host "$fn_name() oldest_date = $oldest_date"
					#Write-Host "$fn_name()dates_sum = $dates_sum"
					#Write-Host ("$fn_name() data_obj.date = " + ($data_obj.date | ConvertTo-Json))

					# Check for more QUALITY issues...
					# ... 1. Check if all dates are zero (FATAL)
					if ($dates_sum -eq 0 ) {
						$skipped_next_json_call_flg = $true
						if ($FromConsoleFlg -and !$SilentFlg) {
							Write-Warning "JSON 'alertlist' response for '$CamName' contains only zero 'date' entries (database corrupt?); find w/ -DevMode"
						}
						break
					}
					# ... 2. Check if the first array element is the max date (IT SHOULD BE)
					$first_date_is_not_max = ($newest_date -lt $max_date)
					# ... 3. Check that the first and last array elements are NOT zero (THEY SHOULD BE)
					$first_date_is_zero = ($newest_date -eq 0)
					$last_date_is_zero = ($oldest_date -eq 0)
					$zero_dates_cntr = 0  # Initialize counter
					# ... 4. Check if any OTHER alerts have dates with zero values
					#        Make hashtable like @("date1":count, "date2":count ...}
					#        if zero-dates are found, $ht will have and entry like {..., "0": 23, ...}
					# ... REF: https://stackoverflow.com/a/12640991
					$dates_ary | Group | % { $ht = @{} } { $ht[$_.Name] = $_.Count } { $ht } | Out-Null
					
					# For debugging
					#Write-Host ("ht = " + ($ht | ConvertTo-Json))
					#Write-Host ("ht['0'] = " + $ht['0'])
					
					if ($ht['0']) {
						$zero_dates_cntr += $ht['0']
						$dates_between_zero_cntr = $ht['0']
						
						# For debugging
						#Write-Host ("ht['0'] type = " + ($ht['0']).GetType())
						
					} else {
						$dates_between_zero_cntr = 0
					}
					if ($first_date_is_zero -and $dates_between_zero_cntr -gt 0) {
						$dates_between_zero_cntr--
					}
					if ($last_date_is_zero -and $dates_between_zero_cntr -gt 0) {
						$dates_between_zero_cntr--
					}
					if ($FromConsoleFlg -and !$SilentFlg) {
						if ($first_date_is_zero) {
							if ($last_date_is_zero) {
								Write-Warning "JSON 'alertlist' response #$iter for '$CamName' begins and ends with an Alert with zero-date values"
							} else {
								Write-Warning "JSON 'alertlist' response #$iter for '$CamName' begins with an Alert with a zero-date value"
							}
						} else {
							if ($first_date_is_not_max) {
								Write-Warning "JSON 'alertlist' response #$iter for '$CamName' does not have the newest date in the first entry (as expected)"
							}
							if ($last_date_is_zero) {
								Write-Warning "JSON 'alertlist' response #$iter for '$CamName' ends with an Alert with a zero-date value"
							}
						}
						if ($dates_between_zero_cntr -gt 0) {
							Write-Warning "JSON 'alertlist' response #$iter for '$CamName' has $zero_dates_cntr zero-date values; find w/ -DevMode"
						}
					}
					
					# For debugging
					#Write-Host ("$fn_name() newest_date type = " + $newest_date.GetType())
					#Write-Host "$fn_name() newest_date = $newest_date"
					#Write-Host ("$fn_name() newest_date for iter #" + $iter + " ($this_loop_alerts_cnt alerts) = " + $newest_date)
					#Write-Host ("$fn_name() oldest_date type = " + $oldest_date.GetType())
					#Write-Host "$fn_name() oldest_date = $oldest_date"

					# Load collectors
					$tmp_obj['cameras']   = $data_obj.camera  # an array (adds a column of values to the hashtable object)
					$tmp_obj['paths']     = $data_obj.path
					$tmp_obj['clips']     = $data_obj.clip
					$tmp_obj['files']     = $data_obj.file
					#$tmp_obj['memos']     = $data_obj.memo   # We handle '$data_obj.memo' differently 
					$tmp_obj['memos']     = $memos_ary
					$tmp_obj['offsets']   = $data_obj.offset
					$tmp_obj['flagss']    = $data_obj.flags
					$tmp_obj['ress']      = $data_obj.res
					$tmp_obj['zoness']    = $data_obj.zones
					$tmp_obj['dates']     = $data_obj.date	# Note: $date_ary[] is reverse-ordered.
					$tmp_obj['colors']    = $data_obj.color
					$tmp_obj['filesizes'] = $data_obj.filesize

					# For debugging
					#Write-Host ("$fn_name() tmp_obj['memos'] = " + ($tmp_obj['memos'] | ConvertTo-Json))
	
					# HANDLE SIMULATIONS
					if ($script:Sim1) {  # remove ALL 'memo':'value' pairs from raw JSON 'alertlist' response
						foreach ($item in $data_obj) {
							$item.PSObject.Properties.Remove('memo')
						}
						if ($FromConsoleFlg) {
							Write-Host "(test mode) Simulation #1: removed ALL 'memo':'value' pairs from JSON 'alertlist' response" -Foregroundcolor Green
							#Write-Host ("(test mode) Simulation #1: data_obj AFTER = " + ($data_obj | ConvertTo-Json)) -Foregroundcolor Green
						}
					}
					if ($script:Sim2) {  # remove 'memo':'value' pairs for 3 random alerts from JSON 'alertlist' response
						try {
							$tmp_obj['memos'] = [Array]$data_obj.memo
							$total_cnt = $tmp_obj['paths'].Count
							$chgd_memos_cnt = [Math]::min(3,$alerts_cnt-1)
							$chgd_idxs_ary = @()
							$chgd_alerts_obj = @()
							$i = 0
							while ($i -lt $chgd_memos_cnt) {
								$idx = Get-Random -Maximum $total_cnt
								# Only protected alerts
								#Write-Host ("flags = " + ($data_obj[$idx]).flags)
								$flags_ary = `
									MakeBitArray `
									-DecVal ($data_obj[$idx]).flags `
									-NoBits 32
								# Flags: 2^0=flagged, 2^1=protected, 2^6=archive, 2^9=export, 2^28 confirmed
								if ($flags_ary[2] -eq 1) {
									if (!($chgd_idxs_ary -contains $idx)) {
										$data_obj[$idx].PSObject.Properties.Remove('memo')
										$chgd_alerts_obj += $data_obj[$idx]
										$chgd_idxs_ary += $idx
										$i++
									}
								}
							}
							if ($FromConsoleFlg) {
								Write-Host "(test mode) Simulation #2: removed JSON alertlist 'memo' entry from $chgd_memos_cnt random protected Alerts" -Foregroundcolor Green
								Write-Host ("(test mode) Simulation #2: changed alertlist entries = " + ($chgd_alerts_obj | ConvertTo-Json)) -Foregroundcolor Green
							}
						} catch {
							if ($FromConsoleFlg) {
								Write-Host "(test mode) Simulation #2: unable to run simulation; no Alerts have a 'memo':'value' pair"
							}
						}
					}
					if ($script:Sim3) {  # simulate response w/ all 'memo'='NA' params
						$tmp_obj['memos'] = 1..$tmp_obj['paths'].Count | % { 'NA' }
						if ($FromConsoleFlg) {
							Write-Host "(test mode) Simulation #3: set 'memo'='NA' for all Alerts in $fn_name() response" -Foregroundcolor Green
							Write-Host ("(test mode) Simulation #3: tmp_obj['memos'] modified = " + ($tmp_obj['memos'] | ConvertTo-Json)) -Foregroundcolor Green
						}
					}
					if ($script:Sim4) {  # simulate response w/ 3 random 'memo'='NA' params
						$memos_cnt = $tmp_obj['memos'].Count
						if ($memos_cnt -gt 0) {
							#Write-Host "memos_cnt = $memos_cnt"
							$memos_cnt = $memos_cnt
							$chgd_memos_cnt = [Math]::min(3,$memos_cnt-1)
							$chgd_idxs_ary = @()
							$chgd_alerts_ary = @()
							$i = 0
							while ($i -lt $chgd_memos_cnt) {
								$idx = Get-Random -Maximum $memos_cnt
								#Write-Host "idx = $idx"
								# Only protected alerts
								#Write-Host ("flags = " + ($data_obj[$idx]).flags)
								$flags_ary = `
									MakeBitArray `
									-DecVal ($data_obj[$idx]).flags `
									-NoBits 32

								# Flags: 2^0=flagged, 2^1=protected, 2^6=archive, 2^9=export, 2^28 confirmed
								if ($flags_ary[2] -eq 1) {
									if (!($chgd_idxs_ary -contains $idx)) {
										if ($tmp_obj['memos'][$idx] -ne 'NA') {
											$tmp_obj['memos'][$idx] = 'NA'
											$chgd_alerts_ary += (($data_obj[$idx]).file).Replace('.jpg','')
											$chgd_idxs_ary += $idx
											$i++
										}
									}
								}
							}
							if ($FromConsoleFlg) {
								Write-Host "(test mode) Simulation #4: set 'memo'='NA' for $chgd_memos_cnt random Alerts in $fn_name() response" -Foregroundcolor Green
								#Write-Host ("(test mode) Simulation #4: tmp_obj['memos'] modified = " + ($tmp_obj['memos'] | ConvertTo-Json)) -Foregroundcolor Green
								Write-Host ("(test mode) Simulation #4: modified AlertIDs = " + ($chgd_alerts_ary | ConvertTo-Json)) -Foregroundcolor Green
							}
						}
					}

					# For debugging
					
					#Write-Host ("$fn_name() tmp_obj['paths'] cnt = " + $tmp_obj['paths'].Count)
					#Write-Host ("$fn_name() tmp_obj['paths'] = " + ($tmp_obj['paths'] | ConvertTo-Json))
					#Write-Host ("$fn_name() tmp_obj['flagss'] cnt = " + $tmp_obj['flagss'].Count)
					#Write-Host ("$fn_name() tmp_obj['flagss'] = " + ($tmp_obj['flagss'] | ConvertTo-Json))
					#Write-Host ("$fn_name() tmp_obj['memos'] dnt = " + $tmp_obj['memos'].Count)
					#Write-Host ("$fn_name() tmp_obj['memos'] = " + ($tmp_obj['memos'] | ConvertTo-Json))

					# Merge results with the master accumulator
					$al_props_obj['cameras'] = $al_props_obj['cameras'] + $tmp_obj['cameras']
					$al_props_obj['paths']   = $al_props_obj['paths']   + $tmp_obj['paths']
					$al_props_obj['clips']   = $al_props_obj['clips']   + $tmp_obj['clips']
					$al_props_obj['files']   = $al_props_obj['files']   + $tmp_obj['files']
					$al_props_obj['memos']   = $al_props_obj['memos']   + $tmp_obj['memos']
					$al_props_obj['offsets'] = $al_props_obj['offsets'] + $tmp_obj['offsets']	
					$al_props_obj['flagss']  = $al_props_obj['flagss']  + $tmp_obj['flagss']	
					$al_props_obj['ress']    = $al_props_obj['ress']    + $tmp_obj['ress']	
					$al_props_obj['zoness']  = $al_props_obj['zoness']  + $tmp_obj['zoness']	
					$al_props_obj['dates']   = $al_props_obj['dates']   + $tmp_obj['dates']	
					$al_props_obj['colors']  = $al_props_obj['colors']  + $tmp_obj['colors']	
					$al_props_obj['filesizes']   = $al_props_obj['filesizes']   + $tmp_obj['filesizes']	
					
					# Stop requesting data if the last date is zero
					if ($oldest_date -eq 0) {
						$skipped_next_json_call_flg = $true
						if ($FromConsoleFlg -and !$SilentFlg) {
							Write-Warning "skipping next JSON 'alertlist' call because this call's oldest date is zero"
						}
						break
					}
				
				} else {
					break
				}
			} else {
				break
			}
		} else {
			break
		}

		# Avoid infinite loop
		if ($iter -gt $max_tries) {
			break
		}
		
		$iter++
	}
	
	# For debugging
	#Write-Host "Broke out of While loop"

	# TEST FOR MORE QUALITY ISSUES (indicators of a possibly corrupt database)
	# ... Test if 'clip' values contain '@-1.jpg' entries (WARNING)
	[String[]]$clips_ary = $al_props_obj['clips']
	if ($clips_ary -contains '@-1.jpg') {
		$clips_cnt = $clips_ary.Count
		$bad_clip_cntr = 0
		foreach($item in $clips_ary) {
			if ($item -eq '@-1.jpg') {
				$bad_clip_cntr++
			}
		}
		if ($FromConsoleFlg -and !$SilentFlg) {
			Write-Warning "JSON 'alertlist' response for '$CamName' has $bad_clip_cntr/$clips_cnt 'clip'='@-1.jpg' entries; find w/ -DevMode"
		}
	}

	# For debugging
	#Write-Host ("$fn_name() al_props_obj type = " + ($al_props_obj.GetType()))
	#Write-Host ("$fn_name() al_props_obj keys = " + $al_props_obj.Keys)
	#Write-Host ("$fn_name() al_props_obj = " + ($al_props_obj | ConvertTo-Json))
	#Write-Host ("$fn_name() al_props_obj['cameras'] = " + ($al_props_obj['cameras'] | ConvertTo-Json))
	#Write-Host ("$fn_name() al_props_obj['memos'] = " + ($al_props_obj['memos'] | ConvertTo-Json))
	#Write-Host ("$fn_name() al_props_obj['flagss'] = " + ($al_props_obj['flagss'] | ConvertTo-Json))
	#Write-Host ("$fn_name() al_props_obj.paths = " + $al_props_obj.paths)
	
	# DEV MODE - Save each camera's 'alertlist' data
	if ($DevModeFlg) {
		if (!$script:Sim1 -and !$script:Sim2 -and !$script:Sim3 -and !$script:Sim4) {
			
			$al_objects_ary = @()  # Initialize accumulator; an array of hashtables
			$keys = [Array]$al_props_obj.Keys
			$all_alerts_cnt = $al_props_obj['paths'].Count
			$alertlist_filespec = "$DevModePath\alertlist.$CamName.json"
			
			# For debugging
			#Write-Host ("$fn_name() keys = " + ($keys | ConvertTo-Json))
			#Write-Host "$fn_name() all_alerts_cnt = $all_alerts_cnt"
			#Write-Host "$fn_name() alertlist_filespec = '$alertlist_filespec'"
			
			if ($all_alerts_cnt -gt 0) {

				# Possible keys in $al_props_obj
				$keys1 = @('cameras','memos','paths','clips','files','filesizes','dates','offsets')
				$keys2 = @('flagss','zoness')

				for ($i=0; $i -lt $all_alerts_cnt; $i++) {
					$ht = @{}  # Initialize hashtable
					# Modify $al_props_obj key for use in hashtable 
					
					#Write-Host ""
					
					foreach ($key in $keys) {
						if ($keys1 -contains $key) {
							$key_new = $key.TrimEnd('s')
						} else {  # $keys_2 -contains $key
							$key_new = $key.Replace('ss','s')
						}
						
						# For debugging
						#Write-Host "key = $key"
						#Write-Host ("al_props_obj[$key] type = " + ($al_props_obj[$key]).GetType())
						#Write-Host ("al_props_obj[$key] = " + ($al_props_obj[$key] | ConvertTo-Json))
						#Write-Host ("al_props_obj[$key][0] = " + $al_props_obj[$key][0])
						#Write-Host ("al_props_obj[$key][" + ($all_alerts_cnt-1) + "] = " + $al_props_obj[$key][$all_alerts_cnt-1])
						#Write-Host ("al_props_obj[$key][$i] = " + $al_props_obj[$key][$i])
						
						$ht.Add($key_new, $al_props_obj[$key][$i])	
						#exit

						
					}
					$al_objects_ary += $ht
				}

				# For debugging
				#Write-Host ("al_list_ary = " + ($al_list_ary | ConvertTo-Json))

				$alertlist_saved_flg = $false
				if (!$Cameras -and !$Pattern) {
					$al_objects_ary | ConvertTo-Json | Out-File -FilePath "$alertlist_filespec"
					$alertlist_saved_flg = $true
				} else {
					if ($Cameras) {
						$match_str = ($Cameras -Join '|')
						if ($match_str -match $CamName) {
							$al_objects_ary | ConvertTo-Json | Out-File -FilePath "$alertlist_filespec"	
							$alertlist_saved_flg = $true
						}
					}				
					if ($Pattern) {
						if ($Pattern -match $CamName) {
							$al_objects_ary | ConvertTo-Json | Out-File -FilePath "$alertlist_filespec"	
							$alertlist_saved_flg = $true
						}
					}				
				}
				if ($alertlist_saved_flg) {		
					if ($FromConsoleFlg) {
						Write-Host "(dev mode) 'alertlist' response saved to disk ($all_alerts_cnt items) --> '$alertlist_filespec'" -ForegroundColor Cyan
						#Write-Host ""
					}
				}
				
				# Top open this *.json file in Excel...
				# 1. Data > Get Data > From File > From JSON
				# 2. Navigate to *json file
				# 3. Click 'Import' 
				# 4. Click 'To Table'
				# 5. Click 'OK'
				# 6. Click icon by 'Column1'
				# 7. Click 'OK'
				# 8. Click 'Close & Load'
				
			}  else {
				if ($FromConsoleFlg -and !$SilentFlg) {
					Write-Warning "no alerts; unable to save alertlist to disk ($alertlist_filespec)"
				}
			}
		} else {
			if ($FromConsoleFlg) {
				Write-Host "(dev mode) HEADS-UP: cam 'alertlist' *NOT* saved to disk when using arguments -SimX" -ForegroundColor Cyan
			}
		}
	}

	# Get all alerts files, paths
	$all_alerts_paths = $al_props_obj.paths
	$all_alerts_files = $al_props_obj.files
	$all_alerts_cnt = $all_alerts_paths.Count
	
	$all_alerts_zones = $al_props_obj.zoness

	# For debugging
	#Write-Host ("$fn_name() AlertPath = " + $AlertPath)
	#Write-Host ("$fn_name() all_alerts_paths cnt = " + $all_alerts_paths.Count)
	#Write-Host ("$fn_name() all_alerts_paths = " + ($all_alerts_paths | ConvertTo-Json))
	#Write-Host ("$fn_name() all_alerts_files = " + ($all_alerts_files | ConvertTo-Json))
	#Write-Host ("$fn_name() all_alerts_zones type = " + $all_alerts_zones.GetType())
	#Write-Host ("$fn_name() all_alerts_zones cnt = " + $all_alerts_zones.Count)
	#Write-Host ("$fn_name() all_alerts_zones = " + ($all_alerts_zones | ConvertTo-Json))
	#Write-Host "$fn_name() Found $all_alerts_cnt total items`n"

	# Initialize collectors
	$rtn_obj = [ordered]@{}
	$new_obj = [ordered]@{}
	if ($AlertProps.Count -gt 0) {
		foreach ($alert_prop in $AlertProps) {
			$new_obj.Add($alert_prop, @())
		}
	} else {
		foreach ($al_props_key in $al_props_obj_keys) {
			$new_obj.Add($al_props_key, @())
		}
	}
	
	# For debugging
	#Write-Host ("$fn_name() new_obj = " + ($new_obj | ConvertTo-Json))

	# WALK THROUGH ALERTS LIST
	for ($i=0; $i -lt $all_alerts_cnt; $i++) { 
	
		# For debugging
		#Write-Host "`nalert idx = $i..."
			
		if ($AlertPath -ne "*") {
			if (!($all_alerts_paths[$i] -match $AlertPath)) {
				Continue
			} else {
				# For debugging
				#Write-Host "Found match for AlertPath ($AlertPath)"
			}
		}
		
		if ($Pattern.Length -gt 0) {
			if (!($all_alerts_files[$i] -match $Pattern)) {
				Continue
			} else {
				# For debugging
				#Write-Host ("Pattern '$Pattern' is a match for '" + $all_alerts_files[$i] + "'")
			}
		}

		if ($AlertProps.Count -gt 0) {
			
			# GET REQUESTED PROPERTIES

			foreach ($alert_prop in $AlertProps) {

				$key = $alert_prop + "s"  # $al_props_obj's keys are plural
				
				[Array]$arr = $al_props_obj.$key
				
				# For debugging
				#if ($key -eq 'memos') {
					#Write-Host ("$fn_name() arr[$key] = " + ($arr | ConvertTo-Json))
				#}
				
				if (!($null -eq $arr)) {  # KEY POINT: $arr can be a single element array @(0)
					
					$val = $arr[$i]
					
					# For debugging
					#if ($arr[$i] -eq '') {
						#Write-Host ($key + " = '" + $arr[$i] + "'")
					#}

					# Append value to collector
					if ($arr[$i] -or $arr[$i] -eq 0) {
						$new_obj.$alert_prop += $arr[$i]				
					} else {
						$new_obj.$alert_prop += ''
					}
					
					# For debugging
					#if ($arr[$i] -eq '') {
						#Write-Host ("new_obj.$alert_prop = " + ($new_obj.$alert_prop | ConvertTo-Json))
					#}

					# For debugging
					#Write-Host ("arr = " + $arr)
					#Write-Host ("item #" + ($i+1) + " $alert_prop = " + $arr[$i])

				} else {
					if ($i -eq 0) {
						if ($FromConsoleFlg) {
							Write-Host ("WARNING/nonexistent AlertProp '$alert_prop', expecting: [" + ($AlertProps -Join ',') + "]")
						}
					}
				}
			}
			
		} else {
			
			# GET ALL PROPERTIES
			
			# Get all property names
			if ($i -lt 2) {
				
				# NOTE: $al_props_obj's keys are plural
				$al_props_obj_keys = $al_props_obj.Keys

				# For debugging
				#Write-Host ("al_props_obj_keys = " + $al_props_obj_keys)
				
			}
			
			foreach ($al_props_key in $al_props_obj_keys) {

				# For debugging
				#Write-host ("new_obj.$al_props_key type = " + ($new_obj.$al_props_key).GetType())

				# Get all values for the property (an array)
				$vals = $al_props_obj.$al_props_key

				# Remove the terminal 's' from $al_props_key
				$new_obj_key = $al_props_key.Substring(0,$al_props_key.Length-1) 
				
				if ($vals) {
					$new_obj.$new_obj_key += $vals[$i]					
				} else {
					#$new_obj.$new_obj_key += $null
					$new_obj.$new_obj_key += ''
				}
				
				#For debugging
				#Write-Host ("item #" + ($i+1) + " $new_obj_key = " + $vals[$i])
			}
		}
			
		# For debugging
		#Write-host ("new_obj = " + ($new_obj | ConvertTo-Json))
	}
	
	$rtn_obj[$CamName] = $new_obj

	# For debugging
	#Write-Host ("rtn_obj cnt = " + $rtn_obj.count)
	#Write-Host "rtn_obj keys = "$rtn_obj.Keys
	#Write-Host ("rtn_obj keys = " + ($rtn_obj | ConvertTo-Json))
	#Write-Host ("rtn_obj = " + ($rtn_obj | ConvertTo-Json))s
	#Write-Host ("rtn_obj.FE = " + ($rtn_obj.FE | ConvertTo-Json))
	#Write-Host ("rtn_obj.DW1.BPS = '" + $rtn_obj.DW1.BPS + "'")
	#Write-Host ("rtn_obj.GT.path = '" + $rtn_obj.GT.path + "'")
	#Write-Host ("rtn_obj.GT.memo = '" + $rtn_obj.GT.memo + "'")
	#Write-Host ("rtn_obj.GT.flags = '" + $rtn_obj.GT.flags + "'")

	return $rtn_obj
}

function BIJsonGetAlertList() {
# PURPOSE:    To get properties from the Blue Iris JSON interface cmd 'alertlist'
# USAGE:      {this_script_name}.ps1 prop cam(s) prop(s)
# PARAMS:     -Cameras        = (string) filter results for Alerts with specified camera shortnames(comma-delimited),  
#                                        like 'DW1','DW2,'FD'
#             -Patterns       = (string) filter results for Alerts with specified descriptor substrings
#             -MemoTag        = (string) filter results for Alerts with specified memo substrings
#             -AlertProps     = (string) return only these JSON 'alertlist' cmd params (comma-delimited )
#                                        like 'enabled,profile,motion'
#             -FromConsoleFlg = (boolean) $true notifies function that calling command was executed from the console
#             -QuietFlg       = (boolean) true suppresses verbose informational output to the console
#             -DevModeFlg     = (boolean) true performs devmode actions
#             -DevModePath    = (string) destination path for devmode actions
# RETURNS:    (hashtable) @{ Cam1: @{ prop1:[values], ... , propN:[values] }, Cam2: @{ prop1:[values], ... , propN:[values] }, ... }
# REQUIRES:   Function: 'BIJsonAlertListParse()'
#
# Created by jaydeel at ipcamtalk.com
# Version: 4 (2024-02-18)
#

	param(
		[String[]]$Cameras,
		[String[]]$Patterns,
		[String[]]$AlertProps,
		[String]$MemoTag,
		[Boolean]$FromConsoleFlg,
		[Boolean]$QuietFlg,
		[Boolean]$DevModeFlg,
		[String]$DevModePath
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	#Write-Host "Entered function $fn_name() ..."
	#Write-Host "$fn_name() RecordID = $RecordID"
	#Write-Host "$fn_name() Cameras = $Cameras"
	#Write-Host "$fn_name() Patterns = $Patterns"
	#Write-Host ("$fn_name() AlertProps = " + ($AlertProps | ConvertTo-Json))
	#Write-Host "$fn_name() MemoTag = $MemoTag"
	#Write-Host "$fn_name() FromConsoleFlg = $FromConsoleFlg"
	#Write-Host "$fn_name() DevModeFlg = $DevModeFlg"
	#Write-Host "$fn_name() DevModePath = $DevModePath"
	#Write-Host "$fn_name() Sim1 = $script:Sim1"
	#Write-Host "$fn_name() Sim3 = $script:Sim3"

	# HANDLE ARGS
	if ($Cameras) {
		$my_cams_ary = $Cameras -Split ','
	} else {
		$my_cams_ary = @()
	}
	$my_cams_cnt = $my_cams_ary.Count

	if ($Patterns) {
		$my_patterns_ary = $Patterns -Split ','
	} else {
		$my_patterns_ary = @('')
	}
	$my_patterns_cnt = $my_patterns_ary.Count

	if ($AlertProps.Count -eq 0) {
		$my_props_ary = @('camera', 'path', 'clip', 'file', 'memo', 'offset', 'flags', 'res', 'zones', 'date', 'color', 'filesize')
	} else {
		$my_props_ary = $AlertProps -Split ','
	}
	$my_props_cnt = $my_props_ary.Count

	# For debugging
	#Write-Host ("$fn_name() my_cams_ary type = " + $my_cams_ary.GetType())
	#Write-Host ("$fn_name() my_cams_ary = " + $my_cams_ary)
	#Write-Host ("$fn_name() my_cams_ary cnt = " + $my_cams_ary.Count)
	#Write-Host "my_patterns_ary = $my_patterns_ary"
	#Write-Host "my_flags_ary = $my_flags_ary"
	#Write-Host ("$fn_name() my_props_ary cnt = " + $my_props_ary.Count)
	#Write-Host ("$fn_name() my_props_ary = " + ($my_props_ary | ConvertTo-Json))

	# INITIALIZE
	$rtn_obj = @{}
	$progress_bar_cntr = 0
	#$cntr = 1
	$patterns_found_ary = @()
	$i = 0
	foreach ($my_cam in $my_cams_ary) {

		# For debugging
		#Write-Host ("$fn_name() " + $my_cam + ":")
		
		# Show progress bar
		if ($FromConsoleFlg) {
			$progress_bar_cntr++
			$WriteProgressParams = @{
				Activity         = "Parsing alertlist data..."
				Status           = "Progress:  cam '$my_cam' ($progress_bar_cntr of requested $my_cams_cnt cams)"
				PercentComplete  = (($progress_bar_cntr / $my_cams_cnt) * 100)
			}
			# Note: If loop is too fast, you might need a delay to get the progress bar to update
			#Start-Sleep -Milliseconds 150				
			Write-Progress @WriteProgressParams
		}
		
		$pattern_cntr = 0
		foreach ($pattern in $my_patterns_ary) {
			
			# For debugging
			#Write-Host "`n----- processing pattern '$pattern' -----"
			
			# Skip pattern search if already found
			if ($patterns_found_ary -contains $pattern) {
				continue
			}

			# GET JSON DATA FROM THE BLUE IRIS WEB SERVER
			# ... returns an ordered hashtable
			$response_obj = `
				BIJsonAlertListParse `
				-CamName $my_cam `
				-Pattern $pattern `
				-AlertProps $my_props_ary `
				-MemoTag $MemoTag `
				-FromConsoleFlg $FromConsoleFlg `
				-QuietFlg $QuietFlg `
				-SilentFlg ($pattern_cntr -gt 0) `
				-DevModeFlg $DevModeFlg `
				-DevModePath $DevModePath

			# For debugging
			#Write-Host ("$fn_name() response_obj type = " + $response_obj.GetType())
			#Write-Host ("$fn_name() response_obj = " + ($response_obj | ConvertTo-Json))
			
			if ($response_obj.GetType() -match 'string') {
				if ($response_obj.StartsWith('ERR/')) {
					return $response_obj
				} else {
					$err_msg = "ERR/unexpected response from AlertListParse(); $response_obj"
					return $err_msg
				}
			}

			# $response_obj is an ordered hashtable, like
			# @{
			# 	DW1: @{
			#		"file": [
			#           filename1,
			#           ...,
			#           filenameN,
			#       ],
			#       "flags": [
			#           int1,
			#           ...,
			#           int2,
			#       ],
			#       "memo": [
			#           string1,
			#           ...,
			#           stringN,
			#       ],
			#	}
			# }

			# INITIALIZE
			$x = ''

			# EXTRACT PROPERTY VALUE(S)
			# ... Note: null/blank $response_obj.ram observed on occasion
			if ($response_obj) {	

				$response_obj_keys = $response_obj.Keys

				# For debugging
				#Write-Host ("$fn_name() response_obj type = " + $response_obj.GetType())
				#Write-Host ("$fn_name() response_obj cnt = " + $response_obj.Count)
				#Write-Host ("$fn_name() response_obj keys = " + $response_obj_keys)
				#Write-Host ("$fn_name() response_obj = " + ($response_obj | ConvertTo-Json))

				if ($response_obj_keys -contains $my_cam) {
					
					$cam = $my_cam
					$item_obj = $response_obj[$cam]
					$item_obj_keys = $item_obj.Keys

					# $item_obj (and $new_obj below) are System.Collections.Specialized.OrderedDictionary 
					# that should look like...
					<# 
					  "camera": ["DW1"],
					  "path": ["@224803430.bvr"],
					  "clip": ["@224669140.bvr"],
					  "file": ["DW1.20240128_020000.3152644.5-0.jpg"],
					  "memo": ["LD/C;vehicle:93%"],
					  "offset": ["3157680"],
					  "flags": [402980864],
					  "res": ["2688x1520"],
					  "zones": [65],
					  "date": [1705777428],
					  "color": [16711808],
					  "filesize": ["22 sec (523K)"]
					}
					#>					

					# For debugging
					#Write-Host ("$fn_name() item_obj type = " + $item_obj.GetType())
					#Write-Host ("$fn_name() item_obj = " + ($item_obj | ConvertTo-Json))
					#Write-Host ("$fn_name() item_obj_keys = " + ($item_obj_keys | ConvertTo-Json))
					#Write-Host ("$fn_name() item_obj = " + ($item_obj | ConvertTo-Json))
					#rite-Host ("$fn_name() item_obj[0] type = " +  ($item_obj[$item_obj_keys[0]]).GetType())
					#Write-Host ("$fn_name() item_obj[0] = " +  $item_obj[$item_obj_keys[0]])
					
					# Test for empty result
					if (!$item_obj[$item_obj_keys[0]]) {  # looking for $item_obj['camera'] = @()
						continue
					} else {
						if ($patterns_ary.Count -gt 1) {
							$patterns_found_ary += $pattern
						}
					}

					$new_obj = [ordered]@{}	
					
					if ($my_props_ary.Length -gt 0) {
						$props_ary = $my_props_ary   # RETURN REQUESTED PROPERTIES
					} else {
						$props_ary = $item_obj_keys  # RETURN ALL PROPERTIES			
					}

					# RETURN PROPERTIES

					foreach ($cam_prop in $props_ary) {
						
						$item_obj_ary = $item_obj.$cam_prop  # expect $item_obj.path = @(value)

						# For debugging
						#Write-Host "$fn_name() Processing property '$cam_prop' ..."
						#Write-Host ("$fn_name() item_obj.$cam_prop type = " + ($item_obj.$cam_prop).GetType())
						#Write-Host ("$fn_name() item_obj.$cam_prop ary = " + ($item_obj_ary | ConvertTo-Json))
						#Write-Host ("$fn_name() cam_prop = $cam_prop, val = '" + $item_obj_ary[0] + "'")
						
						# KEY POINT: $null must put on the left side of operator!!
						# REF: https://stackoverflow.com/a/49411823
						if ($null -eq $item_obj_ary) {
							$new_obj.Add($cam_prop, @('NA'))
							$x = 'NA'  # For single camera, single property requests								
						} else {
							if ($null -eq $item_obj_ary[0]) {
								$new_obj.Add($cam_prop, @('NA'))
								$x = 'NA'  # for single camera, single property requests
							} else {
								$new_obj.Add($cam_prop, $item_obj_ary)
								$x = $item_obj_ary[0]  # for single camera, single property requests
							}
						}
						
						# For debugging
						#Write-Host ("$fn_name() " + $cam_prop + " = '"  + $x + "'")	
					}
					
					# For debugging
					#Write-Host ("$fn_name() new_obj = " + $new_obj)
					#Write-Host ("$fn_name() new_obj = " + ($new_obj | ConvertTo-Json))

					if ($my_patterns_cnt -lt 2) {
						$rtn_obj[$cam] = $new_obj
					} else {
						# Handling multiple -Patterns is a bit more complex
						foreach ($item_obj_key in $item_obj_keys) {
							if ($pattern_cntr -eq 0) {
								# First time...
								if (!$rtn_obj[$cam]) {
									# Initialize the $rtn_obj's $cam keys 
									$rtn_obj.Add($cam, @{})
								}
								# Add & initialize the $rtn_obj[$cam]'s key's prop-value pairs
								$rtn_obj[$cam].Add($item_obj_key, @{})
								$rtn_obj[$cam][$item_obj_key] = @()
							}
							$rtn_obj[$cam][$item_obj_key] += $new_obj[$item_obj_key]
						}
					}

				} else {
					if ($FromConsoleFlg) {
						$err_msg = "ERR/nonexistent camera"
						return $err_msg
					}
					
					$rtn_obj[$cam] = 'NA'
				}
				
			} else {
				if ($FromConsoleFlg) {
					Write-Warning "JSON query returned null/blank`n"
				}
			}

			# Handle single camera, single property request
			if ($rtn_obj -ne 'NA') {
				if ($my_cams_ary.Length -eq 1 -and $my_props_ary.Length -eq 1) {
					$rtn_obj = $x
				}
			}
			
			$pattern_cntr++
		}
		$i++
	}

	# LOG OUT OF API SESSION
	$jsonCmd = @{cmd = 'logout'}
	$json_response_obj = `
		BIJsonCall `
		-JsonCmd $jsonCmd
		
	if ($FromConsoleFlg) {
		if ($json_response_obj.result -eq 'fail') {
			Write-Warning "BI API: log out fail; connection not terminated"
		} else {
			if (!$QuietFlg) {
				#Write-Host "BI API: log out successful; connection terminated"	
			}
		}
	}
	
	# For debugging
	#Write-Host ("$fn_name() rtn_obj = " + ($rtn_obj | ConvertTo-Json))

	return $rtn_obj
}

function GetDatFilesRecursive() {
# PURPOSE:   To get file info for all (or specified) Blue Iris *.dat files
# PARAMS:    see 'param' command below
# RETURNS:   (arrays) file_names_ary, file_subdirs_ary, file_sizes_ary (bytes), $file_timestamps_ary (UNIX)
# REF:       https://stackoverflow.com/questions/40220590/return-multidimensional-array-from-function

	param(
		[array]$Path,      # [REQUIRED] Blue Iris Alerts folder @('D:\BlueIris\Alerts)
		[array]$Patterns,  # filter *.DAT files with specified name patterns (substrings)
		[array]$AgeHours   # filter *.DAT files older than specified hours
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	#Write-Host "$fn_name() Path = $Path"
	#Write-Host ("$fn_name() Patterns type = " + $Patterns.GetType())
	#Write-Host ("$fn_name() Patterns cnt = " + $Patterns.Count)
	#Write-Host "$fn_name() Patterns = '$Patterns'"
	#Write-Host "$fn_name() AgeHours = $AgeHours"
	
	if ($Path -eq "") {
		return
	}	
	$root_path = $Path.TrimEnd('\')
	
	# Initialize collectors to be returned (lists)
	$filespecs_list = New-Object System.Collections.Generic.List[System.Object]
	#$names_list     = New-Object System.Collections.Generic.List[System.Object]
	#$subdirs_list   = New-Object System.Collections.Generic.List[System.Object]
	#$sizes_list     = New-Object System.Collections.Generic.List[System.Object]
	#$tstamps_list   = New-Object System.Collections.Generic.List[System.Object]
 
	# GET FILTERED FILES
	# ... NOTE #1: the '-Include' argument requires an array
	#     	REF: https://stackoverflow.com/a/25331423/13499984
	# ... NOTE #2: Considerations with returned object when using CmdLet 'Get-ChildItem'
	#     	REF: https://stackoverflow.com/questions/55765010/return-array-of-objects-from-get-childitem-path
	# ... NOTE #3: We are attempting to order files as shown by Windows Explorer (Natural order sort)
	# ... 	REF: https://stackoverflow.com/a/5429048/13499984

	# Get all DAT files matching $Pattern in specified folder
	$DatFilesObj = (Get-ChildItem -Path "$root_path\*.dat" -Recurse -Include $Patterns)

	# For debugging
	#Write-Host ("$fn_name() DatFilesObj cnt = " + $DatFilesObj.Count)

	if ($AgeHours) {
		
		# Parse -AgeHours parameter
		$hours = $AgeHours -Split ','
		$is_range = ($hours.Count -gt 1)
		
		# Initialize collectors
		$ages_ary = @()
		$files_obj = @()

		# Get ages of all found DAT files
		for ($i=0; $i -lt $DatFilesObj.Count; $i++) {
			$filespec = $DatFilesObj[$i]
			$file_dt = (Get-Item -LiteralPath "$filespec").LastWriteTime
			#$diff = (Get-Date) - $file_dt
			$diff = (Get-Date).Subtract($file_dt)
			$ages_ary += [math]::Floor($diff.TotalHours)
		}

		# For debugging
		#Write-Host "$fn_name() ages_ary = $ages_ary"

		for ($i=0; $i -lt $DatFilesObj.Count; $i++) {
			if ($is_range) {
				if ($ages_ary[$i] -ge [int]$hours[0] -and $ages_ary[$i] -le [int]$hours[1]) {
					$files_obj += $DatFilesObj[$i]
				}
			} else {
				if ($ages_ary[$i] -ge [int]$hours[0]) {
					$files_obj += $DatFilesObj[$i]
				}
			}
		}
		
		$DatFilesObj = $files_obj
		
	}

	# Natural order sort (see NOTE #3 above)
	<# $ToNatural = { [regex]::Replace($_, '\d+', { $args[0].Value.PadLeft(20) }) }
	if ($SortAsc) {
		$DatFilesObj = $DatFilesObj | Sort-Object $ToNatural
	} else {
		$DatFilesObj = $DatFilesObj | Sort-Object $ToNatural | Sort -Descending
	} #>

	# For debugging
	#Write-Host ("$fn_name() DatFilesObj type = " + $DatFilesObj.GetType())
	#Write-Host ("$fn_name() DatFilesObj = " + ($DatFilesObj | ConvertTo-Json))

	# Initialize arrays to be returned
	[array]$all_filespecs_ary = $DatFilesObj | Select -Expand FullName
	#[array]$all_sizes_ary     = $DatFilesObj | Select -Expand Length
	#[array]$all_dates_ary     = $DatFilesObj | Select -Expand LastWriteTime
	#[array]$all_tstamps_ary   = @()

	# Just in case
	$all_filespecs_ary = $all_filespecs_ary | select -Unique

	# For debugging
	#Write-Host ("$fn_name() all_filespecs_ary type = " + $all_filespecs_ary.GetType())
	#Write-Host ("$fn_name() all_filespecs_ary cnt = " + $all_filespecs_ary.Count)
	#Write-Host ("$fn_name() all_filespecs_ary = " + ($all_filespecs_ary | ConvertTo-Json))

	# Parse/format file info.
	$i = 0
	foreach ($fs in $all_filespecs_ary) {
		# ... Filespecs
		$filespecs_list.Add($fs)
		# ... File names
		#$name = Split-Path $fs -Leaf
		#$names_list.Add($name)
		# ... Sub-folders - use blank for items in root directory
		#$str = Split-Path $fs -Parent
		#$parent = $str.Replace($root_path, "")
		#$subdirs_list.Add($parent)
		# ... File sizes
		#$sizes_list.Add($all_sizes_ary[$i])
		# ... File UNIX timestamps
		#$ts = Get-Date -date $all_dates_ary[$i] -UFormat %s
		#$tstamps_list.Add($ts)
		#$i++
	}

	# Fill collectors
	$filespecs_ary = $filespecs_list.ToArray()
	#$file_names_ary = $names_list.ToArray()
	#$file_subdirs_ary = $subdirs_list.ToArray()
	#$file_sizes_ary = $sizes_list.ToArray()
	#$file_timestamps_ary = $tstamps_list.ToArray()
	
	# For debugging
	#Write-Host ("$fn_name() filespecs_ary = " + ($filespecs_ary | ConvertTo-Json))
	#Write-Host ("$fn_name() file_names_ary = " + ($file_names_ary | ConvertTo-Json))
	#Write-Host ("$fn_name() file_subdirs_ary = " + ($file_subdirs_ary | ConvertTo-Json))
	#Write-Host ("$fn_name() file_sizes_ary = " + ($file_sizes_ary | ConvertTo-Json))
	#Write-Host ("$fn_name() file_sizes_ary type = " + ($file_sizes_aryGetType())
	#Write-Host ("$fn_name() file_timestamps_ary = " + ($file_timestamps_ary | ConvertTo-Json))

	#return $filespecs_ary, $file_names_ary, $file_subdirs_ary, $file_sizes_ary, $file_timestamps_ary
	return @($filespecs_ary, $DatFilesObj)

}

function FindBytes() {
# PURPOSE:  Find all starting indices in $Bytes array where $Search array is found
# ARGS:     see param lines below
# RETURNS:  (array) integers, or empty array @()
# Source:   https://stackoverflow.com/a/62511302/13499984
# Version   2 (2/27/2024)

	param (
		[Byte[]]$Bytes, 
		[Byte[]]$Search, 
		[Int]$Start, 
		[Switch]$All		
	)
	
	[Int[]]$rtn_ary = @()
	
    for ($idx = $Start; $idx -le $Bytes.Length - $Search.Length ; $idx++) {
        for ($i = 0; $i -lt $Search.Length -and $Bytes[$idx + $i] -eq $Search[$i]; $i++) {}
        if ($i -ge $Search.Length) { 
            $rtn_ary += $idx
            if (!$All) { 
				return $rtn_ary
			}
        } 
    }
	
	# KEY POINT: By default, Powershell functions will return $null if attempting to return a empty array.
	# e.g., return @()
	# To avoid this, the options are:
	# 1) return ,$rtn_ary  ... where the comma is the Powershell 'array construction operator'
	# 2) write-output $arr -NoEnumerate 
	# REF: https://stackoverflow.com/a/18477004

	return ,$rtn_ary
}

function FindDatConfimedImageMemo() {
# PURPOSE:     To find the 'confirmed alert' memo string in a Blue Iris *.DAT file
# PARAMS:      -Bytes = [array] bytes between images in the Blue Iris *.DAT file
# RETURNS:     [string] memo string  
# ATTRIBUTION: Thanks to EvanVanVan@ipcamtalk for identifying the confirmed JPG's memo in the DAT file

	param (
		[byte[]]$Bytes  # decimals array
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	#Write-Host "entered $fn_name()..."
	#Write-Host ("$fn_name() Bytes = " + ($Bytes | ConvertTo-Json))
	#Write-Host ("$fn_name() Bytes cnt = " + $Bytes.Length)

	# Start performance timer
	$timer = [Diagnostics.Stopwatch]::StartNew()

	# For debugging
	$bytes_as_str = [System.Text.Encoding]::UTF8.GetString($bytes_after)
	#Write-Host ("$fn_name() Bytes as string = `n" + $bytes_as_str)
	#Write-Host ("$fn_name() Bytes as string = `n" +  ($bytes_as_str -creplace '\P{IsBasicLatin}'))
	
	$rtn_str = $null
	
	# Initialize bytes ary indices for the embedded memo
	$SOM_idx = 0
	$EOM_idx = 0
	
	# Initialize byte array target values
	$hex = "25"  # percent character (%)
	$target1 = [Int32]"0x$hex"	
	$hex = "00"  
	$target2 = [Int32]"0x$hex"
	$hex = "3A"  # colon character (:)
	$target3 = [Int32]"0x$hex"
	
	# For debugging
	#Write-Host "$fn_name() target1 = $target1"
	#Write-Host "$fn_name() target2 = $target2"
	#Write-Host "$fn_name() target3 = $target3"

	# Find the memo string's end index
	# ... by walking backwards to find the first percent (%) character
	for ($idx = $Bytes.Length - 1; $idx -ge 0; $idx--) {
		if ($Bytes[$idx] -eq $target1){
			$EOM_idx = $idx + 1
			break
		}
	}
	
	# Find the memo string's start index
	# ... by walking backward from the $EOM_idx to find first the '00 00 00' byte triplet
	for ($idx = $EOM_idx - 1; $idx -gt 2; $idx--) {
		if  ($Bytes[$idx-3] -eq $target2 -and $Bytes[$idx-2] -eq $target2 -and $Bytes[$idx-1] -eq $target2) {
			$SOM_idx = $idx
			break
		}
	}

	# Create a candidate memo string
	if (($EOM_idx-$SOM_idx) -gt 1) {
		$bytes_after = $Bytes[$SOM_idx..$EOM_idx]
		$bytes_after_as_str = [System.Text.Encoding]::UTF8.GetString($bytes_after)

		# At this stage, a memo string like "vehicle:93%" is actually the following string: "v\u0000e\u0000h\u0000i\u0000c\u0000l\u0000e\u0000:\u00009\u00003\u0000%\u0000"
		# So we must remove all '\0000' null characters from the extracted string
		# REF: https://stackoverflow.com/a/9866769
		$bytes_after_as_str = $bytes_after_as_str.Replace("`0", "")
		$bytes_after_as_str = $bytes_after_as_str.Trim()  # Just in case
						
		# Validate the candidate memo string 
		# ... must contain a colon that is not at either end of the string
		if ($bytes_after -contains $target3) {
			if (!$bytes_after_as_str.StartsWith($target3) -and !$bytes_after_as_str.EndsWith($target3)) {
				$rtn_str = $bytes_after_as_str
			}
		}
	}

	# Stop overall performance timer
	$timer.stop()
	$total_ms  = [math]::Round($timer.elapsed.totalmilliseconds,1).ToString("0.00")
	if ($script:fromConsole -and $script:DevMode) {
		Write-Host "(dev  mode) $fn_name() execution time: $total_ms (msec)" -ForegroundColor cyan
	}
	
	# For debugging
	#Write-Host "$fn_name() EOM_idx = $EOM_idx"	
	#Write-Host "$fn_name() SOM_idx = $SOM_idx"
	#Write-Host "$fn_name() rtn_str = $rtn_str"
	
	return $rtn_str
}

function ExtractAiLabels() {
# PURPOSE:   To extract AI labels from a Blue Iris database clips/alerts 'memo' parameter
# PARAMS:    see param() line below
# RETURNS:   (string) modified input string
# SOURCE:    https://stackoverflow.com/a/67884741

    param(
        [string]$InputStr
    )

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging
	#Write-Host "Entered $fn_name() ..."
	#Write-Host "$fn_name() InputStr = '$InputStr'"

	# NOTE: A Blue Iris alert memo may be prefixed with ONVIF details, e.g., 'RuleEngine*;person:93%,vehicle:85%'
	#       so we attempt to extract the actual memo substring 
	# NOTE: memo may contain AI confidence entries, like person:90%
	#       so we remove all digits and ':' & '%' characters
	# NOTE: the .NET method .Replace() does not support regex
	#       so we use -Replace '\d+',''
	
	$arr1 = ( ($InputStr -Replace '\d+','').Replace(':','').Replace('%','') ).Split(';')
	if ($arr1.Count -gt 1) {
		$arr2 = $arr1 | Select -Last ($arr1.Count - 1)
		$rtn_str = $arr2 -Join ';'
	} else {
		# Just in case user-edited AI labels are semicolon delimited
		$rtn_str = $arr1 -Join ','
	}
	
	# For debugging
	#Write-Host "$fn_name() arr1 = $arr1"
	#Write-Host "$fn_name() arr2 = $arr2"
	
	return $rtn_str
	
}

function RepairDatFile() {
# PURPOSE:   To try to repair a Blue Iris *.DAT file with an unexpected byte structure,
#            i.e., unbalanced SOI (Start-of-Image) end EOI (End-of-Image) markers
# PARAMS:    see 'param' command below
# NOTE:      Repair is attempted only when the count of 'end markers' <> the count of 'beg markers'
# RETURNS    [array] @([boolean]rtn_flg, [array]SOI_mrks, [array]EOI_mrks)

	param (
		[byte[]]$Bytes,
		[array]$BegOfImageMarks,
		[array]$EndOfImageMarks
	)

	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	#Write-Host "Entered $fn_name()..."
	#Write-Host ("$fn_name() BegOfImageMarks type = " + $BegOfImageMarks.GetType())
	#Write-Host ("$fn_name() BegOfImageMarks cnt = " + $BegOfImageMarks.Count)
	#Write-Host "$fn_name() BegOfImageMarks = $BegOfImageMarks"
	#Write-Host ("$fn_name() EndOfImageMarks type = " + $EndOfImageMarks.GetType())
	#Write-Host ("$fn_name() EndOfImageMarks cnt = " + $EndOfImageMarks.Count)
	#Write-Host "$fn_name() EndOfImageMarks = $EndOfImageMarks"
	
	# Initialize vars
	$rtn_flg = $true  # Assume success
	$SOI_mrks_cnt = $BegOfImageMarks.Count
	$EOI_mrks_cnt = $EndOfImageMarks.Count		

	# Must convert arrays to ArrayLists to use method 'RemoveAt()' (later)
	$SOI_mrks_lst = [System.Collections.Generic.List[System.Object]]$BegOfImageMarks
	$EOI_mrks_lst = [System.Collections.Generic.List[System.Object]]$EndOfImageMarks

	# For debugging
	#Write-Host ("$fn_name() SOI_mrks_lst type = " + $SOI_mrks_lst.GetType())
	#Write-Host ("$fn_name() SOI_mrks_lst cnt = " + $SOI_mrks_lst.Count)
	#Write-Host "$fn_name() SOI_mrks_lst = $SOI_mrks_lst"
	#Write-Host ("$fn_name() EOI_mrks_lst type = " + $EOI_mrks_lst.GetType())
	#Write-Host ("$fn_name() EOI_mrks_lst cnt = " + $EOI_mrks_lst.Count)
	
	if ($SOI_mrks_cnt -gt $EOI_mrks_cnt) {

		for ($i=0; $i -lt $EOI_mrks_cnt; $i++) {
			$indices_delta = [int]$EndOfImageMarks[$i] - [int]$BegOfImageMarks[$i]
			
			# For debugging
			#Write-Host ("- end index = [$i] " + $EndOfImageMarks[$i])
			#Write-Host "- indices_delta = $indices_delta"

			if ($indices_delta -lt 0) {
				
				$SOI_mrks_lst_new = $SOI_mrks_lst
				$SOI_mrks_lst_new.RemoveAt($i)

				# For debugging
				#Write-Host "starting recursive call..."
				#Write-Host "- SOI_mrks_lst_new = $SOI_mrks_lst_new"

				# Recursive call
				$arr1 = [array]$SOI_mrks_lst_new
				$arr2 = [array]$EOI_mrks_lst
				$result_flg, $SOI_mrk_idxs_ary, $EOI_mrk_idxs_ary = `
					RepairDatFile `
					-Bytes $bytes `
					-BegOfImageMarks $arr1 `
					-EndOfImageMarks $arr2

				# For debugging
				#Write-Host "recursive result_flg = $result_flg"

				if ($result_flg) {
					$rtn_flg = $true
					$SOI_mrks_lst = [System.Collections.Generic.List[System.Object]]$SOI_mrk_idxs_ary
					$EOI_mrks_lst = [System.Collections.Generic.List[System.Object]]$EOI_mrk_idxs_ary
					break
				} else {
					$rtn_flg = $false
				}				
			}
		}					
	}
	
	if ($EOI_mrks_cnt -ge $SOI_mrks_cnt) {

		for ($i=0; $i -lt $SOI_mrks_cnt; $i++) {
			$indices_delta = [int]$EndOfImageMarks[$i] - [int]$BegOfImageMarks[$i]
			
			# For debugging
			#Write-Host ("- beg index = [$i] " + $BegOfImageMarks[$i])
			#Write-Host "- indices_delta = $indices_delta"
			
			if ($indices_delta -lt 0) {
				
				$EOI_mrks_lst_new = $EOI_mrks_lst
				$EOI_mrks_lst_new.RemoveAt($i)

				# For debugging
				#Write-Host "starting recursive call..."
				#Write-Host "- EOI_mrks_lst_new = $EOI_mrks_lst_new"

				# Recursive call
				$arr1 = [array]$SOI_mrks_lst
				$arr2 = [array]$EOI_mrks_lst_new
				$result_flg, $SOI_mrk_idxs_ary, $EOI_mrk_idxs_ary = `
					RepairDatFile `
					-Bytes $bytes `
					-BegOfImageMarks $arr1 `
					-EndOfImageMarks $arr2
					
				# For debugging
				#Write-Host "recursive result_flg = $result_flg"

				if ($result_flg) {
					$rtn_flg = $true
					$SOI_mrks_lst = [System.Collections.Generic.List[System.Object]]$SOI_mrk_idxs_ary
					$EOI_mrks_lst = [System.Collections.Generic.List[System.Object]]$EOI_mrk_idxs_ary
					break
				} else {
					$rtn_flg = $false
				}				
			}
		}
	}

	return @($rtn_flg, [array]$SOI_mrks_lst, [array]$EOI_mrks_lst)

}

function DeleteDatFile() {
# PURPOSE:   Moves specified DAT filespec (and associated JPG) from Blue Iris storage to the Windows Recycle bin
# PARAMS:    see param() line
# RETURNS:   (boolean) $false if file NOT deleted
# NOTES:     1. DAT file is NOT deleted if the DAT file or its associated JPG alert file is Read-Only 
#               (this may mean that the ALERT if 'protected' by Blue Iris) 
#            2. Whether the DAT has actually been deleted is verified
	
	param(
		[string]$DatFile,        # Full filespec for the file to be deleted
		[boolean]$NoRecycleFlg,  # PERMANENTLY deletes filtered DAT files
		[string]$Destination,    # Path to folder to archive the DAT file if running from Task Scheduler and [-NoRecycleFlg] no used
		[boolean]$ForceFlg       # Delete DAT file even if associated ALERT JPG file is READ-ONLY (Protected by Blue Iris)
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	
	# Initialize vars
	$is_protected = $false  
	$fname = (Get-Item -LiteralPath "$DatFile").Name
	
	# Test if the DAT file, or its associated ALERT JPG is Read-Only
	if (!$ForceFlg) {
		if (Test-Path -LiteralPath "$DatFile") {
			$obj = Get-ItemProperty -LiteralPath "$DatFile" | Select-Object IsReadOnly
			if ($obj.IsReadOnly) {
				$is_protected = $true	# DAT file is read-only (may be protected by Blue Iris)
			}
		}
		$alert_filespec = $DatFile.Replace(".dat", ".jpg")
		if (Test-Path -LiteralPath "$alert_filespec") {
			$obj = Get-ItemProperty -LiteralPath "$alert_filespec" | Select-Object IsReadOnly
			if ($obj.IsReadOnly) {
				$is_protected = $true	# Alert JPG is read-only (may be protected by Blue Iris)
			}
		}
		
		# For debugging
		#Write-Host "$fn_name() alert_filespec = '$alert_filespec'"
		#Write-Host "$fn_name() obj = $obj"
		#Write-Host "$fn_name() protected_flg = '$is_protected'"
	}
	
	if ($is_protected) {
		return $false  # DAT file NOT deleted
	}
	
	if ($NoRecycleFlg) {
		
		# PERMANENTLY DELETE THE FILES
		Remove-Item -LiteralPath "$DatFile"
		#Remove-Item -LiteralPath "$alert_filespec"

	} else {
		
		# *** WARNING ***
		# If this script is executed via Task Scheduler, the used action 'VisualBasic:DeleteFile'
		# PERMANENTLY deletes the specified file. Otherwise it seems to work just fine 
		# (I've confirmed this via the Console) using both PS5 and PS7)
		# 
		# To get around this, we backup the files to an alternate folder '_background_deleted_DAT_files' for safe keeping.

		# NOTE: Scripts running from Windows Task Scheduler have a parent process named 'svchost'.
		#       https://stackoverflow.com/a/65894924
		$ParentProcess = (Get-Process -Id (Get-CimInstance Win32_Process -Filter "ProcessID = $pid").ParentProcessId).Name

		if (!($ParentProcess -match "svchost")) {  # NOT Task Scheduler

			# MOVE THE FILE TO THE WINDOWS RECYCLE BIN

			# REFS:  
			#   https://stackoverflow.com/a/21118566/13499984
			#   https://learn.microsoft.com/en-us/dotnet/api/microsoft.visualbasic.fileio.filesystem.deletefile?view=net-7.0
			#
			Add-Type -AssemblyName Microsoft.VisualBasic
			[Microsoft.VisualBasic.FileIO.FileSystem]::DeleteFile(
				"$DatFile", 
				'OnlyErrorDialogs', 
				'SendToRecycleBin', 
				'ThrowException'
			)
			<# [Microsoft.VisualBasic.FileIO.FileSystem]::DeleteFile(
				"$alert_filespec", 
				'OnlyErrorDialogs', 
				'SendToRecycleBin', 
				'ThrowException'
			) #>
			
		} else {  # NOT Task Scheduler
			
			# BACKUP FILE TO AN ALTERNATE LOCATION
			$bkup_path = "$Destination\_background_recycle_bin"
			# ... Copy, then delete the file
			Copy-Item -LiteralPath "$DatFile" -Destination $("$bkup_path\$fname") -Force
			Remove-Item -LiteralPath "$DatFile"
			#Copy-Item -LiteralPath "$alert_filespec" -Destination $("$bkup_path\$fname") -Force
			#Remove-Item -LiteralPath "$alert_filespec"
			
		}
	}
	
	# Verify that that the DAT file has be successfully removed from the Alerts folder
	if (Test-Path -LiteralPath "$DatFile") {
		return $false
	} else {		
		return $true
	}
}

function ConvertTo-Hashtable() {
# PURPOSE:  To take an object returned from the 'ConvertFrom-Json' CmdLet and convert it to a Powershell hashtable.
# NOTE:     PowerShell has a native command called ConvertFrom-Json, but (before PowerShell 7) 
#           it did not directly convert data to a hashtable
# Source:   https://4sysops.com/archives/convert-json-to-a-powershell-hash-table/

    [CmdletBinding()]
    [OutputType('hashtable')]
    param (
        [Parameter(ValueFromPipeline)]
        $InputObject
    )

    process {
        # Return null if the input is null. This can happen when calling the function
        # recursively and a property is null
        if ($null -eq $InputObject) {
            return $null
        }

        # Check if the input is an array or collection. If so, we also need to convert
        # those types into hash tables as well. This function will convert all child
        # objects into hash tables (if applicable)
        if ($InputObject -is [System.Collections.IEnumerable] -and $InputObject -isnot [string]) {
            $collection = @(
                foreach ($object in $InputObject) {
                    ConvertTo-Hashtable -InputObject $object  # RECURSIVE CALLS
                }
            )
            # Return the array but don't enumerate it because the object may be pretty complex
            Write-Output -NoEnumerate $collection
        } elseif ($InputObject -is [psobject]) { ## If the object has properties that need enumeration
            # Convert it to its own hash table and return it
            $hash = @{}
            foreach ($property in $InputObject.PSObject.Properties) {
                $hash[$property.Name] = ConvertTo-Hashtable -InputObject $property.Value
            }
            $hash
        } else {
            # If the object isn't an array, collection, or other object, it's already a hash table
            # So just return it.
            $InputObject
        }
    }
}

function JsonGetAiModelsAndLabels() {
# PURPOSE:   To get all AI models used for a single image in a Blue Iris *.DAT file (via its JSON string)
# PARAMS:    -JsonStr (string)
# RETURNS:   (array) @( @(model_1,model_2...), @(lbl_1,lbl_2...) )
# REQUIRES:  Function: 'ConvertTo-Hashtable'

	param (
		[string]$JsonStr
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host ("$fn_name() JsonStr  type = " + $JsonStr.GetType())
	#Write-Host "$fn_name() JsonStr = $JsonStr"
	
	if (!$JsonStr) {
		return @()
	}
																
	# Convert JSON string to hashtable for ease of use
	$PsVersion = $PSVersionTable.PSVersion.Major
	if ($PsVersion -ge 7) {
		# This is EASY in PowerShell 7
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json -AsHashtable
	} else {
		# This is not easy before PowerShell 7
		# ... to learn more, see the URL provided in the 'ConvertTo-HashTable' function header
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json | ConvertTo-HashTable
	}
	
	# For debugging
	#$json_obj_cnt = $jsonstr_hashtable.Count
	#Write-Host "$fn_name() json_obj_cnt = $json_obj_cnt"
	#Write-Host ("$fn_name() jsonstr_hashtable keys = " + $jsonstr_hashtable.Keys)
	#Write-Host ("$fn_name() jsonstr_hashtable = " + ($jsonstr_hashtable | ConvertTo-Json -Depth 8))
	
	# Get all values in the 'api' 'column'
	if (($jsonstr_hashtable.api).GetType() -match 'string') {
		$models_ary = @()
		$models_ary += $jsonstr_hashtable.api
	} else {
		$models_ary = $jsonstr_hashtable.api
	}
	
	# Parse image's JSON string for ALL labels
	$labels_ary = @()
	foreach ($item in $jsonstr_hashtable) {
		$api = $item.api
		if ($api) {
			$found_obj = $item.found
			$predictions_obj = $found_obj.predictions
			foreach ($p in $predictions_obj) {
				$lbl = $p.label
				if ($lbl) {
					if (!($labels_ary -contains $lbl)) {
						$labels_ary += $lbl
					}
				}
			}
		}
	}
	
	# For debugging
	#Write-Host ("$fn_name() models_ary type = " + $models_ary.GetType())
	#Write-Host ("$fn_name() models_ary cnt = " + $models_ary.Count)
	#Write-Host "$fn_name() models_ary = $models_ary"
	#Write-Host "$fn_name() labels_ary = $labels_ary"
	
	return @( $models_ary, $labels_ary )
}

function JsonAiModelFound() {
# PURPOSE:   To test if a Blue Iris *.DAT file image's JSON string has a match for the named AI model
# PARAMS:    see param() line below
# RETURNS:   (array) @((boolean)result)

	param (
		[string]$JsonStr, # JSON string as extracted from a Blue Iris DAT file
		[string]$Model    # Note: a partial name is fine, e.g., 'animal' for AI model 'ipcam-animal'
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	
	# Initialize return var
	$rtn_flg = $false
	
	if (!$JsonStr -or !$Model) {
		return $rtn_flg
	}
																
	# Convert JSON string to hashtable for ease of use
	if ($PsVersion -ge 7) {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json -AsHashtable
	} else {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json | ConvertTo-HashTable
	}
	$json_obj_cnt = $jsonstr_hashtable.Count
	
	# For debugging
	#Write-Host "json_obj_cnt = $json_obj_cnt"
	#Write-Host ("jsonstr_hashtable = " + ($jsonstr_hashtable | ConvertTo-Json -Depth 8))
	
	# Get all values in 'api' 'column'
	# .. used for -NotNothingFoundFlg option
	$models_used_ary = $jsonstr_hashtable.api
	$models_used_ary_cnt = $models_used_ary.Count
	
	# For debugging
	#Write-Host "$fn_name() models_used_ary_cnt = $v"

	# Just in case
	if ($models_used_ary_cnt -eq 0) {
		return @($rtn_flg, @())
	}

	# Parse image's JSON string
	foreach ($item in $jsonstr_hashtable) {

		# For debugging
		#Write-Host ("$fn_name() item = " + ($item |  ConvertTo-Json -Depth 8))
		#Write-Host ("$fn_name() item.api = " + $item.api)

		$api = $item.api									
		if ($api) {		
			if ($api -match $Model) {
				$rtn_flg = $true
				break
			}
		}
	}
	
	return @($rtn_flg)
}

function JsonAiLabelsFound() {
# PURPOSE:   To test if a Blue Iris *.DAT file image's JSON string has a match for the named object label(s)
#            (and AI model, if provided)
# PARAMS:    see param() line below
# RETURNS:   (array) @( (boolean)result, (array)found_l_ary, (object)if_ai_lbls_models_obj )

	param (
		[string]$JsonStr, # JSON string as extracted from a Blue Iris DAT file
		[array]$Labels,   # comma delimited list of AI model labels, e.g., 'vehicle,person,dog'
		[string]$Model    # Note: a partial name is fine, e.g., 'animal' for AI model 'ipcam-animal'
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() JsonStr = $JsonStr"
	#Write-Host ("$fn_name() Labels type = " + $Labels.GetType())
	#Write-Host "$fn_name() Labels = $Labels"
	#Write-Host "$fn_name() Model = $Model"

	# Initialize return values & collectors	
	$rtn_flg = $false
	$rtn_lbls_ary = @()
	# ... custom object
	$rtn_lbls_models_obj = New-Object PSObject
	foreach ($lbl in $Labels) {
		Add-Member -InputObject $rtn_lbls_models_obj -MemberType NoteProperty -Name $lbl -Value @()
	}
	
	# Validate params
	if (!$JsonStr -or !$Labels) {
		return @($rtn_flg, $rtn_lbls_ary, $rtn_lbls_models_obj)
	}
																
	# Convert JSON string to hashtable for ease of use
	if ($PsVersion -ge 7) {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json -AsHashtable
	} else {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json | ConvertTo-HashTable
	}

	# For debugging
	$json_obj_cnt = $jsonstr_hashtable.Count
	#Write-Host "$fn_name() json_obj_cnt = $json_obj_cnt"
	#Write-Host ("$fn_name() jsonstr_hashtable = " + ($jsonstr_hashtable |  ConvertTo-Json -Depth 8))
	
	# Get all values in 'api' 'column'
	# .. used for -NotNothingFoundFlg option
	$models_used_ary = $jsonstr_hashtable.api
	$models_used_ary_cnt = $models_used_ary.Count

	# Just in case
	if ($models_used_ary_cnt -eq 0) {
		return @($false, @(), @(), @())
	}

	# Parse image's JSON string
	foreach ($item in $jsonstr_hashtable) {

		# For debugging
		#Write-Host ("$fn_name() item = " + ($item |  ConvertTo-Json -Depth 8))
		#Write-Host ("$fn_name() item.api = " + $item.api)

		if (!$item.api) {
			continue
		} else {
			$api = $item.api	
			if ($api) {		
				if ($Model) {
					if (!($api -match $Model)) {
						continue
					}
				}
				$found_obj = $item.found
				$found_obj_cnt = $found_obj.Count
				
				# For debugging
				#Write-Host ("$fn_name() model '$api' found_obj = " + ($found_obj | ConvertTo-Json -Depth 8))
				#Write-Host "$fn_name() model '$api' found_obj_cnt = $found_obj_cnt"
				
				if ($found_obj_cnt -gt 0) {
					$predictions_obj = $found_obj.predictions
					$predictions_obj_cnt = $predictions_obj.Count

					# For debugging
					#Write-Host ("$fn_name() model '$api' predictions_obj = " + ($predictions_obj | ConvertTo-Json))
					#Write-Host "$fn_name() model '$api' predictions_obj cnt = $predictions_obj_cnt"

					if ($predictions_obj_cnt -gt 0) {
						for ($i = 0; $i -lt $predictions_obj_cnt; $i++) {
							$predictions_obj_lbl = $predictions_obj[$i].label

							# For debugging
							#Write-Host ("model '$api' predictions_obj #" + ($i+1) + " = " + ($predictions_obj[$i] | ConvertTo-Json))
							#Write-Host "model '$api' predictions_obj_lbl = $predictions_obj_lbl"

							foreach ($lbl in $Labels) {
								if ($predictions_obj_lbl -contains $lbl) {
									$rtn_flg = $true
									#  Add only unique labels
									if (!($rtn_lbls_ary -contains $lbl)) {
										$rtn_lbls_ary += $lbl
									}
									#  Add only unique models
									if (!($rtn_lbls_models_obj.$lbl -contains $api)) {
										$rtn_lbls_models_obj.$lbl += $api
									}
								}
							}
						}
					}
				}
			}
		}
	}
	
	# For debugging
	#Write-Host "$fn_name() rtn_lbls_ary = $rtn_lbls_ary"
	#Write-Host ("$fn_name() rtn_lbls_ary_models type = " + $rtn_lbls_ary_models.GetType())
	#Write-Host ("$fn_name() rtn_lbls_ary_models = " + (($rtn_lbls_models_obj | ConvertTo-Json)))
	
	#return @($rtn_flg, $rtn_lbls_ary, $rtn_lbls_models_obj | ConvertTo-Json)
	return @($rtn_flg, $rtn_lbls_ary, $rtn_lbls_models_obj)
}

function JsonAiNothingFoundAny() {
# PURPOSE:   To test if a Blue Iris *.DAT file JSON response has the key:value pair ' "predictions": [] '
#            for ANY of the AI models used (or for just the model specified)
# PARAMS:    see param() line below
# RETURNS:   (array) @( (boolean)result, (array)found_models_ary )

	param (
		[string]$JsonStr, # JSON string as extracted from a Blue Iris DAT file
		[string]$Model    # limit evaluation to a single model
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() JsonStr = $JsonStr"
	
	if (!$JsonStr) {
		return @($false, @())
	}
																
	# Convert JSON string to hashtable for ease of use
	if ($PsVersion -ge 7) {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json -AsHashtable
	} else {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json | ConvertTo-HashTable
	}
	
	# For debugging
	#Write-Host ("$fn_name() jsonstr_hashtable = " + ($jsonstr_hashtable | ConvertTo-Json -Depth 8))
	
	# Get all values in 'api' 'column'
	# .. used for -NotNothingFoundFlg option
	$models_used_ary = $jsonstr_hashtable.api
	$models_used_ary_cnt = $models_used_ary.Count

	# Just in case
	if ($models_used_ary_cnt -eq 0) {
		return @($false, @())
	}
	
	# Initialize return collectors
	$rtn_ary = @()

	# Parse image's JSON string for ALL models
	foreach ($item in $jsonstr_hashtable) {
		$api = $item.api
		if ($api) {
			if ($Model) {
			
				# For debugging
				#Write-Host ("$fn_name() api = $api, TargetModel = $Model, match = " + ($api -match $Model))

				if (!($api -match $Model)) {
					Continue
				}

				#$predictions_obj = $item.found.predictions
				$found_obj = $item.found
				$predictions_obj = $found_obj.predictions
				$predictions_obj_cnt = $predictions_obj.Count
				
				# For debugging
				#Write-Host ("$fn_name() predictions_obj = " + ($predictions_obj | ConvertTo-Json))
				#Write-Host ("$fn_name() predictions_obj cnt = " + $predictions_obj.Count)
				
				# Test for JSON response key:value pair "predictions": []
				if ($predictions_obj_cnt -eq 0) {
					$rtn_ary += $api
				}
			}
		}
	}
	
	# For debugging
	#Write-Host "$fn_name() rtn_ary = $rtn_ary"
	
	$rtn_flg = ($rtn_ary.Count -gt 0) 

	return @($rtn_flg, $rtn_ary)
}

function JsonAiNothingFoundAll() {
# PURPOSE:   To test if a Blue Iris *.DAT file JSON response has the key:value pair ' "predictions": [] '
#            for EVERY one of the AI models used (or specified by -Model)
# PARAMS:    see param() line below
# RETURNS:   (array) @( (boolean)result, (array)found_models_ary )

	param (
		[string]$JsonStr, # JSON string as extracted from a Blue Iris DAT file
		[string]$Model    # [OPTIONAL] limit evaluation to a single model
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() JsonStr = $JsonStr"
	
	if (!$JsonStr) {
		return @($false, @())
	}
																
	# Convert JSON string to hashtable for ease of use
	if ($PsVersion -ge 7) {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json -AsHashtable
	} else {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json | ConvertTo-HashTable
	}
	
	# For debugging
	#Write-Host ("$fn_name() jsonstr_hashtable = " + ($jsonstr_hashtable | ConvertTo-Json -Depth 8))
	
	# Get all values in 'api' 'column'
	# ... Note: by default, this array will have unique values
	$models_used_ary = $jsonstr_hashtable.api
	$models_used_ary_cnt = $models_used_ary.Count

	# Just in case
	if ($models_used_ary_cnt -eq 0) {
		return @($false, @())
	}
	
	# Initialize return collectors
	$rtn_ary = @()

	# Parse image's JSON string for ALL models
	foreach ($item in $jsonstr_hashtable) {
		$api = $item.api
		if ($api) {
			if ($Model) {
			
				# For debugging
				#Write-Host ("$fn_name() api = $api, TargetModel = $Model, match = " + ($api -match $Model))

				if (!($api -match $Model)) {
					Continue
				}
			}

			#$predictions_obj = $item.found.predictions
			$found_obj = $item.found
			$predictions_obj = $found_obj.predictions
			$predictions_obj_cnt = $predictions_obj.Count
			
			# For debugging
			#Write-Host ("$fn_name() predictions_obj = " + ($predictions_obj | ConvertTo-Json))
			#Write-Host ("$fn_name() predictions_obj cnt = " + $predictions_obj.Count)
			
			# Test for JSON response key:value pair "predictions": []
			if ($predictions_obj_cnt -eq 0) {
				$rtn_ary += $api
			}
		}
	}
	
	# For debugging
	#Write-Host "$fn_name() rtn_ary = $rtn_ary"
	
	$rtn_flg = $false
	
	if ($rtn_ary.Count -gt 0) {
		if ($rtn_ary.Count -eq $models_used_ary_cnt) {
			$rtn_flg = $true
		}
	}
	return @($rtn_flg, $rtn_ary)
}

function JsonAiSomethingFoundAny() {
# PURPOSE:   To test if a Blue Iris *.DAT file JSON response DOES NOT have the key:value pair ' "predictions": [] '
#            for ANY of the AI models used (or for just the model specified)
# PARAMS:    see param() line below
# RETURNS:   (array) @( (boolean)result, (array)found_models_ary) )

	param (
		[string]$JsonStr, # [REQUIRED] JSON string as extracted from a Blue Iris DAT file
		[string]$Model    # [OPTIONAL] limit evaluation to a single model
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() JsonStr = $JsonStr"
	#Write-Host "$fn_name() Model = $Model"
	
	if (!$JsonStr) {
		return @($false, @())
	}
																
	# Convert JSON string to hashtable for ease of use
	if ($PsVersion -ge 7) {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json -AsHashtable
	} else {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json | ConvertTo-HashTable
	}
	
	# For debugging
	#Write-Host ("$fn_name() jsonstr_hashtable = " + ($jsonstr_hashtable | ConvertTo-Json -Depth 8))	
	
	# Get all values in 'api' 'column'
	# ... Note: by default, this array will have unique values
	$models_used_ary = $jsonstr_hashtable.api
	$models_used_ary_cnt = $models_used_ary.Count

	# Just in case
	if ($models_used_ary_cnt -eq 0) {
		return @($false, @())
	}

	# Initialize collector
	$rtn_ary = @()

	# Parse image's JSON string
	foreach ($item in $jsonstr_hashtable) {
		$api = $item.api	
		if ($api) {
			if ($Model) {
			
				# For debugging
				#Write-Host ("$fn_name() api = $api, TargetModel = $Model, match = " + ($api -match $Model))

				if (!($api -match $Model)) {
					Continue
				}
			} 
			
			#$predictions_obj = $item.found.predictions
			$found_obj = $item.found
			$predictions_obj = $found_obj.predictions
			$predictions_obj_cnt = $predictions_obj.Count
			
			# For debugging
			if ($predictions_obj_cnt -gt 0) {
				#Write-Host ("$fn_name() predictions_obj = " + ($predictions_obj | ConvertTo-Json))
				#Write-Host ("$fn_name() predictions_obj cnt = " + $predictions_obj.Count)
			}
			
			if ($predictions_obj_cnt -ne 0) {
				$rtn_ary += $api
			}
		}
	}
	
	$rtn_flg = ($rtn_ary.Count -gt 0) 

	# For debugging
	#Write-Host ("$fn_name() return object = " + (@($rtn_flg, $rtn_ary) | ConvertTo-Json))

	return @($rtn_flg, $rtn_ary)
}

function JsonAiSomethingFoundAll() {
# PURPOSE:   To test if a Blue Iris *.DAT file JSON response DOES NOT have the key:value pair ' "predictions": [] ' 
#            for EVERY one of the AI models used (or specified by -Model)
# PARAMS:    see param() line below
# RETURNS:   (array) @( (boolean)result, (array)found_models_ary )
# TIP:       If we DELETE the DAT files identified by this function, then we will be left 
#            with only DAT files that at least one 'Nothing found' result. 
#            WHY USE? 
#            The images in these remaining DAT files may contain images that are suitable 
#            for customizing AI models that are failing to identify specific objects in 
#            your camera's field of view (FOV)        

	param (
		[string]$JsonStr, # [REQUIRED] JSON string as extracted from a Blue Iris DAT file
		[string]$Model    # [OPTIONAL] limit evaluation to a single model
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() JsonStr = $JsonStr"
	#Write-Host "$fn_name() Model = $Model"
	
	if (!$JsonStr) {
		return @($false, @())
	}
																
	# Convert JSON string to hashtable for ease of use
	if ($PsVersion -ge 7) {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json -AsHashtable
	} else {
		$jsonstr_hashtable = $JsonStr | ConvertFrom-Json | ConvertTo-HashTable
	}
	
	# For debugging
	#Write-Host ("$fn_name() jsonstr_hashtable = " + ($jsonstr_hashtable | ConvertTo-Json -Depth 8))
	
	# Get all values in 'api' 'column'
	# ... Note: by default, this array will have unique values
	$models_used_ary = $jsonstr_hashtable.api
	$models_used_ary_cnt = $models_used_ary.Count

	# Just in case
	if ($models_used_ary_cnt -eq 0) {
		return @($false, @())
	}
	
	# Initialize collector
	$rtn_ary = @()

	# Parse image's JSON string
	foreach ($item in $jsonstr_hashtable) {
		$api = $item.api	
		if ($api) {		
			if ($Model) {
			
				# For debugging
				#Write-Host ("$fn_name() api = $api, TargetModel = $Model, match = " + ($api -match $Model))

				if (!($api -match $Model)) {
					Continue
				}
			}

			#$predictions_obj = $item.found.predictions
			$found_obj = $item.found
			$predictions_obj = $found_obj.predictions
			$predictions_obj_cnt = $predictions_obj.Count
			
			# For debugging
			#Write-Host ("$fn_name() predictions_obj = " + ($predictions_obj | ConvertTo-Json))
			#Write-Host ("$fn_name() predictions_obj cnt = " + $predictions_obj.Count)
			
			if ($predictions_obj_cnt -ne 0) {
				$rtn_ary += $api
			}
		}
	}
	
	# For debugging
	#Write-Host "$fn_name() rtn_ary = $rtn_ary"
	
	$rtn_flg = $false
	
	if ($rtn_ary.Count -gt 0) {
		if ($rtn_ary.Count -eq $models_used_ary_cnt) {
			$rtn_flg = $true
		}
	}
	return @($rtn_flg, $rtn_ary)
}

function IsJpegFileValid() {
# PURPOSE:   To confirm that a JPG file is a valid JPG image
# PARAMS:    see param() line below
# NOTES:     This function uses uses 2 methods:
#            1. Test image type...
#               REFS: http://learningpcs.blogspot.com/2011/07/powershell-validate-jpeg-files.html
#                     https://www.powershellgallery.com/packages/PScribo/0.9.1/Content/Src%5CPrivate%5CGet-ImageMimeType.ps1
#            2. Test against the JPEG Interchange Format... 
#               Any JPEG file or stream that is written according to the JPEG Interchange Format 
#               must start with a SOI (Start-of-Image) marker -- two bytes 0xFF, 0xD8 --
#               and end with the EOI (End-of-Image) marker -- two bytes, 0xFF, 0xD9). 
#               These two markers will not be found anywhere else in a JPEG file/stream.
#               REFS: https://stackoverflow.com/a/46809226
#                     https://www.codeproject.com/Questions/421855/Verifying-a-file-is-JPEG
# DISCUSSION:
#    Originally I used only Method #1 in this function. However, I learned later that Method #1 would still return valid
#    if the image bytes did not terminate with the EOI (End-of-Image) marker (0xFF, 0xD9). These JPG files still opened 
#    just fine in every windows viewer I tried (Photos, Paint, Paint3D, PhotoScape X, ACDSee...), HOWEVER, if they were 
#    opened in a web browser (tested Chrome, Edge) the images had a white band across the bottom. 
#    Additionally, web apps like https://app.roboflow.com/ would not import the JPGs.
#    So clearly, Method 1 was NOT SUFFICIENT. So, for redundancy, I've opted to use both methods. 

	param(
		[string]$FilePath
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() FilePath  = $FilePath"
	
	# Initialize flags
	$method1_flg = $false
	$method2_flg = $false
	
	# ===========================
	# METHOD 1
	# Validate Image file Type

	# WARNING: The following code line IS ESSENTIAL when executing from Task Scheduler (or Blue Iris)
	#          (however works just fine from Powershell ISE)
	#          REF: https://tinyurl.com/2p929nhz
	add-type -AssemblyName System.Drawing
	
	try {
		$img = [System.Drawing.Image]::FromFile($FilePath)
		$method1_flg = $img.RawFormat.Equals([System.Drawing.Imaging.ImageFormat]::Jpeg)
		$img.Dispose()  # Release resources
	} catch [OutOfMemoryException] {
		$method1_flg = $false
	}
	
	# ===========================
	# METHOD 2
	# Validate bytes per the 'JPEG Interchange Format' (see Notes above)
	
	# Import the file to a byte[] array
	$ImageBytes = [System.IO.File]::ReadAllBytes($FilePath)
	
	# Capture the start and end byte pairs.
	#$bytes_rng1 = $ImageBytes[0],$ImageBytes[1]
	#$bytes_rng2 = $ImageBytes[$ImageBytes.Count-2],$ImageBytes[$ImageBytes.Count-1]
	$bytes_rng1 = $ImageBytes[0..1]
	$bytes_rng2 = $ImageBytes[($ImageBytes.Count-2)..($ImageBytes.Count-1)]

	# Define the required JPG start/end markers
	$markers1 = @(255,216) # hexArray @("FF", "D8")
	$markers2 = @(255,217) # hexArray @("FF", "D9")
	<# $hexArray = "FF", "D8"
	$markers1 = @()
	foreach ($hex in $hexArray) {
		$markers1 += [Int32]"0x$hex"
	}
	$hexArray = "FF", "D9"
	$markers2 = @()
	foreach ($hex in $hexArray) {
		$markers2 += [Int32]"0x$hex"
	} #>
	
	# Validate the start and end byte pairs.
	# ... Note: Method Compare-Object returns null if the arrays are the identical
	$x1 = Compare-Object $bytes_rng1 $markers1
	$x2 = Compare-Object $bytes_rng2 $markers2
	if ($null -eq $x1 -and $null -eq $x2) {
		$method2_flg = $true
	} else {
		$method2_flg = $false
	}
	
	# For testing
	#$method2_flg = $true

	# For debugging
	#Write-Host "markers1 = $markers1, markers2 = $markers2"
	#Write-Host "bytes_rng1 = $bytes_rng1, bytes_rng2 = $bytes_rng2"
	#Write-Host "method1_flg = $method1_flg, method2_flg = $method2_flg"
	
	if ($method1_flg -and $method2_flg) {
		return $true
	} else {
		return $false
	}
}

function Convert-ByteArrayToHexString() {
# SOURCE: https://www.sans.org/blog/powershell-byte-array-and-hex-functions/
################################################################
#.Synopsis
# Returns a hex representation of a System.Byte[] array as
# one or more strings. Hex format can be changed.
#.Parameter ByteArray
# System.Byte[] array of bytes to put into the file. If you
# pipe this array in, you must pipe the [Ref] to the array.
# Also accepts a single Byte object instead of Byte[].
#.Parameter Width
# Number of hex characters per line of output.
#.Parameter Delimiter
# How each pair of hex characters (each byte of input) will be
# delimited from the next pair in the output. The default
# looks like "0x41,0xFF,0xB9" but you could specify "\x" if
# you want the output like "\x41\xFF\xB9" instead. You do
# not have to worry about an extra comma, semicolon, colon
# or tab appearing before each line of output. The default
# value is ",0x".
#.Parameter Prepend
# An optional string you can prepend to each line of hex
# output, perhaps like '$x += ' to paste into another
# script, hence the single quotes.
#.Parameter AddQuotes
# A switch which will enclose each line in double-quotes.
#.Example
# [Byte[]] $x = 0x41,0x42,0x43,0x44
# Convert-ByteArrayToHexString -ByteArray $x
#
# 0x41,0x42,0x43,0x44
#.Example
# [Byte[]] $x = 0x41,0x42,0x43,0x44
# Convert-ByteArrayToHexString -ByteArray $x -Width 2 -Delimiter "\x" -AddQuotes
#
# "\x41\x42"
# "\x43\x44"
################################################################

	[CmdletBinding()] Param (
	[Parameter(Mandatory = $True, ValueFromPipeline = $True)] [System.Byte[]] $ByteArray,
	[Parameter()] [Int] $Width = 10,
	[Parameter()] [String] $Delimiter = ",0x",
	[Parameter()] [String] $Prepend = "",
	[Parameter()] [Switch] $AddQuotes )
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	 
	if ($Width -lt 1) { 
		$Width = 1
	}
	if ($ByteArray.Length -eq 0) { 
		Return 
	}
	$FirstDelimiter = $Delimiter -Replace "^[\,\:\t]",""
	$From = 0
	$To = $Width - 1
	
	# For debugging
	#Write-Host ("fn_name() ByteArray cnt = " + $ByteArray.Count)
	#Write-Host ("fn_name() ByteArray[0] = " + $ByteArray[0])
	#Write-Host ("fn_name() ByteArray[1] = " + $ByteArray[1])
	#Write-Host ("fn_name() ByteArray[" + ($ByteArray.Count - 1) + "] = " + $ByteArray[$ByteArray.Count - 1])
	#Write-Host "$fn_name() From = $From, To = $To"
	#Write-Host ("fn_name() ByteArray[" + $From + "] = " + $ByteArray[$From])
	#Write-Host ("fn_name() ByteArray[" + $To + "] = " + $ByteArray[$To])
	
	Do {
		$String = [System.BitConverter]::ToString($ByteArray[$From..$To])
		
		# For debugging
		#Write-Host ("fn_name() String = " + $String)
		
		$String = $FirstDelimiter + ($String -replace "\-",$Delimiter)
		if ($AddQuotes) { 
			$String = '"' + $String + '"' 
		}
		if ($Prepend -ne "") { 
			$String = $Prepend + $String 
		}
		$String
		$From += $Width
		$To += $Width
		
		# [ADDED BY JAYDEEL] added this code to avoid error under Set-StrictMode method 
		if ($To -gt ($ByteArray.Count - 1)) {
			$To = $ByteArray.Count - 1
		}
		
	} While ($From -lt $ByteArray.Length)
}

function IsJsonStringValid() {
# PURPOSE:   To test for a valid JSON string
# PARAMS:    -JsonStr = [string] to be tested
# RETURNS:   (boolean)
# REFS:      https://stackoverflow.com/a/17170800/13499984
#            https://jsonlint.com/  <-- Handy on-line JSON string test utility

	param(
		[string]$JsonStr
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host ("$fn_name() JsonStr type = " + $JsonStr.GetType())
	#Write-Host "$fn_name() JsonStr  = $JsonStr"
	#Write-Host ("JsonStr = " + ($JsonStr | ConvertTo-Json))
	
	# Test for non-alphanumeric characters
	#If (!($JsonStr -match '^[a-z0-9.-]{1,10}$')) {
		#return $false
	#}

	# For debugging (this was how I found the null terminator issue that caused grief in PS5)
	#$json_filespec = "$script:dest_path\temp\tmp.json"
	#Write-Host "json_filespec = '$json_filespec'"
	#$JsonStr | Out-File -FilePath "$json_filespec" -Encoding UTF8
	#$JsonStr = Get-Content -Raw -Path $json_filespec

	$PsVersion = $PSVersionTable.PSVersion.Major

	# Validity test
	# ... Note: I unsuccessfully tried PS6 '$JsonStr | Test-Json' (see commented code below); 
	#           it output a non-fatal error for json strings with binary characters
	if ($JsonStr) {
		<# if ($PsVersion -ge 6) {
			try {
				#$json_test = ($JsonStr | Test-Json)
				$powershellRepresentation = ConvertFrom-Json $JsonStr -ErrorAction Stop
			}
			catch {
				Write-Warning "Cannot parse JSON string"
				return $false
			}

			if (!$json_test) {
				return $false
			}
			
		} else {
			try {
				$powershellRepresentation = ConvertFrom-Json $JsonStr -ErrorAction Stop
			} catch {
				Write-Warning "Cannot parse JSON string"
				return $false
			}
		} #>
		try {
			$powershellRepresentation = ConvertFrom-Json $JsonStr -ErrorAction Stop
		} catch {
			#Write-Warning "Cannot parse JSON string"
			return $false
		}
	} else {
		return $false
	}
	
	return $true
}

function MakeSafeFileName() {
# PURPOSE:   To replace any sequence of forbidden chars in filename by an underscore
# PARAMS:    see param() line below
# RETURNS:   (string) modified filename
# SOURCE:    https://stackoverflow.com/a/67884741
    param(
        [object]$Data,
		[string]$ReplaceChar
    )

    process {
        $pattern = '[' + ([System.IO.Path]::GetInvalidFileNameChars() -join '').Replace('\','\\') + ']+'
        [regex]::Replace($Data, $pattern, "_")
    }
}

function ProcessDATFiles() {
# PURPOSE:   1. To gather JPG image counts for a set of DAT files. 
#            2. To extract JPG files & AI analysis JSON strings for set of DAT files (if requested).
#            3. To move to the Recycle Bin (or permanently delete) a set of DAT files (if requested).
# PARAMS:    see 'param' command below
# RETURNS:   (array of arrays) 
#            @(
#              datfiles_ary, dat_al_flags_ary, dat_imgcnts_ary, dat_imgssaved_ary, 
#              dat_confirmed_img_nos_ary, dat_confirmed_img_memos_ary,
#              dat_ai_models_ary, dat_ai_labels_ary, dat_al_memos_ary, 
#              loadats_sec, , dat_img_labels_used_ary, invalid_jpgs_cnt
#            )
# KEY POINT: JPG images in the Blue Iris DAT file are stored in reverse chronological order
# REQUIRED:  Functions...
#   FindBytes(), Convert-ByteArrayToHexString()
#   IsJpegFileValid(). IsJsonStringValid(), 
#   FindDatConfimedImageMemo(), 
#   JsonGetAiModelsAndLabels(), JsonAiModelFound(), JsonAiLabelsFound(), 
#   JsonAiNothingFoundAny(), JsonAiNothingFoundAll(), 
#   JsonAiSomethingFoundAny(), JsonAiSomethingFoundAll(), 
#   MakeSafeFileName(), DeleteDatFile(), 



	param(
		[array]$Filespecs,               # [REQUIRED] Blue Iris alert filespecs like @('{path}\DW1.20230614_070000.2520653.17-0.dat', ...)
		[boolean]$NoInspectFlg,          # disable default inspection of images & JSON in DAT files
		[int]$MinImages,                 # filter DAT files that contain N or more JPGs
		[int]$MaxImages,                 # filter DAT files that contain N or more JPGs
		[String[]]$FlagsFilter,          # filter output table for Alerts w/ specified flags, comma-delimited; like "C" or "P","!C"
		[hashtable]$AlFlagsLookupObj,    # used to check of Alert is flagged, protected, or confirmed
		[hashtable]$AlReadOnlyLookupObj, # used to check of Alert and DAT files have their read-only attributes set
		[hashtable]$AlMemoLookupObj,     # used to get Alert memos
		[string]$IfAiModel,              # filter JPGs if analyzed by a specified model
		[array]$IfAiLabels,              # filter JPGs if specified labels are confirmed (comma-delimited)
		[boolean]$IfAiNothingAnyFlg,     # filter JPGs if 'Nothing found' is a result in ANY model used
		[boolean]$IfAiNothingAllFlg,     # filter JPGs if 'Nothing found' is a result in EVERY model used
		[boolean]$IfAiSomethingAnyFlg,   # filter JPGs if JPGs have something found (any AI label) in ANY model used
		[boolean]$IfAiSomethingAllFlg,   # filter JPGs if JPGs have something found (any AI label) in EVERY model used
		[boolean]$SaveJPGsFlg,           # filter DAT files that contain N or more JPGs
		[string]$Destination,            # destination folder for extracted JPGs (default is 'C:\dat_file_utility')
		[boolean]$SingleFolderFlg,       # save JPGs to -Destination root (vs to one subfolder per DAT file)
		[boolean]$SaveJsonFlg,           # save AI Results JSON strings with associated files when using -SaveJPGs
		[boolean]$DeleteFlg,             # delete filtered DAT files to the Windows Recycle bin
		[boolean]$NoRecycleFlg,          # use w/ -DeleteFlg; PERMANENTLY deletes filtered DAT files
		[boolean]$ForceFlg,              # use w/ -DeleteFlg; remove read-only DAT files, and protected Alert DAT files"
		[boolean]$FromConsoleFlg,        # script is running from Powershell console
		[boolean]$QuietFlg,              # disables Console status messaging EXCEPT results table, warnings and return object
		[boolean]$DevModeFlg          	 # displays developer output
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host ("$fn_name() Filespecs type = " + $Filespecs.GetType())
	#Write-Host "$fn_name() Filespecs = $Filespecs"
	#Write-Host "$fn_name() NoInspectFlg = $NoInspectFlg"
	#Write-Host "$fn_name() MinImages = $MinImages"
	#Write-Host "$fn_name() MaxImages = $MaxImages"
	#Write-Host "$fn_name() FlagsFilter = $FlagsFilter"
	#Write-Host ("$fn_name() AlFlagsLookupObj type = " + $AlFlagsLookupObj.GetType())
	#Write-Host ("$fn_name() AlFlagsLookupObj = " + ($AlFlagsLookupObj | ConvertTo-Json))
	#Write-Host ("$fn_name() AlReadOnlyLookupObj type = " + $AlReadOnlyLookupObj.GetType())
	#Write-Host ("$fn_name() AlReadOnlyLookupObj = " + ($AlReadOnlyLookupObj | ConvertTo-Json))
	#Write-Host ("$fn_name() AlMemoLookupObj type = " + $AlMemoLookupObj.GetType())
	#Write-Host ("$fn_name() AlMemoLookupObj = " + ($AlMemoLookupObj | ConvertTo-Json))
	#Write-Host "$fn_name() FoundAlertMemoFlg = $FoundAlertMemoFlg"
	#Write-Host "$fn_name() SaveJPGsFlg = $SaveJPGsFlg"
	#Write-Host "$fn_name() IfAiModel = $IfAiModel"
	#Write-Host "$fn_name() IfAiLabels = $IfAiLabels"
	#Write-Host ("$fn_name() IfAiLabels cnt = " + $IfAiLabels.Count)
	#Write-Host "$fn_name() IfAiNothingAnyFlg = $IfAiNothingAnyFlg"
	#Write-Host "$fn_name() IfAiNothingAllFlg = $IfAiNothingAllFlg"
	#Write-Host "$fn_name() IfAiSomethingAnyFlg = $IfAiSomethingAnyFlg"
	#Write-Host "$fn_name() IfAiSomethingAllFlg = $IfAiSomethingAllFlg"
	#Write-Host "$fn_name() SaveJsonFlg = $SaveJsonFlg"
	#Write-Host "$fn_name() Destination = $Destination"
	#Write-Host "$fn_name() SingleFolderFlg = $SingleFolderFlg"
	#Write-Host "$fn_name() DeleteFlg = $DeleteFlg"
	#Write-Host "$fn_name() NoRecycleFlg = $NoRecycleFlg"
	#Write-Host "$fn_name() FromConsoleFlg = $FromConsoleFlg"
	#Write-Host "$fn_name() QuietFlg = $QuietFlg"
	
	# Validate arguments
	if (!$MinImages) {
		$MinImages = 0
	}
	if (!$MaxImages) {
		$MaxImages = 999
	}
	#Write-Host "$fn_name() Min/MaxImages = $MinImages/$MaxImages"
	if (!$SaveJPGsFlg) {
		$SaveJPGsFlg = $false
	}
	if ($Destination) {
		if (!(Test-Path -LiteralPath $Destination)) {
			$err_msg = "ERR/nonexistent destination folder ($Destination)"
			return $err_msg
		}
		$app_path = $Destination
	}
	$save_jpgs_flg = $SaveJPGsFlg
	$save_jsons_flg = $SaveJsonFlg
	$if_ai_model_arg_used = ($IfAiModel -and $IfAiModel.Length -gt 0)
	$if_ai_labels_arg_used = ($IfAiLabels -and $IfAiLabels.Length -gt 0)
	$if_ai_nothing_args_used = ($IfAiNothingAnyFlg -or $IfAiNothingAllFlg)
	$if_ai_nothing_any_arg_used = $IfAiNothingAnyFlg
	$if_ai_nothing_all_arg_used = $IfAiNothingAllFlg
	$if_ai_something_args_used = ($IfAiSomethingAnyFlg -or $IfAiSomethingAllFlg)
	$if_ai_something_any_arg_used = $IfAiSomethingAnyFlg
	$if_ai_something_all_arg_used = $IfAiSomethingAllFlg
	$if_ai_type_arg_used_flg = ($if_ai_model_arg_used -or $if_ai_labels_arg_used -or $if_ai_nothing_args_used -or $if_ai_something_args_used)
	
	#For debugging
	#Write-Host "$fn_name() save_jpgs_flg = $save_jpgs_flg"
	#Write-Host "$fn_name() if_ai_model_arg_used = $if_ai_model_arg_used"
	#Write-Host "$fn_name() if_ai_labels_arg_used = $if_ai_labels_arg_used"
	#Write-Host "$fn_name() if_ai_nothing_args_used = $if_ai_nothing_args_used"
	#Write-Host "$fn_name() if_ai_something_args_used = $if_ai_something_args_used"
	#Write-Host "$fn_name() if_ai_type_arg_used_flg = $if_ai_type_arg_used_flg"
	
	# BUILD JPG BYTE START/END MARKERS
	# ... JPG begin marker
	$hexArray = "FF", "D8", "FF", "E0"
	$search_ary1 = @()
	foreach ($hex in $hexArray) {
		$search_ary1 += [Int32]"0x$hex"
	}
	# ... JPG end marker
	$hexArray = "FF", "D9"
	$search_ary2 = @()
	foreach ($hex in $hexArray) {
		$search_ary2 += [Int32]"0x$hex"
	}

	# For debugging.
	#Write-Host "jpg data starting byte marker = $search_ary1"
	#Write-Host "jpg data ending byte marker = $search_ary2"

	# @@@ DEV
	# BUILD DAT IMAGE START BYTE MARKERS
	# ... Image start
	$hexArray = "1F", "A9"  # 0x8105
	$search_ary0 = @()
	foreach ($hex in $hexArray) {
		$search_ary0 += [Int32]"0x$hex"
	}
	#Write-Host "DAT image starting byte marker = $search_ary0"

	# Initialize return collectors
	[string[]]$rtn_dat_names_ary = @()
	[string[]]$rtn_dat_al_flags_ary = @()
	[string[]]$rtn_al_readonly_ary = @()
	[int[]]$rtn_dat_ages_ary = @()
	[int[]]$rtn_dat_imgcnts_ary = @()
	[int[]]$rtn_dat_imgssaved_ary = @()
	[string[]]$rtn_dat_confirmed_img_nos_ary = @()
	[string[]]$rtn_dat_confirmed_img_memos_ary = @()
	[string[]]$rtn_dat_ailabels_ary = @()
	[string[]]$rtn_dat_aimodels_ary = @()
	[string[]]$rtn_dat_almemos_ary = @()
	[string[]]$dat_img_labels_used_ary = @()

	# Initialize other collectors
	$deleted_files_ary = @()
	
	# Initialize vars
	$progress_bar_cntr = 0
	$filespecs_cnt = $Filespecs.Count
	$PsVersion = $PSVersionTable.PSVersion.Major
	$jpgs_processed_cntr = 0
	$invalid_jpgs_cntr = 0
	$ai_filtered_jpgs_cntr = 0
	$verbose_flg = $false  # Used in loop for output aesthetics 

	# Start resize performance timer
	$timer_load_dats = [Diagnostics.Stopwatch]::StartNew()

	# LOAD THE 'DAT' FILES
	foreach($dat_file in $Filespecs) {
		
		# Show progress bar
		if ($FromConsoleFlg) {
			if ($DeleteFlg) {
				$action = "Deleting"
			} else {
				if ($NoInspectFlg) {
					$action = "Processing"
				} else {
					$action = "Inspecting"
				}
			}
			$progress_bar_cntr++
			$WriteProgressParams = @{
				Activity         = "$action DAT files..."
				Status           = "Progress: $progress_bar_cntr of $filespecs_cnt"
				PercentComplete  = (($progress_bar_cntr / $filespecs_cnt) * 100)
			}
			Write-Progress @WriteProgressParams
		}
		
		# Initialize collectors
		$img_jsonstrs_ary = @()
		$img_jsonstrs_valid_ary = @()
		$dat_imgs_models_used_ary = @()
		$dat_imgs_lbls_found_ary = @()

		# Initialize custom object
		#  ... to track which images use which labels
		$dat_imgs_lbls_found_obj = New-Object PSObject
		#  ... Add an empty valued 'NoteProperty' to avoid errors when existence testing if labels already added
		Add-Member -InputObject $dat_imgs_lbls_found_obj -MemberType NoteProperty -Name 'xxxx' -Value @()
		# like,
		#	dat_imgs_lbls_found_obj = [
		#		"xxxx": [
		#		],
		#		"vehicle": [
		#			1,2,3,6,8
		#		],
		#		"person": [
		#			4,6,9
		#		],
		#	]
		
		# Initialize issues collectors
		$empty_jsons_ary = @()
		$empty_jsons_cntr = 0
		$invalid_jsons_ary = @()
		$invalid_jsons_cntr = 0

		if (Test-Path -LiteralPath "$dat_file") {
			
			# ... NOTE: Considerations with returned object when using CmdLet 'Get-ChildItem'
			#     REF: https://stackoverflow.com/questions/55765010/return-array-of-objects-from-get-childitem-path
			$fname = (Get-Item -LiteralPath "$dat_file").Name
			$bname = (Get-Item -LiteralPath "$dat_file").BaseName
			
			# For debugging.
			#Write-Host ("$fn_name() fname type = " + $fname.GetType())
			#Write-Host "$fn_name() fname = $fname"
			#Write-Host "$fn_name() bname = $bname"
			
			# Check flags...if Alert is flagged or protected or confirmed
			$al_is_flagged = $false
			$al_is_protected = $false
			$al_flags_ary = @()
			$db_al_flags_ary = $AlFlagsLookupObj[$fname]  # Returns 32 element bit array, like  [0,1,1,0. ,,,]

			if ($db_al_flags_ary) {

				# For debugging.
				#Write-Host ("$fn_name() AlFlagsLookupObj[$fname] = " + $db_al_flags_ary)
				#Write-Host ("$fn_name() AlFlagsLookupObj[$fname] type = " + $db_al_flags_ary.GetType())
				#Write-Host ("$fn_name() db_al_flags_ary[0] type = " + $db_al_flags_ary[0].GetType())				
				
				if ($FlagsFilter.Count -gt 0) {
					$skip_to_next_dat = $false
					$arr = @()
					if ($db_al_flags_ary[1] -eq 1) {  # Flagged @(0,1,0,0...)
						$arr += 'F'
					}
					if ($db_al_flags_ary[28] -eq 1) {  # Confirmed
						$arr += 'C'
					}
					if ($db_al_flags_ary[2] -eq 1) {  # Protected @(0,0,1,0...)
						$arr += 'P'
					}

					# For debugging.
					#Write-Host "$fn_name() this DAT's flags arr = $arr"

					foreach ($flag in $FlagsFilter) {
						if ($flag.StartsWith('!')) {
							if ($arr -contains $flag.TrimStart('!')) {
								$skip_to_next_dat = $true
								break
							}
						} else {
							if (!($arr -contains $flag)) {
								$skip_to_next_dat = $true
								break
							}
						}				
					}

					# For debugging.
					#Write-Host "$fn_name() skip_to_next_dat = $skip_to_next_dat"
				
					if ($skip_to_next_dat) {
						continue
					}
					
				}

				if ($db_al_flags_ary[1] -eq 1) {  # Flagged @(0,1,0,0...)
					$al_is_flagged = $true
					$al_flags_ary += 'F'
				} else {
					$al_flags_ary += ''
				}
				if ($db_al_flags_ary[28] -eq 1) {  # Confirmed
					$al_flags_ary += 'C'
				} else {
					$al_flags_ary += ''
				}
				if ($db_al_flags_ary[2] -eq 1) {  # Protected @(0,0,1,0...)
					$al_is_protected = $true
					$al_flags_ary += 'P'
				} else {
					$al_flags_ary += ''
				}
				$rtn_dat_al_flags_ary += $al_flags_ary -Join ''
			} else {
				$rtn_dat_al_flags_ary += ''
			}

			# For debugging.
			#Write-Host ("$fn_name() AlFlagsLookupObj[$fname] = " + $db_al_flags_ary)
			#Write-Host ("$fn_name() DAT's Alert isflagged = " + $al_is_protected)
			#Write-Host ("$fn_name() DAT's Alert isprotected = " + $al_is_protected)
			
			# Check read-only file attributes... if Alert DAT or JPF is read-only
			$al_readonly_str = $AlReadOnlyLookupObj[$fname]  # string like '--', 'D-', '-J', 'DJ', or 'Dx'
			if ($al_readonly_str) {
				$rtn_al_readonly_ary += $al_readonly_str
			} else {
				$rtn_al_readonly_ary += ""
			}
			
			# Get Alert's memo AI labels 
			$al_memo_ai_labels = ""  # Default
			$db_al_memo = $AlMemoLookupObj[$fname]
			if ($db_al_memo) {

				$al_memo_ai_labels = `
					ExtractAiLabels `
					-InputStr $db_al_memo

				$rtn_dat_almemos_ary += $al_memo_ai_labels
				
			} else {
				$rtn_dat_almemos_ary += $al_memo_ai_labels
			}
			
			# For debugging.
			#Write-Host ("$fn_name() AlMemoLookupObj[$fname] = " + $db_al_memo)
			
			# Populate returned array w/ DAT file age
			$file_dt = (Get-Item -LiteralPath "$dat_file").LastWriteTime
			$diff = (Get-Date).Subtract($file_dt)
			[int]$diff_hrs = [math]::Floor($diff.TotalHours)
			$rtn_dat_ages_ary += $diff_hrs
			
			if ($NoInspectFlg) {
				
				# Delete the DAT file, if requested
				if ($DeleteFlg) {	
					if (!$al_is_protected) {  # Alert is NOT protected per the database
						$result_flg = `
							DeleteDatFile `
							-DatFile $dat_file `
							-NoRecycleFlg $NoRecycleFlg `
							-Destination $Destination
							-ForceFlg $ForceFlg

						if (!$result_flg) {
							if ($FromConsoleFlg) {
								$msg = "File not deleted; DAT or Alert JPG is read-only (may be protected by Blue Iris)"
								if ($QuietFlg) {
									Write-Warning ($msg + " ($dat_file))")
								} else {
									Write-Warning $msg
								}
							}
						}
					} else {  # Alert is protected per the database
						if ($FromConsoleFlg) {
							$msg = "File not deleted; Alert is flagged as 'Protected' by Blue Iris"
							if ($QuietFlg) {
								Write-Warning ($msg + " ($dat_file))")
							} else {
								Write-Warning $msg
							}
						}
					}
				}
				
				$rtn_dat_names_ary += $fname
				#$rtn_dat_ages_ary += -1  # Already assigned above
				$rtn_dat_imgcnts_ary += -1  # [int] array; cannot accept string, like "skipped" or 'NA"
				$rtn_dat_aimodels_ary += "skipped"
				$rtn_dat_ailabels_ary += "skipped"
				$dat_img_labels_used_ary += "skipped"

			} else {											
				
				# Provide feedback
				if ($FromConsoleFlg -and !$QuietFlg) {
					if ($if_ai_type_arg_used_flg) {
						Write-Host "`nAI inspecting $progress_bar_cntr/$filespecs_cnt - $fname ..."
					} else {
						if ($verbose_flg) {
							Write-Host ""
						}
						if ($DeleteFlg) {
							Write-Host "Deleting file $progress_bar_cntr/$filespecs_cnt - $fname ..."
						} else {
							Write-Host "`nInspecting $progress_bar_cntr/$filespecs_cnt - $fname ..."
						}
					}
				}
				
				$verbose_flg = $false  # Reset

				# Import the DAT file
				if ($PsVersion -ge 7) {
					# Ref: https://stackoverflow.com/a/63782608/13499984
					#$bytes = Get-Content -Path "$dat_file" -AsByteStream -Raw
					$bytes = Get-Content -Path "$dat_file" -AsByteStream -Raw 4>$null
				} else {
					$bytes = Get-Content -Path "$dat_file" -Encoding Byte -Raw
				}
				$bytes_cnt = $bytes.Count

				# For debugging
				#Write-Host ("$fn_name() bytes type = " + $bytes.GetType())
				#Write-Host ("$fn_name() bytes len = " + $bytes_cnt)
				#Write-Host "$fn_name() bytes = $bytes"
					
				# Find image start/end indices for all images in the DAT files
				# ... expect $jpg_SOI_mrk_idxs like '25 113202'
				# ...        $jpg_EOI_mrk_idxs like '113054 227880'
				$jpg_SOI_mrk_idxs = `
					FindBytes `
					-Bytes $bytes `
					-Search $search_ary1 `
					-Start 0 `
					-All

				$jpg_SOI_mrk_idxs_cnt = $jpg_SOI_mrk_idxs.Count

				$jpg_EOI_mrk_idxs = `
					FindBytes `
					-Bytes $bytes `
					-Search $search_ary2 `
					-Start 0 `
					-All
					
				$jpg_EOI_mrk_idxs_cnt = $jpg_EOI_mrk_idxs.Count

				# For debugging.
				#Write-Host "$fn_name() dat image start indices = $dat_img_start_mrk_idxs"
				#Write-Host "$fn_name() jpg data start indices (SOI) = $jpg_SOI_mrk_idxs"
				#Write-Host "$fn_name() jpg data end indices (EOI) = $jpg_EOI_mrk_idxs"
				
				# VALIDATE EXPECTED STRUCTURE DEFINITION FOR DAT FILE
				$bad_DAT_file_flg = $false

				# ... 1. Test for non-strictly increasing markers
				$i = 0
				foreach ($jpg_SOI_mrk_idx in $jpg_SOI_mrk_idxs) {
					if ($i -gt 0) {
						# Starting with the 2nd found image, we expect its start marker index to be 
						# greater than the previous found image's end marker index
						# ... for images:                      img1,   img2,   img3, ...
						# ... expect $jpg_SOI_mrk_idxs like '    25, 113202, 228028, ...'
						# ...        $jpg_EOI_mrk_idxs like '113054, 227880, ...'
						if ($jpg_SOI_mrk_idx -le $jpg_EOI_mrk_idxs[$i - 1]) {
							$bad_DAT_file_flg = $true
							break
						}
					}
				}

				# ... 2. Test for unexpected structure
				# ...    we expect both sets of markers to have the same number of elements
				if (!$bad_DAT_file_flg) {  # Not bad yet!
					if ($jpg_SOI_mrk_idxs_cnt -ne $jpg_EOI_mrk_idxs_cnt) {
						if ($FromConsoleFlg) {
							$verbose_flg = $true
							if ($QuietFlg) {
								Write-Host ""  # Prettier output
							}
							Write-Warning "'$fname' has an unexpected structure [unbalanced JPG beg/end markers]"
							Write-Warning "- $jpg_SOI_mrk_idxs_cnt 'beg marker' indices = $jpg_SOI_mrk_idxs"
							Write-Warning "- $jpg_EOI_mrk_idxs_cnt 'end marker' indices = $jpg_EOI_mrk_idxs"
						}
				
						# Try to repair DAT file marker arrays before giving up
						if ($jpg_EOI_mrk_idxs_cnt -ne $jpg_SOI_mrk_idxs_cnt) {
							$result_flg, $SOI_mrk_idxs_ary, $EOI_mrk_idxs_ary = `
								RepairDatFile `
								-Bytes $bytes `
								-BegOfImageMarks $jpg_SOI_mrk_idxs `
								-EndOfImageMarks $jpg_EOI_mrk_idxs
								
							# For debugging
							#Write-Host "result_flg = $result_flg"

							if ($result_flg) {
								$jpg_SOI_mrk_idxs = $SOI_mrk_idxs_ary
								$jpg_EOI_mrk_idxs = $EOI_mrk_idxs_ary
								$jpg_SOI_mrk_idxs_cnt = $SOI_mrk_idxs_ary.Count
								$jpg_EOI_mrk_idxs_cnt = $EOI_mrk_idxs_ary.Count

								if ($FromConsoleFlg) {
									if ($jpg_SOI_mrk_idxs_cnt -gt $jpg_EOI_mrk_idxs_cnt) {
										Write-Host "REPAIRED 'beg marker' indices: now = $jpg_SOI_mrk_idxs"
									} else {
										Write-Host "REPAIRED 'end marker' indices; now = $jpg_EOI_mrk_idxs"
									}
								}
							}
						}
					}
				} else {
					if ($FromConsoleFlg -and $Filespecs.Count -eq 1) {
						$verbose_flg = $true
						if ($QuietFlg) {
							Write-Host ""  # Prettier output
						}
						Write-Warning ("counts of jpg marker start/end indices = " +  $jpg_SOI_mrk_idxs_cnt + "/" +  $jpg_EOI_mrk_idxs_cnt)
						Write-Warning "- $jpg_SOI_mrk_idxs_cnt 'beg marker' indices = $jpg_SOI_mrk_idxs"
						Write-Warning "- $jpg_EOI_mrk_idxs_cnt 'end marker' indices = $jpg_EOI_mrk_idxs"
					}
				}
				
				if (!$bad_DAT_file_flg) {

					# DAT FILE STRUCTURE IS GOOD (LOOKS AS EXPECTED)

					if ($jpg_SOI_mrk_idxs_cnt -gt 0) {
						
						# DAT FILE HAS AT LEAST ONE JPG FILE

						# Initialize
						#$dat_file_bkeys_ary = @()
						$dat_file_used_models_ary = @()
						$dat_file_found_labels_ary = @()
						$df_if_ai_model_success_flg = $false
						$df_if_ai_model_cntr = 0
						$df_if_ai_labels_success_flg = $false
						$df_if_ai_labels_cntr = 0
						$df_if_ai_nothing_any_success_flg = $false
						$df_if_ai_nothing_any_cntr = 0
						$df_if_ai_nothing_all_success_flg = $false
						$df_if_ai_nothing_all_cntr = 0
						$df_if_ai_something_any_success_flg = $false
						$df_if_ai_something_any_cntr = 0
						$df_if_ai_something_all_success_flg = $false
						$df_if_ai_something_all_cntr = 0
						
						# Filter number of images
						if (($jpg_SOI_mrk_idxs_cnt -ge $MinImages) -and ($jpg_SOI_mrk_idxs_cnt -le $MaxImages)) {
							
							# Initialize vars
							$dat_images_cnt = $jpg_SOI_mrk_idxs_cnt
							$invalid_jpgs_cntr = 0
							[String[]]$confirmed_img_no_ary = @()
							[String[]]$confirmed_img_memo_ary = @()

							# =======================================================
							# EXTRACT ALL N JSON STRINGS (TO AN STRING ARRAY) - 1 PER JPG IMAGE
							# ... FROM EACH JSON STRING, EXTRACT THE AI MODELS USED AND LABELS FOUND (TO STRING ARRAYS)
							# @@@ UNDER DEVELOPMENT @@@ ALSO EXTRACT 2-N bkey VALUES (TRUE = THE AI STARRED IMAGE)
							
							#$bkey_beg_idxs = @()
							$i = 0
							foreach ($jpg_SOI_mrk_idx in $jpg_SOI_mrk_idxs) {

								# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
								# EXTRACT THE ACCOMPANYING AI RESULTS JSON STRINGS
								# ... per Blue Iris Support, "after the bitmap there are 2 QWORDs (8 bytes each), 
								#     then the STRING for the JSON"

								# Get start/end indices of DWORD holding json string's LENGTH 
								$json_len_beg_idx = ($jpg_EOI_mrk_idxs[$i] + 1) + 2*8 + 1   # 2 QWORDS (8 bytes)
								$json_len_end_idx = $json_len_beg_idx + 1*4 - 1             # 1 DWORD  (4 bytes)
								$json_len_bytes = [byte[]]$bytes[$json_len_beg_idx..$json_len_end_idx]
								$json_len = [bitconverter]::ToInt16($json_len_bytes,0)
																
								# Get start/end indices of the json string itself
								$json_beg_idx = $json_len_beg_idx + 1*4
								$json_end_idx = $json_beg_idx + 2*$json_len -1
								$json_bytes = $bytes[$json_beg_idx..$json_end_idx]
								
								# CONVERT JSON BYTE ARRAY TO A HEX STRING
								$json_hex_str = `
									Convert-ByteArrayToHexString `
									-ByteArray $json_bytes
								$json_hex_str_no_nulls = $json_hex_str.Replace(",0x00","")

								# For debugging
								#Write-Host "$fn_name() json_str BEFORE = $json_hex_str_no_nulls"

								# MAKE THE JSON STRING
								# ... by encoding the hex bytes
								$img_json_str = [System.Text.Encoding]::UTF8.GetString($json_hex_str_no_nulls.Split(','))
								# ... should look like: 
								<# [{"api":"ipcam-general","found":{"success":true,"predictions":[{"confidence":0.48438695073127747,"label":"vehicle","x_min":71,"y_min":42,"x_max":146,"y_max":90},{"confidence":0.519202709197998,"label":"person","x_min":194,"y_min":32,"x_max":213,"y_max":92},{"confidence":0.7803327441215515,"label":"vehicle","x_min":308,"y_min":16,"x_max":418,"y_max":62},{"confidence":0.8269557952880859,"label":"vehicle","x_min":240,"y_min":32,"x_max":350,"y_max":82},{"confidence":0.8934379816055298,"label":"vehicle","x_min":0,"y_min":48,"x_max":76,"y_max":110},{"confidence":0.9408416748046875,"label":"vehicle","x_min":242,"y_min":59,"x_max":420,"y_max":147}],"processMs":57,"inferenceMs":55,"analysisRoundTripMs":65}}]
								#>
								
								# Just-in-case... trim any null-terminators
								$img_json_str = $img_json_str.Trim([char]0)
								$img_json_len = $img_json_str.length
								# KEY POINT: 
								# This was a BIG DEAL when running this script in Powershell-ISE (PS5) (PS7 had no problem).
								# Until I discovered this was happening, random terminal null characters were causing var $img_json_str  
								# to be regarded as INVALID when used with Cmdlets 'CovertFrom-Json' and 'CovertTo-Json'

								# For debugging
								#Write-Host "$fn_name() jpg_filespec = $jpg_filespec"
								#Write-Host "$fn_name() json_beg_idx = $json_beg_idx"
								#Write-Host "$fn_name() json_end_idx = $json_end_idx"
								#Write-Host "$fn_name() img_json len = $img_json_len"
								#Write-Host ("$fn_name() img_json_str type = " + $img_json_str.GetType())
								#Write-Host "$fn_name() img_json_str = $img_json_str"

								# Validate the JSON string
								# ... test #1
								if ($img_json_len -eq 0) {
									$empty_jsons_cntr++
									$empty_jsons_ary += "img" + ($dat_images_cnt - $i).ToString()

								# ... test #2
								} else {

									$json_is_valid = `
										IsJsonStringValid `
										-JsonStr $img_json_str
									
									if (!$json_is_valid) {
										$invalid_jsons_cntr++
										$invalid_jsons_ary += "img" + ($dat_images_cnt - $i).ToString()
									}	
								}
								
								# Make unique list AI models AND labels found in this DAT file
								if ($json_is_valid) {							
									$img_used_models_ary, $img_found_labels_ary = `
										JsonGetAiModelsAndLabels `
										-JsonStr $img_json_str
										
									# For debugging
									#Write-Host ("$fn_name() img_used_models_ary type = " + $img_used_models_ary.GetType())
									#Write-Host "$fn_name() img_used_models_ary = $img_used_models_ary"
									#Write-Host ("$fn_name() img_found_labels_ary type = " + $img_found_labels_ary.GetType())
									#Write-Host "$fn_name() img_found_labels_ary = $img_found_labels_ary"
									
									if ($img_used_models_ary.Count -gt 0) {
										foreach($m in $img_used_models_ary) {
											if ($shorten_model_name) {
												$x = $m.Replace('ipcam-',$shorten_model_name)
												if (!($dat_imgs_models_used_ary -contains $x)) {
													$dat_imgs_models_used_ary += $x
												}
											} else {
												if (!($dat_imgs_models_used_ary -contains $m)) {
													$dat_imgs_models_used_ary += $m
												}
											}
										}
									}
									if ($img_found_labels_ary.Count -gt 0) {
										foreach($lbl in $img_found_labels_ary) {
											if (!($dat_imgs_lbls_found_ary -contains $lbl)) {
												$dat_imgs_lbls_found_ary += $lbl
											}
											#  Track which images use which labels
											if (!($dat_imgs_lbls_found_obj.PSobject.Properties.Name -contains $lbl)) {
												# Add $lbl as new 'Name' property in custom object
												Add-Member -InputObject $dat_imgs_lbls_found_obj -MemberType NoteProperty -Name $lbl -Value @()
											}
											$img_no = $dat_images_cnt - $i
											$dat_imgs_lbls_found_obj.$lbl += $img_no
										}
									}
								}

								# Add to collectors
								$img_jsonstrs_ary += $img_json_str
								$img_jsonstrs_valid_ary += $json_is_valid
								$i++
							}
							
							# For debugging
							#Write-Host ("img_jsonstrs_ary cnt = " + $img_jsonstrs_ary.Count)
							#Write-Host ("img_jsonstrs_ary = " + ($img_jsonstrs_ary -Join ' ///// '))

							$dat_file_used_models_ary_cnt  = $dat_imgs_models_used_ary.Count
							$dat_file_found_labels_ary_cnt = $dat_imgs_lbls_found_ary.Count
							
							# ID CONFIRMED IMAGE
							# @@@ DEV - Using function xxx() instead
							<# $arr = `
								IdDatConfirmedImage `
								-JsonStrs $img_jsonstrs_ary #>
								
							# For debugging
							#Write-Host ("DAT confirmed image #" + $arr[0])
							#Write-Host ("DAT confirmed image AI results = " + $arr[1])
							
							# Remove placeholder 'Name' property 'xxxx'
							$dat_imgs_lbls_found_obj.PSObject.Properties.Remove('xxxx')

							# Add to collectors
							$rtn_dat_names_ary += $fname
							$rtn_dat_imgcnts_ary += $dat_images_cnt
							$rtn_dat_aimodels_ary += $dat_imgs_models_used_ary -Join ' '
							$rtn_dat_ailabels_ary += $dat_imgs_lbls_found_ary -Join ' '
							
							# Make output string for labels used
							$dat_img_labels_str_ary = @()
							foreach ($item in $dat_imgs_lbls_found_obj.PSObject.Properties) {
								$tmp_ary = $item.Value
								[array]::Reverse($tmp_ary)
								#$dat_img_labels_str_ary += $item.Name + "(imgs:" + ($tmp_ary -Join ",") + ")"
								$dat_img_labels_str_ary += $item.Name + "(" + ($tmp_ary -Join ",") + ")"
							}
							$dat_img_labels_used_str = $dat_img_labels_str_ary -Join ","
							$dat_img_labels_used_ary += $dat_img_labels_used_str
								
							# For debugging
							#Write-Host "$fn_name() rtn_dat_imgcnts_ary = $rtn_dat_imgcnts_ary"
							#Write-Host ("$fn_name() img_jsonstrs_ary cnt = " + $img_jsonstrs_ary.Count)
							#Write-Host "$fn_name() img_jsonstrs_ary = $img_jsonstrs_ary"
							#Write-Host "$fn_name() img_jsonstrs_valid_ary = $img_jsonstrs_valid_ary"
							#Write-Host ("$fn_name() dat_imgs_models_used_ary type = " + ($dat_imgs_models_used_ary.GetType()))
							#Write-Host ("$fn_name() dat_imgs_models_used_ary cnt = " + $dat_imgs_models_used_ary.Count)
							#Write-Host "$fn_name() dat_imgs_models_used_ary = $dat_imgs_models_used_ary"
							#Write-Host ("$fn_name() dat_imgs_lbls_found_ary type = " + ($dat_imgs_lbls_found_ary.GetType()))
							#Write-Host ("$fn_name() dat_imgs_lbls_found_ary cnt = " + $dat_imgs_lbls_found_ary.Count)
							#Write-Host "$fn_name() dat_imgs_lbls_found_ary = $dat_imgs_lbls_found_ary"
							#Write-Host ("$fn_name() dat_imgs_lbls_found_obj = " + ($dat_imgs_lbls_found_obj | ConvertTo-Json))
							#Write-Host "$fn_name() dat_img_labels_used_str = $dat_img_labels_used_str"
							
							# Provide feedback on requested filters
							if ($FromConsoleFlg -and !$QuietFlg) {
								if ($dat_imgs_models_used_ary.Count -gt 0) {
									Write-Host ("AI: Models used by DAT: " + ($dat_imgs_models_used_ary -Join ","))
								} else {
									Write-Host "AI: Models used by DAT: -none-"												
								}
								if ($dat_imgs_models_used_ary.Count -gt 0) {
									Write-Host ("AI: Labels found in DAT's imgs: " + $dat_img_labels_used_str)
								} else {
									Write-Host "AI: labels found in DAT's imgs: -none-"												
								}
								if ($if_ai_model_arg_used) {
									Write-Host "AI: Target Model: $IfAiModel"
								}
								if ($if_ai_labels_arg_used) {
									Write-Host "AI: Seeking imgs w/ Label(s): $IfAiLabels"
								}
								if ($if_ai_nothing_any_arg_used) {
									if ($if_ai_model_arg_used) {
										Write-Host "AI: Seeking imgs w/ 'Nothing found' results in Target Model '$IfAiModel'"
									} else {
										Write-Host "AI: Seeking imgs w/ 'Nothing found' results in ANY Model used"
									}
								}
								if ($if_ai_nothing_all_arg_used) {
									if ($if_ai_model_arg_used) {
										Write-Host "AI: Seeking imgs w/ 'Nothing found' results in Target Model '$IfAiModel'"
									} else {
										Write-Host "AI: Seeking imgs w/ 'Nothing found' results in EVERY Model used"
									}
								}
								if ($if_ai_something_any_arg_used) {
									if ($if_ai_model_arg_used) {
										Write-Host "AI: Seeking imgs w/ 'Something found' (any Label) in Target Model '$IfAiModel'"
									} else {
										Write-Host "AI: Seeking imgs w/ 'Something found' (any Label) in ANY Model used"
									}
								}
								if ($if_ai_something_all_arg_used) {
									if ($if_ai_model_arg_used) {
										Write-Host "AI: Seeking imgs w/ 'Something found' (any Label) in Target Model '$IfAiModel'"
									} else {
										Write-Host "AI: Seeking imgs w/ 'Something found' (any Label) in EVERY Model used"
									}
								}
							}

							# For debugging
							#Write-Host ("rtn_dat_names_ary cnt = " + $rtn_dat_names_ary.Count)
							#Write-Host "rtn_dat_names_ary = $rtn_dat_names_ary"
							#Write-Host "rtn_dat_imgcnts_ary = $rtn_dat_imgcnts_ary"
							#Write-Host "rtn_dat_aimodels_ary = $rtn_dat_aimodels_ary"
							#Write-Host "rtn_dat_ailabels_ary = $rtn_dat_ailabels_ary"

							# Create the extraction folder (if necessary)
							if ($save_jpgs_flg -or $save_jsons_flg) {
								# NOTE: Cmdlet 'New-Item' returns the item that it creates.
								#       REF: https://tinyurl.com/5n78mbvt (scroll to section 'Outputs')
								# KEY POINT: To avoid returning the Cmdlet's output IN ADDITION TO the return variable, 
								#       we must direct the cmdlet's output to $null
								# 		LEARN MORE: https://powershell.one/code/9.html
								if ($SingleFolderFlg) {
									$jpg_path = "$Destination\SingleFolder"
								} else {
									$jpg_path = "$Destination\$fname"
									if (!(Test-Path -LiteralPath "$jpg_path")) {
										New-Item -ItemType Directory -Force -Path "$jpg_path" | Out-Null
									} else {
										# Remove exiting items
										Remove-Item -Path ($jpg_path + "\" + "*.jpg")
										Remove-Item -Path ($jpg_path + "\" + "*.json")
									}
								}
								
								# For debugging
								#Write-Host "jpg_path - $jpg_path"
								
							}

							# =======================================================
							# EXTRACT IMAGE AND SAVE AS JPG FILES, 
							# ... ALSO SAVE ALREADY EXTRACTED JSON STRINGS AS *.json FILES
							
							$jpgs_cntr = 0
							$jsons_cntr = 0
							$empty_imgs_ary = @()
							$empty_imgs_cntr = 0
							$invalid_imgs_ary = @()
							$invalid_imgs_cntr = 0
							$dat_memo_str_found_flg = $false

							$i = 0
							foreach ($jpg_SOI_mrk_idx in $jpg_SOI_mrk_idxs) {
								
								$img_bounding_idx1 = $jpg_SOI_mrk_idx
								$img_bounding_idx2 = $jpg_EOI_mrk_idxs[$i] + 1  # Include the EOI marker!

								# For testing (create *.jpg files without the expected EOI marker)
								#$img_bounding_idx2 = $jpg_EOI_mrk_idxs[$i]

								$img_bytes = $bytes[$img_bounding_idx1..$img_bounding_idx2]
								$img_bytes_cnt = $img_bytes.Count
								
								if ($img_bytes_cnt -gt 0) {
									
									$jpgs_processed_cntr++

									# Build JPG's base filespec
									$img_no = $dat_images_cnt - $i  # Reminder: JPGS are stored in reverse order chronologically
									$img_no_sfx = ([string]$img_no).PadLeft(2,'0')
									if ($SingleFolderFlg) {
										$jpg_filespec = "$jpg_path\$bname.$img_no_sfx.jpg"
									} else {
										$jpg_filespec = "$jpg_path\img$img_no_sfx.jpg"
									}
									
									# Make label for feedback for ifAi type params 
									$img_lbl = "img" + $img_no.ToString()

								
									# For debugging
									#Write-Host ("`n_____ image " + $img_no_sfx + " (" + $img_bytes_cnt + " bytes)_____")
							
									# =======================================================
									# FIND THE CONFIRMED IMAGE AND ITS MEMO

									# -----------------------------------
									# APPROACH #1 - ABORTED 2024-01-19 
									# RETAIN THIS CODE FOR POSSIBLE FUTURE USE
									# Attempt to get each images 'bkey' value  [boolean]

									# Find image start/end indices for all image SIZES in the DAT file
									<# $hexArray = "2E", "00", "6A", "00", "70", "00", "67", "00"  # '.jpg'
									$search_ary = @()
									foreach ($hex in $hexArray) {
										$search_ary += [Int32]"0x$hex"
									}
									
									$img_size_bounding_idxs = `
										FindBytes `
										-Bytes $bytes_after `
										-Search $search_ary `
										-Start 0

									if ($img_size_bounding_idxs.Count -gt 0) {
										$img_size_bounding_idx1 = $img_size_bounding_idxs[0] + $search_ary.Count + 2
										$img_size_bounding_idx2 = $img_size_bounding_idx1 + 1
										$img_size_bytes = $bytes_after[$img_size_bounding_idx1..$img_size_bounding_idx2]
									} else {
										$img_size_bounding_idx1 = 0
										$img_size_bounding_idx2 = 0
										$img_size_bytes = @(0,0)
									} #>
									
									# For debugging
									#Write-Host "search_ary = $search_ary"
									#Write-Host "$img_no_sfx : img_size_bounding_idx1 = $img_size_bounding_idx1, img_size_bounding_idx2 = $img_size_bounding_idx2"
									#Write-Host "$img_no_sfx : img_size_bytes = $img_size_bytes"
									# -----------------------------------
									
									# APPROACH #2
									# Identify the image with a 'memo' like string
									# e.g., 'person:93$,vehicle:53%'

									# GET BYTES AFTER JPG IMAGES
									if ($i -eq $jpg_SOI_mrk_idxs_cnt - 1) {
										$after_bounding_idx1 = $jpg_EOI_mrk_idxs[$i] + 2
										$after_bounding_idx2 = $bytes.Count - 1
									} else {
										if ($i -eq 0) {
											# Get text before the final image
											$before_bounding_idx1 = 0
											$before_bounding_idx2 = $jpg_SOI_mrk_idxs[$i] - 1
											$bytes_before = $bytes[$before_bounding_idx1..$before_bounding_idx2]
											$bytes_before_cnt = $bytes_before.Count
											$bytes_before_as_str = [System.Text.Encoding]::UTF8.GetString($bytes_before)
											$bytes_before_as_clean_str = $bytes_before_as_str -creplace '\P{IsBasicLatin}'
										} 
										$after_bounding_idx1 = $jpg_EOI_mrk_idxs[$i] + 2
										$after_bounding_idx2 = $jpg_SOI_mrk_idxs[$i+1] - 1
									}
									$bytes_after = $bytes[$after_bounding_idx1..$after_bounding_idx2]
									$bytes_after_cnt = $bytes_after.Count
									$bytes_after_as_str = [System.Text.Encoding]::UTF8.GetString($bytes_after)
									# Remove any non-ASCII characters from the LHS string,
									# (this includes problematic hidden control characters)
									$bytes_after_as_clean_str = $bytes_after_as_str -creplace '\P{IsBasicLatin}'

									# For debugging
									if ($i -eq 0) {
										<# Write-Host "$img_no_sfx : before_bounding_idx1 = $before_bounding_idx1, before_bounding_idx2 = $before_bounding_idx2"
										Write-Host ("$img_no_sfx : bytes_before cnt = " + $bytes_before_cnt)
										#Write-Host ("$img_no_sfx : bytes_before = " + $bytes_before)
										Write-Host ("$img_no_sfx : bytes_before as string = " + $bytes_before_as_str)
										#Write-Host ("$img_no_sfx : bytes_before as 'clean' string = " + $bytes_before_as_clean_str) #>
									}
									<# Write-Host "$img_no_sfx : img_bounding_idx1 = $img_bounding_idx1, img_bounding_idx2 = $img_bounding_idx2"
									Write-Host "$img_no_sfx : after_bounding_idx1 = $after_bounding_idx1, after_bounding_idx2 = $after_bounding_idx2"
									Write-Host ("$img_no_sfx : bytes_after cnt = " + $bytes_after_cnt)
									#Write-Host ("$img_no_sfx : bytes_after[0] = " + $bytes_after[0])
									#Write-Host ("$img_no_sfx : bytes_after[" + ($bytes_after_cnt - 1) + "] = " + $bytes_after[$bytes_after_cnt - 1])
									#Write-Host ("$img_no_sfx : bytes_after = " + $bytes_after)
									#Write-Host ("`n$img_no_sfx : bytes_after as string = `n" + $bytes_after_as_str)
									Write-Host ("`n$img_no_sfx : bytes_after as 'clean' string = `n" + $bytes_after_as_clean_str) #>
									
									$memo_str = `
										FindDatConfimedImageMemo `
										-Bytes $bytes_after
											
									if ($memo_str) {
										if ($FromConsoleFlg -and !$Quiet) {
											$confirmed_img_no_ary += $img_no
											$confirmed_img_memo_ary += $memo_str
											$dat_memo_str_found_flg = $true
											Write-Host "possible confirmed image found #$img_no_sfx (w/ memo-like string: string: '$memo_str'"
										}
									}
											
									
									# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

									# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
									# ANALYZE JSON strings	
									
									$img_json_str = $img_jsonstrs_ary[$i]
									$json_is_valid = $img_jsonstrs_valid_ary[$i]

									# Initialize test flags
									$if_ai_flg1  = $false  # IfAiModel result
									$if_ai_flg2  = $false  # IfAiLabels result
									$if_ai_flg3a = $false  # IfAiNothingAny result
									$if_ai_flg3b = $false  # IfAiNothingAll result
									$if_ai_flg4a = $false  # IfAiSomethingAny result
									$if_ai_flg4b = $false  # IfAiSomethingAll result

									# Initialize collectors
									$found_nothing_models_ary = @()
									$found_something_models_ary = @()

									if ($json_is_valid) {						
																					
										# As requested, do the following AI filter tests for every image in the DAT file

										# ... Check #1
										if ($if_ai_model_arg_used) {

											if (!$if_ai_nothing_any_arg_used -and !$if_ai_nothing_all_arg_used -and !$if_ai_something_any_arg_used -and !$if_ai_something_all_arg_used) {

												$if_ai_flg1 = `
													JsonAiModelFound `
													-JsonStr $img_json_str `
													-Model $IfAiModel
											}
										}
										
										# ... Check #2
										if ($if_ai_labels_arg_used) {
											$if_ai_flg2, $if_ai_lbls, $if_ai_lbls_models_obj = `

												JsonAiLabelsFound `
												-JsonStr $img_json_str `
												-Labels $IfAiLabels `
												-Model $IfAiModel
												
											$tmp_ary = @()
											foreach ($lbl in $IfAiLabels) {
												$models = $if_ai_lbls_models_obj.$lbl
												if ($models.Count -gt 0) {
													$models_str = $models -Join "; "
												} else {
													$models_str = "none"
												}
												$tmp_ary += ($lbl + ":" + $models_str)
											}
											$if_ai_lbls_models_str = $tmp_ary -Join ";"
										}

										# ... Check #3a
										if ($if_ai_nothing_any_arg_used) {
											
											$if_ai_flg3a, $found_nothing_models_ary = `
												JsonAiNothingFoundAny  `
												-JsonStr $img_json_str `
												-Model $IfAiModel
												
											$found_nothing_models_ary_cnt = $found_nothing_models_ary.Count
											$found_nothing_models_str = $found_nothing_models_ary -Join ","
										}

										# ... Check #3b
										if ($if_ai_nothing_all_arg_used) {
											
											$if_ai_flg3b, $found_nothing_models_ary = `
												JsonAiNothingFoundAll  `
												-JsonStr $img_json_str `
												-Model $IfAiModel
												
											$found_nothing_models_ary_cnt = $found_nothing_models_ary.Count
											$found_nothing_models_str = $found_nothing_models_ary -Join ","
										}

										# ... Check #4a
										if ($if_ai_something_any_arg_used) {
											
											$if_ai_flg4a, $found_something_models_ary = `
												JsonAiSomethingFoundAny  `
												-JsonStr $img_json_str `
												-Model $IfAiModel

											$found_something_models_ary_cnt = $found_something_models_ary.Count
											$found_something_models_str = $found_something_models_ary -Join ","

										}
										# ... Check #4b
										if ($if_ai_something_all_arg_used) {
											
											$if_ai_flg4b, $found_something_models_ary = `
												JsonAiSomethingFoundAll `
												-JsonStr $img_json_str `
												-Model $IfAiModel

											$found_something_models_ary_cnt = $found_something_models_ary.Count
											$found_something_models_str = $found_something_models_ary -Join ","
										}
									}
									
									# For debugging										
									#Write-Host "$fn_name() $dat_file, $img_lbl"
									#Write-Host "$fn_name() if_ai_flg1 = $if_ai_flg1"
									#Write-Host "$fn_name() models_used_ary_str = $models_used_ary_str"
									#Write-Host "$fn_name() if_ai_flg2 = $if_ai_flg2"
									#Write-Host "$fn_name() if_ai_lbls = $if_ai_lbls"
									#Write-Host ("$fn_name() if_ai_lbls_models_obj cnt = " + ($if_ai_lbls_models_obj | Measure).Count())
									#Write-Host ("$fn_name() if_ai_lbls_models_obj = " + ($if_ai_lbls_models_obj | ConvertTo-Json))
									#Write-Host "$fn_name() if_ai_flg3a = $if_ai_flg3a"
									#Write-Host "$fn_name() if_ai_flg3b = $if_ai_flg3b"
									#Write-Host ("$fn_name() found_nothing_models_ary cnt = " + $found_nothing_models_ary_cnt)
									#Write-Host "$fn_name() found_nothing_models_ary = $found_nothing_models_ary"
									#Write-Host "$fn_name() if_ai_flg4a = $if_ai_flg4a"
									#Write-Host "$fn_name() if_ai_flg4b = $if_ai_flg4b"
									#Write-Host "$fn_name() found_something_models_ary cnt = $found_something_models_ary_cnt"
									#Write-Host "$fn_name() found_something_models_ary = $found_something_models_ary"
																			
									# Provide feedback for 'IfAi*' param results
									if ($dat_imgs_models_used_ary.Count -gt 0) {

										# If just -IfAiModel AND/OR -IfAiLabels
										if ($if_ai_model_arg_used -or $if_ai_labels_arg_used -and `
											!($IfAiNothingAny -or $IfAiNothingAll -or $IfAiSomethingAny -or $IfAiSomethingAll)`
										) {
											
											if ($if_ai_model_arg_used) {
												
												if (!$if_ai_labels_arg_used) {  
												
													# Param: -IfAiModel ALONE

													if ($if_ai_flg1) {
														
														$df_if_ai_model_cntr++
														
														$msg = "AI: ($img_lbl) Model ($IfAiModel) USED"
														
													} else {
														if ($img_json_str.length -eq 0) {
															$msg = "AI: ($img_lbl) unable to analyze (image's JSON string is empty)"
														} else {
															$msg = "AI: ($img_lbl) Model ($IfAiModel) NOT used"
														}
													}
													
													if ($FromConsoleFlg -and !$QuietFlg) {
														Write-Host $msg
													}

												} else {
													
													# Param: -IfAiModel WITH -IfAiLabels

													if ($if_ai_flg2) {
														
														# Param: -IfAiLabels successful
														
														$df_if_ai_labels_cntr++

														if ($if_ai_flg1) {
															$df_if_ai_model_cntr++
															$str = "(" + ($if_ai_lbls -Join ",") + ")"
															$msg = "AI: ($img_lbl) target Label(s) $str FOUND by target Model ($IFAiModel)"
														} else {
															$msg = "AI: ($img_lbl) target Label(s) NOT found by any of the Models used"
														}
														if ($FromConsoleFlg -and !$QuietFlg) {
															Write-Host $msg
														}
														
													} else {
														
														# Param: -IfAiLabels unsuccessful

														$df_if_ai_model_cntr++
														$msg = "AI: ($img_lbl) target Label(s) NOT found by target Model ($IFAiModel)"

														if ($FromConsoleFlg -and !$QuietFlg) {
															Write-Host $msg
														}
													}
												}

											} else {

												# Param: -IfAiLabels ALONE

												if ($if_ai_flg2) {
														
													$df_if_ai_labels_cntr++

													$str = ""
													$arr = @()
													foreach ($obj in $if_ai_lbls_models_obj.PSObject.Properties) {
														if (($obj.Value).Count -gt 0) {
															$arr += $obj.Name + ":" + ($obj.Value -Join ",")
														}
													}
													$sfx = "(" + ($arr -Join ",") + ")"

													if ($arr.Count -gt 0) {
														$msg = "AI: ($img_lbl) target Label(s) FOUND by 1 or more models $sfx"
													} else {
														$msg = "AI: ($img_lbl) target Label(s) NOT found by any Model(s) used"
													}
												} else {
													$msg = "AI: ($img_lbl) target Label(s) NOT found by any Model(s) used"
												}
												if ($FromConsoleFlg -and !$QuietFlg) {
													Write-Host $msg
												}
											}

										} else {

											# Param: -IfAiNothingAny|All, or -IfAiSomethingAny|All	
											
											if ($if_ai_nothing_args_used) {  

												# Params: -IfAiNothingAny & -IfAiNothingAll
											
												if ($if_ai_flg3a -or $if_ai_flg3b) {
													if ($if_ai_model_arg_used) {
														$sfx = "(" + $IfAiModel + ")"
													} else {
														$sfx = "(" + $found_nothing_models_ary + ")"
													}
													if ($shorten_model_name) {
														$sfx = $sfx.Replace("ipcam-", $shorten_model_name)
													}
													
													$found_models_ary_cnt = $found_nothing_models_ary_cnt

													# For debugging
													#Write-Host "found_nothing_models_ary = $found_nothing_models_ary"
													#Write-Host "found_models_ary_cnt = $found_models_ary_cnt"
													#Write-Host "dat_file_used_models_ary = $dat_file_used_models_ary"
													#Write-Host "dat_file_used_models_ary_cnt = $dat_file_used_models_ary_cnt"

													if ($if_ai_flg3a) {
														
														# Param: -IfAiNothingAny
																														
														$df_if_ai_nothing_any_cntr++
														
														if ($found_models_ary_cnt -eq $dat_file_used_models_ary_cnt) {
															if ($if_ai_model_arg_used) {
																$msg = ("AI: ($img_lbl) 'Nothing found' was found by the specified Model $sfx")
															} else {
																$msg = ("AI: ($img_lbl) 'Nothing found' was found by all Models used")
															}
														} else {
															if ($if_ai_model_arg_used) {
																$msg = ("AI: ($img_lbl) 'Nothing found' was found by the specified Model $sfx")
															} else {
																$msg = ("AI: ($img_lbl) 'Nothing found' was found by " + $found_models_ary_cnt + " Model(s) used $sfx")
															}
														}
													} else {  # $if_ai_flg3b=$true
													
														# Param: -IfAiNothingAll
														
														if ($found_models_ary_cnt -eq $dat_file_used_models_ary_cnt) {
															
															$df_if_ai_nothing_all_cntr++
															
															if ($if_ai_model_arg_used) {
																$msg = "AI: ($img_lbl) 'Nothing found' was found by the specified Model $sfx"
															} else {
																$msg = "AI: ($img_lbl) 'Nothing found' was found by EVERY Model used"
															}
														} else {
															if ($if_ai_model_arg_used) {
																$msg = ("AI: ($img_lbl) 'Nothing found' was found by the specified Model $sfx")
															} else {
																$msg = ("AI: ($img_lbl) 'Nothing found' was found by only " + $found_models_ary_cnt + " Models used $sfx")
															}
														}
													}
												} else {
													if ($img_json_str.length -eq 0) {
														$msg = "AI: ($img_lbl) unable to analyze (image's JSON string is empty)"
													} else {
														if ($if_ai_model_arg_used) {
															$msg = "AI: ($img_lbl) 'Nothing found' was found by NO Models used"
															#$msg = "AI: ($img_lbl) 'Nothing found' was NOT found by the specified Model $sfx"
														} else {
															$msg = "AI: ($img_lbl) 'Nothing found' was found by NO Models used"
														}
													}
												}
												if ($FromConsoleFlg -and !$QuietFlg) {
													Write-Host $msg
												}
											}
											
											if ($if_ai_something_args_used) { 

												# Params: -IfAiSomethingAny & -IfAiSomethingAll
											
												if ($if_ai_flg4a -or $if_ai_flg4b) {
													if ($if_ai_model_arg_used) {
														$sfx = "(" + $IfAiModel + ")"
													} else {
														$sfx = "(" + $found_something_models_ary + ")"
													}
													if ($shorten_model_name) {
														$sfx = $sfx.Replace("ipcam-", $shorten_model_name)
													}

													$found_models_ary_cnt = $found_something_models_ary_cnt

													# For debugging
													#Write-Host "found_something_models_ary = $found_something_models_ary"
													#Write-Host "found_models_ary_cnt = $found_models_ary_cnt"
													#Write-Host "dat_file_used_models_ary_cnt = $dat_file_used_models_ary_cnt"

													if ($if_ai_flg4a) {
														
														# Param: -IfAiSomethingAny
															
														$df_if_ai_something_any_cntr++
														
														if ($found_models_ary_cnt -eq $dat_file_used_models_ary_cnt) {
															if ($if_ai_model_arg_used) {
																$msg = ("AI: ($img_lbl) Some Label(s) were found by the Target Model $sfx")
															} else {
																$msg = ("AI: ($img_lbl) Some Label(s) were found by all Models used")
															}
														} else {
															if ($if_ai_model_arg_used) {
																$msg = ("AI: ($img_lbl) Some Label(s) were found by the Target Model $sfx")
															} else {
																$msg = ("AI: ($img_lbl) Some Label(s) were found by " + $found_models_ary_cnt + " used Model(s) $sfx")
															}
														}
														
													} else {  # $if_ai_flg4b=$true
													
														# Param: -IfAiSomethingAll
														
														if ($found_models_ary_cnt -eq $dat_file_used_models_ary_cnt) {

															$df_if_ai_something_all_cntr++
															
															if ($if_ai_model_arg_used) {
																$msg = ("AI: ($img_lbl) Some Label(s) were found by the Target Model $sfx")
															} else {
																$msg = ("AI: ($img_lbl) Some Label(s) were found by EVERY Model used")
															}
														} else {
															if ($if_ai_model_arg_used) {
																$msg = "AI: ($img_lbl) Some Label(s) were found for by the specified Model $sfx"
															} else {
																$msg = "AI: ($img_lbl) Some Label(s) were found for only " + $found_models_ary_cnt + " Model(s) used $sfx"
															}
														}
													}
												} else {
													if ($img_json_str.length -eq 0) {
														$msg = "AI: ($img_lbl) unable to analyze (image's JSON string is empty)"
													} else {
														if ($if_ai_model_arg_used) {
															$msg = ("AI: ($img_lbl) Some Label(s) were NOT found by any Models used")
															#$msg = "AI: ($img_lbl) Some Label(s) were NOT found by the specified Model $sfx"
														} else {
															$msg = ("AI: ($img_lbl) Some Label(s) were NOT found by any Models used")
														}
													}
												}
												if ($FromConsoleFlg -and !$QuietFlg) {
													Write-Host $msg
												}
											}
										}
									} else {
										if ($if_ai_type_arg_used_flg) {
											if ($FromConsoleFlg -and !$QuietFlg) {
												Write-Host "AI: ($img_lbl) Nothing to analyze"
											}
										}
									}
								
									# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
									# SAVE THE IMAGE'S JSON STRING TO FILE
									if ($save_jsons_flg) {
										if ($img_jsonstrs_valid_ary[$i]) {
											if ($SingleFolderFlg) {
												$json_filespec = "$jpg_path\$bname.$img_no_sfx.json"
											} else {
												$json_filespec = "$jpg_path\img$img_no_sfx.json"
											}

											# For debugging
											#Write-Host "$json_filespec = $json_filespec"

											$img_jsonstrs_ary[$i] | Out-File -FilePath "$json_filespec" -Encoding UTF8
											$jsons_cntr++
										}
									}
								
									# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
									# DETERMINE WHETHER TO SKIP SAVING THE JPG FILE
									
									if ($if_ai_type_arg_used_flg) {

										# Skip this jpg if param -IfAiModels results in no models found
										if ($if_ai_model_arg_used) {
											if (!$if_ai_flg1 -and !$if_ai_flg3a -and !$if_ai_flg3b -and !$if_ai_flg4a -and !$if_ai_flg4b) {
												#Write-Host "no matches to AI json results for $img_lbl"
												$i++
												continue
											}
										}

										# Skip this jpg if param -IfAiLabels results in no labels found
										if ($if_ai_labels_arg_used) {
											if (!$if_ai_flg2) {
												#Write-Host "AI: no matches to AI json results for $img_lbl"
												$i++
												continue
											}
										}

										# Skip this jpg if param -IfAiNothingAny results in no 'nothing found' 
										if ($if_ai_nothing_any_arg_used) {
											if (!$if_ai_flg3a) {
												#Write-Host "no matches to AI json results for $img_lbl"
												$i++
												continue
											}
										}

										# Skip this jpg if param -IfAiNothingAll results in no 'nothing found' 
										if ($if_ai_nothing_all_arg_used) {
											if (!$if_ai_flg3b) {
												#Write-Host "no matches to AI json results for $img_lbl"
												$i++
												continue
											} else {
												# For debugging
												#Write-Host "df_if_ai_nothing_all_cntr*** = $df_if_ai_nothing_all_cntr"
											}
										}

										# Skip this jpg if param -IfAiNothingAny results in no 'nothing found' 
										if ($if_ai_something_any_arg_used) {
											if (!$if_ai_flg4a) {
												#Write-Host "no matches to AI json results for $img_lbl"
												$i++
												continue
											}
										}

										# Skip this jpg if param -IfAiSomethingAll results in no labels found
										if ($if_ai_something_all_arg_used) {
											if (!$if_ai_flg4b) {
												#Write-Host "no matches to AI json results for $img_lbl"
												$i++
												continue
											}
										}
																		
										#Write-Host "saving jpg"
									
										# Update count of DAT files successfully filtered
										if ($if_ai_flg1 -or $if_ai_flg2 -or `
											$if_ai_flg3a -or $if_ai_flg3b -or`
											$if_ai_flg4a -or $if_ai_flg4b) `
										{
											$ai_filtered_jpgs_cntr++
										}
									}

									# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
									# SAVE THE JPG FILE TO DISK
									
									# Tweak the JPG's filespec when using AI models and/or AI labels as filters
									if ($save_jpgs_flg) {
				
										# Replace any characters that cannot used in a filename
										# Why? We use this string if saving JPG filenames
										$al_memo_ai_labels_safe = `
											MakeSafeFileName `
											-Data $al_memo_ai_labels
										
										if ($if_ai_type_arg_used_flg) {
											
											if ($if_ai_model_arg_used) {

												# Continue only if NOT also used with -IfAiLabels
												if (!$if_ai_labels_arg_used) {
													
													$xtra_sfx = ""
													if ($if_ai_flg1) {
														$xtra_sfx += " ($IfAiModel)"
													}
													if ($SingleFolderFlg) {
														$jpg_filespec = "$jpg_path\$bname.$img_no_sfx$xtra_sfx.jpg"
													} else {
														$jpg_filespec = "$jpg_path\img$img_no_sfx$xtra_sfx.jpg"
													}
												}
											}
											
											if ($if_ai_labels_arg_used) {
												
												if ($if_ai_flg2) {
													
													$xtra_sfx = ""
													
													# include labels in JPG filename
													if ($if_ai_lbls.Count -gt 0) {
														$xtra_sfx += " (" + $if_ai_lbls + ")"
													}
													
													# include models in JPG filename
													$models_ary = @()  # Initialize accumulator
													foreach ($lbl in $IfAiLabels) {
														foreach ($model in $if_ai_lbls_models_obj.$lbl) {
															if (!($models_ary -contains $model)) {
																$models_ary += $model
															}
														}
													}
													if ($models_ary.Count -gt 0) {
														$xtra_sfx += " (" + $models_ary + ")"
													}
												}
												if ($SingleFolderFlg) {
													$jpg_filespec = "$jpg_path\$bname.$img_no_sfx$xtra_sfx.jpg"
												} else {
													$jpg_filespec = "$jpg_path\img$img_no_sfx$xtra_sfx.jpg"
												}
											}
											
											if ($if_ai_nothing_args_used) {
												if ($if_ai_flg3a -or $if_ai_flg3b) {
													if ($FoundAlertMemoFlg) {															
														$xtra_sfx = " (possibly " + $al_memo_ai_labels_safe + ")"
														if ($SingleFolderFlg) {
															$jpg_filespec = "$jpg_path\$bname.$img_no_sfx$xtra_sfx.jpg"
														} else {
															$jpg_filespec = "$jpg_path\img$img_no_sfx$xtra_sfx.jpg"
														}											
													} else {
														if ($found_nothing_models_ary.Count -eq 0) {
															$xtra_sfx = " (nothing found)"
														} else {
															$xtra_sfx = " (nothing found in $found_nothing_models_str)"
														}
														if ($SingleFolderFlg) {
															$jpg_filespec = "$jpg_path\$bname.$img_no_sfx$xtra_sfx.jpg"
														} else {
															$jpg_filespec = "$jpg_path\img$img_no_sfx$xtra_sfx.jpg"
														}
													}
												}
											}
											
											if ($if_ai_something_args_used) {
												if ($if_ai_flg4a -or $if_ai_flg4b) {
													if ($FoundAlertMemoFlg) {
														$xtra_sfx = " (possibly " + $al_memo_ai_labels_safe + ")"
														if ($SingleFolderFlg) {
															$jpg_filespec = "$jpg_path\$bname.$img_no_sfx$xtra_sfx.jpg"
														} else {
															$jpg_filespec = "$jpg_path\img$img_no_sfx$xtra_sfx.jpg"
														}											
													} else {
														if ($found_something_models_ary.Count -eq 0) {
															$xtra_sfx = " (something found)"
														} else {
															$xtra_sfx = " (something found in $found_something_models_str)"
														}
														if ($SingleFolderFlg) {
															$jpg_filespec = "$jpg_path\$bname.$img_no_sfx$xtra_sfx.jpg"
														} else {
															$jpg_filespec = "$jpg_path\img$img_no_sfx$xtra_sfx.jpg"
														}
													}
												}
											}

										} else {

											if ($FoundAlertMemoFlg) {
												$xtra_sfx = " (possibly " + $al_memo_ai_labels_safe + ")"
												
												if ($SingleFolderFlg) {
													$jpg_filespec = "$jpg_path\$bname.$img_no_sfx$xtra_sfx.jpg"
												} else {
													$jpg_filespec = "$jpg_path\img$img_no_sfx$xtra_sfx.jpg"
												}
											}
										}
									
										# ======================================================================
										# NOW (FINALLY!) SAVE THE JPG
										# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
										
										# Replace invalid characters with underscore
										# REF: https://stackoverflow.com/a/52528107
										#$jpg_filespec.Split([IO.Path]::GetInvalidFileNameChars()) -Join '_'
										#$jpg_filespec.Split([IO.Path]::GetInvalidFileNameChars(),@('[',']')) -Join '_'

										# For debugging
										#Write-Host "jpg_path = $jpg_filespec"
										
										# Using next line to to avoid occasional error message
										# "Could not find a part of the path..."
										# REF: https://stackoverflow.com/a/28754238
										#New-Item -Path "$jpg_filespec" -ItemType "file" -Force | Out-Null
										
										# DO IT
										if ($PsVersion -ge 6) {
											# Ref: https://stackoverflow.com/a/63782608/13499984
											Set-Content -Path "$jpg_filespec" -Value $img_bytes -AsByteStream | Out-Null
										} else {
											Set-Content -Path "$jpg_filespec" -Value $img_bytes -Encoding Byte | Out-Null
										}

										# Confirm that the new file is a valid JPG image
										$jpg_is_valid = `
											IsJpegFileValid `
											-FilePath $jpg_filespec
											
										if (!$jpg_is_valid) {
											$invalid_imgs_cntr++
											$invalid_imgs_ary += $img_lbl
											
											# Delete the invalid file
											#Remove-Item -LiteralPath "$jpg_filespec"										
										}
										$jpgs_cntr++
									}
									# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

								} else {
									$img_no = $dat_images_cnt - $i
									$empty_imgs_cntr++
									$empty_imgs_ary += $img_lbl
								}

								$i++
								
							}  # PROCESS NEXT IMAGE

							$rtn_dat_imgssaved_ary += $jpgs_cntr 
							
							if (!$dat_memo_str_found_flg) {
								$rtn_dat_confirmed_img_nos_ary += ''
								$rtn_dat_confirmed_img_memos_ary += ''
								if ($FromConsoleFlg -and !$QuietFlg) {	
									Write-Host ("no confirmed image found (w/ memo-like string: 'label:X%')")
								}
							} else {
								$rtn_dat_confirmed_img_nos_ary += $confirmed_img_no_ary -Join ','
								$rtn_dat_confirmed_img_memos_ary += $confirmed_img_memo_ary -Join ','
							}

							# CHECK IF REMOVING DAT FROM FILE LIST 
							# ... Applies if using 'IfAi*' FILTERS WITH NEGATIVE RESULT
							
							if ($if_ai_type_arg_used_flg) {
									
								if ($df_if_ai_model_cntr -gt 0) {
									$df_if_ai_model_success_flg = $true
								}
								
								if ($df_if_ai_labels_cntr -gt 0) {
									$df_if_ai_labels_success_flg = $true
								}
								
								if ($df_if_ai_nothing_any_cntr -gt 0) {
									$df_if_ai_nothing_any_success_flg = $true
								}
								
								if ($df_if_ai_nothing_all_cntr -gt 0) {
									if ($if_ai_model_arg_used) {
										if ($df_if_ai_nothing_all_cntr -eq 1) {
											$df_if_ai_nothing_all_success_flg = $true
										}
									} else {
										if ($df_if_ai_nothing_all_cntr -eq $dat_images_cnt) {
											$df_if_ai_nothing_all_success_flg = $true
										}
									}
								}
								
								if ($df_if_ai_something_any_cntr -gt 0) {
									$df_if_ai_something_any_success_flg = $true
								}
								
								if ($df_if_ai_something_all_cntr -gt 0) {
									if ($if_ai_model_arg_used) {
										if ($df_if_ai_something_all_cntr -eq 1) {
											$df_if_ai_something_all_success_flg = $true
										}
									} else {
										if ($df_if_ai_something_all_cntr -eq $dat_images_cnt) {
											$df_if_ai_something_all_success_flg = $true
										}
									}
								}
								
								# Set flag to true when ANY 'IfAi*' filter is successful
								$if_dat_ai_args_overall_success_flg = (`
									$df_if_ai_model_success_flg -or $df_if_ai_labels_success_flg -or `
									$df_if_ai_nothing_any_success_flg -or $df_if_ai_nothing_all_success_flg -or `
									$df_if_ai_something_any_success_flg -or $df_if_ai_something_all_success_flg `
								)

								# For debugging
								#Write-Host "dat_images_cnt = $dat_images_cnt"
								#Write-Host "df_if_ai_model_cntr = $df_if_ai_model_cntr"
								#Write-Host "df_if_ai_model_success_flg = $df_if_ai_model_success_flg"
								#Write-Host "df_if_ai_labels_cntr = $df_if_ai_labels_cntr"
								#Write-Host "df_if_ai_labels_success_flg = $df_if_ai_labels_success_flg"
								#Write-Host "df_if_ai_nothing_any_cntr = $df_if_ai_nothing_any_cntr"
								#Write-Host "df_if_ai_nothing_any_success_flg = $df_if_ai_nothing_any_success_flg"
								#Write-Host "df_if_ai_nothing_all_success_flg = $df_if_ai_nothing_all_success_flg"
								#Write-Host "df_if_ai_nothing_all_cntr = $df_if_ai_nothing_all_cntr"
								#Write-Host "df_if_ai_something_any_cntr = $df_if_ai_something_any_cntr"
								#Write-Host "df_if_ai_something_any_success_flg = $df_if_ai_something_any_success_flg"
								#Write-Host "df_if_ai_something_all_cntr = $df_if_ai_something_all_cntr"
								#Write-Host "df_if_ai_something_all_success_flg = $df_if_ai_something_all_success_flg"
								#Write-Host "if_dat_ai_args_overall_success_flg = $if_dat_ai_args_overall_success_flg"

								if (!$if_dat_ai_args_overall_success_flg) {
									
									# For debugging
									#Write-Host "NOTE: DAT file excluded from the output...  $fname"
									#Write-Host ("rtn_dat_imgssaved_ary cnt BEFORE = " + $rtn_dat_imgssaved_ary.Count)
									#Write-Host "rtn_dat_imgssaved_ary BEFORE = $rtn_dat_imgssaved_ary"
									#Write-Host ("rtn_dat_almemos_ary cnt BEFORE = " + $rtn_dat_almemos_ary.Count)
									#Write-Host "rtn_dat_almemos_ary BEFORE = $rtn_dat_almemos_ary"

									# REMOVE DAT FROM ORIGINAL FILTERED FILE LIST 
									# NOTE: must convert arrays to Powershell lists to remove array elements by index

									# Get array index used by all 4 return arrays
									[Collections.Generic.List[String]]$lst = $rtn_dat_names_ary
									$idx = $lst.IndexOf($fname)  
									
									# For debugging
									#Write-Host "DAT file excluded from the output idx = $idx"

									$lst.RemoveAt($idx)									
									$rtn_dat_names_ary = [array]$lst
									
									[Collections.Generic.List[String]]$lst = $rtn_dat_al_flags_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_al_flags_ary = [array]$lst
									
									[Collections.Generic.List[String]]$lst = $rtn_al_readonly_ary
									$lst.RemoveAt($idx)									
									$rtn_al_readonly_ary = [array]$lst
									
									[Collections.Generic.List[String]]$lst = $rtn_dat_ages_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_ages_ary = [array]$lst
									
									[Collections.Generic.List[String]]$lst = $rtn_dat_imgcnts_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_imgcnts_ary = [array]$lst
									
									[Collections.Generic.List[String]]$lst = $rtn_dat_imgssaved_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_imgssaved_ary = [array]$lst
									
									[Collections.Generic.List[String]]$lst = $rtn_dat_confirmed_img_nos_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_confirmed_img_nos_ary = [array]$lst

									[Collections.Generic.List[String]]$lst = $rtn_dat_aimodels_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_aimodels_ary = [array]$lst

									[Collections.Generic.List[String]]$lst = $rtn_dat_ailabels_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_ailabels_ary = [array]$lst

									[Collections.Generic.List[String]]$lst = $rtn_dat_almemos_ary
									$lst.RemoveAt($idx)									
									$rtn_dat_almemos_ary = [array]$lst

									[Collections.Generic.List[String]]$lst = $dat_img_labels_used_ary
									$lst.RemoveAt($idx)									
									$dat_img_labels_used_ary = [array]$lst
									
									# Also remove previously saved JPG and JSON files
									if ($save_jpgs_flg -and $jpgs_cntr -gt 0) {
										$jpgs_cntr = 0
										Get-ChildItem -Path "$jpg_path\$bname*.jpg" | Remove-Item
										if ($FromConsoleFlg -and $DevModeFlg) {
											Write-Host "(dev_mode) Removed JPG files:  '$jpg_path\$bname*.jpg'..."
										}
									}
									if ($save_jsons_flg -and $jsons_cntr -gt 0) {
										$jsons_cntr = 0
										Get-ChildItem -Path "$jpg_path\$bname*.json" | Remove-Item
										if ($FromConsoleFlg -and $DevModeFlg) {
											Write-Host "(dev_mode) Removed JSON files: '$jpg_path\$bname*.json'..."
										}
									}
									
									# For debugging
									#Write-Host ("rtn_dat_names_ary cnt AFTER = " + $rtn_dat_names_ary.Count)
									#Write-Host "rtn_dat_names_ary AFTER = $rtn_dat_names_ary"
									#Write-Host ("rtn_dat_al_flags_ary cnt AFTER = " + $rtn_dat_al_flags_ary.Count)
									#Write-Host "rtn_dat_al_flags_ary AFTER = $rtn_dat_al_flags_ary"
									#Write-Host ("rtn_al_readonly_ary cnt AFTER = " + $rtn_al_readonly_ary.Count)
									#Write-Host "rtn_al_readonly_ary AFTER = $rtn_al_readonly_ary"
									#Write-Host ("rtn_dat_ages_ary cnt AFTER = " + $rtn_dat_ages_ary.Count)
									#Write-Host "rtn_dat_ages_ary AFTER = $rtn_dat_ages_ary"
									#Write-Host ("rtn_dat_imgcnts_ary cnt AFTER = " + $rtn_dat_imgcnts_ary.Count)
									#Write-Host "rtn_dat_imgcnts_ary AFTER = $rtn_dat_imgcnts_ary"
									#Write-Host ("rtn_dat_imgssaved_ary cnt AFTER = " + $rtn_dat_imgssaved_ary.Count)
									#Write-Host "rtn_dat_imgssaved_ary AFTER = $rtn_dat_imgssaved_ary"
									#Write-Host ("rtn_dat_confirmed_img_nos_ary cnt AFTER = " + $rtn_dat_confirmed_img_nos_ary.Count)
									#Write-Host "rtn_dat_confirmed_img_nos_ary AFTER = $rtn_dat_confirmed_img_nos_ary"
									#Write-Host ("rtn_dat_aimodels_ary cnt AFTER = " + $rtn_dat_aimodels_ary.Count)
									#Write-Host "rtn_dat_aimodels_ary AFTER = $rtn_dat_aimodels_ary"
									#Write-Host ("rtn_dat_almemos_ary cnt AFTER = " + $rtn_dat_almemos_ary.Count)
									#Write-Host "rtn_dat_almemos_ary AFTER = $rtn_dat_almemos_ary"
									#Write-Host ("dat_img_labels_used_ary cnt AFTER = " + $dat_img_labels_used_ary.Count)
									#Write-Host "dat_img_labels_used_ary AFTER = $dat_img_labels_used_ary"
								}
								
							} else {

								[Collections.Generic.List[String]]$lst = $rtn_dat_aimodels_ary
								$rtn_dat_aimodels_ary = [array]$lst
								
							}
							
							# For debugging
							#Write-Host "$fn_name() jpgs_cnt = $jpgs_cntr"
							#Write-Host "$fn_name() jsons_cnt = $jsons_cntr"
							#Write-Host ("$fn_name() rtn_dat_confirmed_img_nos_ary cnt AFTER = " + $rtn_dat_confirmed_img_nos_ary.Count)
							#Write-Host "$fn_name() rtn_dat_confirmed_img_nos_ary AFTER = $rtn_dat_confirmed_img_nos_ary"
							
							# Feedback results
							if ($FromConsoleFlg -and !$QuietFlg) {
								if ($jpgs_cntr -gt 0 -or $jsons_cntr -gt 0) {
									if ($if_ai_type_arg_used_flg) {
										if ($if_dat_ai_args_overall_success_flg) {
											if ($save_jsons_flg) {
												Write-Host ("Saved $jpgs_cntr jpg + $jsons_cntr json files")
											} else {
												Write-Host ("Saved $jpgs_cntr jpg files")
											}
										} else {
											if ($save_jsons_flg) {
												Write-Host ("Saved $jpgs_cntr jpg + $jsons_cntr json files")
											} else {
												Write-Host ("Saved $jpgs_cntr jpg files")
											}
										}
									} else {
										if ($save_jsons_flg) {
											Write-Host ("Saved $jpgs_cntr jpg + $jsons_cntr json files")
										} else {
											Write-Host ("Saved $jpgs_cntr jpg files")
										}
									}
								} else {
									if ($save_jpgs_flg -or $save_jsons_flg) {
										Write-Host ("NO jpg or json files saved")
									}
								}
							}
							
							# CLEAN UP $DESTINATION FOLDER ... remove empty folder created to receive extracted *.jpg and *.json files
							# WHY? the folders named after each DAT file MIGHT BE EMPTY if using parameters -IfAiModel, -fAiLabel, -IfAiNothing 
							if (Test-Path -LiteralPath "$Destination") {
								Get-ChildItem -LiteralPath "$Destination" -Recurse | Where-Object { $_.PSIsContainer -and (Get-ChildItem -Path $_.FullName | Where-Object { !$_.PSIsContainer }) -eq $null } | Remove-Item -Force -Recurse
							}
							
							# DELETE THE DAT FILE, IF REQUESTED
							$doit_flg = $false
							if ($DeleteFlg) {								
								if (!$al_is_protected) {  # Alert is NOT protected per the database
									if ($if_ai_type_arg_used_flg) {
										if ($if_dat_ai_args_overall_success_flg) {
											$doit_flg = $true
										}
									} else {
										$doit_flg = $true
									}
									if ($doit_flg) {
										$result_flg = 
										DeleteDatFile `
											-DatFile $dat_file `
											-NoRecycleFlg $NoRecycleFlg `
											-Destination $Destination `
											-ForceFlg $ForceFlg 
											
										if (!$result_flg) {
											if ($FromConsoleFlg) {
												$msg = "File not deleted; DAT or Alert JPG is read-only (may be protected by Blue Iris)"
												if ($QuietFlg) {
													Write-Warning ($msg + " ($dat_file))")
												} else {
													Write-Warning $msg
												}
											}
										}
									}
								} else {  # Alert is protected per the database
									if ($FromConsoleFlg) {
										$msg = "File not deleted; Alert is flagged as 'Protected' by Blue Iris"
										if ($QuietFlg) {
											Write-Warning ($msg + " ($dat_file))")
										} else {
											Write-Warning $msg
										}
									}
								}
							}
						
						}	
						
					} else {
						$rtn_dat_names_ary += $fname
						$rtn_dat_imgcnts_ary += -1  
						$rtn_dat_aimodels_ary += "N/A"
						$rtn_dat_ailabels_ary += "N/A"
						if ($FromConsoleFlg -and !$QuietFlg) {
							Write-Warning "No JPGs found in DAT file"
						}
					}		
				
				} else {

					$rtn_dat_names_ary += $fname
					$rtn_dat_imgcnts_ary += -1 # 
					$rtn_dat_aimodels_ary += "N/A"
					$rtn_dat_ailabels_ary += "N/A"
					if ($FromConsoleFlg) {
						Write-Warning "DAT file has an unexpected structure [overlapping JPG beg/end markers]"
					}
				}
			}
		} else {
			$fname = Split-Path -leaf "$dat_file"
			if (!$NoInspectFlg) {
				if ($FromConsoleFlg -and !$QuietFlg) {
					if ($if_ai_type_arg_used_flg) {
						Write-Host "`nInspecting $progress_bar_cntr/$filespecs_cnt - $fname ..."
					} else {
						Write-Host "Inspecting $progress_bar_cntr/$filespecs_cnt - $fname ..."
					}
				}
			}
			if ($FromConsoleFlg) {
				$verbose_flg = $true
				if ($quiet) {
					Write-Warning "File not found '$dat_file'"
				} else {
					Write-Warning "File not found"
				}
			}
			$rtn_dat_names_ary += $fname
			$rtn_dat_al_flags_ary += "--"
			$rtn_al_readonly_ary += "--"
			$rtn_dat_ages_ary += -1
			$rtn_dat_imgcnts_ary += -1
			$rtn_dat_imgssaved_ary += 0 
			$rtn_dat_confirmed_img_nos_ary +- 'NA'
			$rtn_dat_aimodels_ary += "ERR/nonexistent"
			$rtn_dat_ailabels_ary += "ERR/nonexistent"
			$rtn_dat_almemos_ary += "ERR/nonexistent"
			$dat_img_labels_used_ary += ""

		}

		# Feedback issues, if any
		if ($empty_imgs_cntr -gt 0) {
			[array]::Reverse($empty_imgs_ary)
			Write-Warning ("'$fname' contains " + $empty_imgs_ary.Count + " empty JPGs`nEmpty JPGs: " + ($empty_imgs_ary -Join ","))
		}
		if ($invalid_imgs_cntr -gt 0) {
			$invalid_jpgs_cntr += $invalid_imgs_cntr
			[array]::Reverse($invalid_imgs_ary)
			Write-Warning (($invalid_imgs_ary.Count).ToString() + " JPGs saved from '$fname' test as invalid`nInvalid: " + ($invalid_imgs_ary -Join ","))
		}
		if ($empty_jsons_cntr -gt 0) {
			$show_msg = $true  # Default
			if ($ignore_img1_json_zero_length_warnings) {
				
				# For debugging
				#Write-Host ("empty_jsons_ary.Count = " + $empty_jsons_ary.Count)
				#Write-Host ("empty_jsons_ary = " + $empty_jsons_ary)
				
				if ( ($empty_jsons_ary.Count -eq 1) -and ($empty_jsons_ary -Contains "img1") ) {
					$show_msg = $false
				}
			}
			if ($show_msg) {
				$verbose_flg = $true
				[array]::Reverse($empty_jsons_ary)
				Write-Warning ("'$fname' contains " + $empty_jsons_ary.Count + " empty JSON string(s)`nEmpty JSON strings: " + ($empty_jsons_ary -Join ","))				
			}
		}
		if ($invalid_jsons_cntr -gt 0) {
			$verbose_flg = $true
			[array]::Reverse($invalid_jsons_ary)
			Write-Warning ("'$fname' contains " + $invalid_jsons_ary.Count + " invalid JSON strings`nInvalid: " + ($invalid_jsons_ary -Join ","))
		}

	}  # LOOP BACK TO NEXT DAT FILE

	# Stop performance timer
	$timer_load_dats.stop()
	$loadats_sec = [math]::Round(($timer_load_dats.elapsed.totalseconds),1).ToString("0.0")
	if ($DevModeFlg) {
		Write-Host "`n(dev mode) DAT file processing time (seconds) = $loadats_sec" -ForegroundColor Cyan
	}

	# Toggle off the ProcessDATFiles() progress bar.
	# REF: https://stackoverflow.com/a/6651374
	# BTW: Get-Variable *preference will list all the preference variables
	$ProgressPreference = "SilentlyContinue"
	
	$deleted_files_ary_cnt = $deleted_files_ary.Count
	if ($deleted_files_ary_cnt -gt 0) {
		if ($FromConsoleFlg) {
			if ($NoRecycle) {
				Write-Warning "$deleted_files_ary_cnt DAT files permanently deleted"
			} else {
				Write-Warning "$deleted_files_ary_cnt DAT files moved to the Recycle Bin"
			}
		}
	}
	
	if ($FromConsoleFlg -and !$QuietFlg) {
		if ($if_ai_type_arg_used_flg) {
			Write-Host "`nIfAi* FILTERS RESULT: flagged $ai_filtered_jpgs_cntr/$jpgs_processed_cntr JPG files inspected"
		}
	}

	# For debugging
	#Write-Host "$fn_name() made it!"
	#Write-Host ("$fn_name() rtn_dat_names_ary type = " + $rtn_dat_names_ary.GetType())
	#Write-Host ("$fn_name() rtn_dat_names_ary cnt = " + $rtn_dat_names_ary.Count)
	#Write-Host "$fn_name() rtn_dat_names_ary = $rtn_dat_names_ary"
	#Write-Host "$fn_name() rtn_dat_al_flags_ary = $rtn_dat_al_flags_ary"
	#Write-Host ("$fn_name() rtn_dat_ages_ary type = " + $rtn_dat_ages_ary.GetType())
	#Write-Host ("$fn_name() rtn_dat_ages_ary cnt = " + $rtn_dat_ages_ary.Count)
	#Write-Host "$fn_name() rtn_dat_ages_ary = $rtn_dat_ages_ary"
	#foreach ($x in $rtn_dat_ages_ary) {
		#Write-Host ("$x, type = " + $x.GetType())
	#}
	#Write-Host ("$fn_name() rtn_dat_imgcnts_ary type = " + $rtn_dat_imgcnts_ary.GetType())
	#Write-Host ("$fn_name() rtn_dat_imgcnts_ary cnt = " + $rtn_dat_imgcnts_ary.Count)
	#Write-Host "$fn_name() rtn_dat_imgcnts_ary = $rtn_dat_imgcnts_ary"
	#Write-Host ("$fn_name() rtn_dat_aimodels_ary cnt = " + $rtn_dat_aimodels_ary.Count)
	#Write-Host "$fn_name() rtn_dat_aimodels_ary = $rtn_dat_aimodels_ary"
	#Write-Host ("$fn_name() rtn_dat_ailabels_ary cnt = " + $rtn_dat_ailabels_ary.Count)
	#Write-Host "$fn_name() rtn_dat_ailabels_ary = $rtn_dat_ailabels_ary"
	#Write-Host ("$fn_name() rtn_dat_almemos_ary cnt = " + $rtn_dat_almemos_ary.Count)
	#Write-Host "$fn_name() rtn_dat_almemos_ary = $rtn_dat_almemos_ary"
	#Write-Host ("$fn_name() dat_img_labels_used_ary cnt = " + $dat_img_labels_used_ary.Count)
	#Write-Host "$fn_name() dat_img_labels_used_ary = $dat_img_labels_used_ary"

	return @($rtn_dat_names_ary, $rtn_dat_al_flags_ary, $rtn_al_readonly_ary, $rtn_dat_ages_ary, $rtn_dat_imgcnts_ary, $rtn_dat_imgssaved_ary, $rtn_dat_confirmed_img_nos_ary, $rtn_dat_confirmed_img_memos_ary, $rtn_dat_aimodels_ary, $rtn_dat_ailabels_ary, $rtn_dat_almemos_ary, $loadats_sec, $dat_img_labels_used_ary, $invalid_jpgs_cntr)

}

function MakeTable() {
# PURPOSE:   To create a CSV file filtered DAT files showing: 
#            filenames, file ages, JPG counts, AI models used, AI labels found, and Alert memos.
#            (This is accomplished by using a temporary CSV file; see note 3 below.)
# PARAMS:    -TempPath            = (string) path for temporary CSV file is to display hashtable
#            -SortColNo           = (int) column to sort on (first column no = 1)
#            -SortAscFlg          = (boolean) sort ascending
#            -FilesList           = (list) '[\subfolder\]filenames'
#            -AlertFlagsList      = (list) flags on Alert associated with DAT file (F=flagged,P=protected)
#            -AlertAttribsList    = (list) JPG and DAT file read-only attributes set
#            -FilesAgesList       = (list) 'ages in hours' for each entry in $FilesList
#            -ImagesList          = (list) 'images' count for each entry in $FilesList
#            -DatConfImgNosList   = (list) DAT images that appear to be confirmed for each entry in $FilesList
#            -DatConfImgMemosList = (list) memos for DAT images that appear to be confirmed
#            -AiModelsList        = (list) AI models used for each entry in $FilesList
#            -AiLabelsList        = (list) AI labels found for each entry in $FilesList
#            -AlMemosList         = (list) Alert memos found for each entry in $FilesList
#            -ImgLabelsList       = (list) for each label in -AiLabelsList shows which images contains it
#            -JpgExifMemos        = (list) extracted 'Title' from JPG Exif data
#
# RETURNS:  (string) filespec
# NOTES:    1. Using CSV files is very convenient; Powershell automatically handles the table formatting.
#           2. The temporary CSV files are created in directory "$app_path\_output" ($app_path via the user_settings file)
#           3. The temporary CSV file can be displayed to the console using the following command:
#              --> Import-Csv "output.csv" | Sort-Object "xxx" | Format-Table 
#              A challenge with this approach is that the Sort-Object column has only the -Length property.
#              Because of this, successfully displaying the 'AgeHrs' & 'ImgsCnt' columns in sorted order requires that their values  
#              i) have an identical number of digits after the decimal, and 
#              ii) be left-padded to create strings of identical length.

	param(
		[string]$TempPath,
		[int]$SortColNo,
		[boolean]$SortAscFlg,
		[array]$FilesList,
		[array]$AlertFlagsList,
		[array]$AlertAttribsList,
		[array]$FileAgesList,
		[array]$ImagesList,
		[array]$DatConfImgNosList,
		[array]$DatConfImgMemosList,
		[array]$AiModelsList,
		[array]$AiLabelsList,
		[array]$AlMemosList,
		[array]$ImgLabelsList,
		[array]$JpgExifMemos
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() TempPath = $TempPath"
	#Write-Host ("$fn_name() FlagsFilter type = " + $FlagsFilter.GetType())
	#Write-Host "$fn_name() SortColNo = $SortColNo"
	#Write-Host ("$fn_name() FilesList type = " + $FilesList.GetType())
	#Write-Host ("$fn_name() FilesList cnt = " + $FilesList.length)
	#Write-Host ("$fn_name() ImagesList cnt = " + $ImagesList.length)
	#Write-Host ("$fn_name() DatConfImgNosList cnt = " + $DatConfImgNosList.length)
	#Write-Host ("$fn_name() DatConfImgNosList = " + ($DatConfImgNosList | ConvertTo-Json))
	#Write-Host ("$fn_name() DatConfImgMemosList cnt = " + $DatConfImgMemosList.length)
	#Write-Host ("$fn_name() AlertFlagsList cnt = " + $AlertFlagsList.length)
	#Write-Host "$fn_name() AlertFlagsList = $AlertFlagsList"
	#Write-Host ("$fn_name() AlertAttribsList cnt = " + $AlertAttribsList.length)
	#Write-Host "$fn_name() AlertAttribsList = $AlertAttribsList"
	#Write-Host ("$fn_name() FileAgesList cnt = " + $FileAgesList.length)
	#Write-Host "$fn_name() FileAgesList = $FileAgesList"
	#Write-Host ("$fn_name() AiModelsList cnt = " + $AiModelsList.length)
	#Write-Host "$fn_name() AiModelsList = $AiModelsList"
	#Write-Host ("$fn_name() AiLabelsList cnt = " + $AiLabelsList.length)
	#Write-Host "$fn_name() AiLabelsList = $AiLabelsList"
	#Write-Host ("$fn_name() AlMemosList cnt = " + $AlMemosList.length)
	#Write-Host "$fn_name() AlMemosList = $AlMemosList"
	#Write-Host ("$fn_name() ImgLabelsList cnt = " + $ImgLabelsList.length)
	#Write-Host "$fn_name() ImgLabelsList = $ImgLabelsList"
	#Write-Host ("$fn_name() JpgExifMemos cnt = " + $JpgExifMemos.length)
	#Write-Host "$fn_name() JpgExifMemos = $JpgExifMemos"
	
	# Abort of nothing to do
	if ($FilesList.Count -eq 0) {
		return
	}

	# Create directory for temporary CSV file (if necessary).
	# ... CSV file is used to display a hashtable
	If (!(test-path -PathType container $TempPath)) {
		New-Item -ItemType Directory -Path "$TempPath" | Out-Null
	}

	# Initialize list collectors; each collector is a column in the displayed output table.
	$files        = New-Object System.Collections.Generic.List[System.Object]
	$flags        = New-Object System.Collections.Generic.List[System.Object]
	$attribs      = New-Object System.Collections.Generic.List[System.Object]
	$ages         = New-Object System.Collections.Generic.List[System.Object]
	$images       = New-Object System.Collections.Generic.List[System.Object]
	$confimgnos   = New-Object System.Collections.Generic.List[System.Object]
	$confimgmemos = New-Object System.Collections.Generic.List[System.Object]
	$aimodels     = New-Object System.Collections.Generic.List[System.Object]
	$ailabels     = New-Object System.Collections.Generic.List[System.Object]
	$almemos      = New-Object System.Collections.Generic.List[System.Object]
	$imglabels    = New-Object System.Collections.Generic.List[System.Object]
	$jpgmemos     = New-Object System.Collections.Generic.List[System.Object]
	
	$i = 0
	foreach($f in $FilesList) {
		$files.Add($f)
		$flags.Add($AlertFlagsList[$i])
		$attribs.Add($AlertAttribsList[$i])
		$ages.Add($FileAgesList[$i])
		$images.Add($ImagesList[$i])
		$confimgnos.Add($DatConfImgNosList[$i])
		$confimgmemos.Add($DatConfImgMemosList[$i])
		$aimodels.Add($AiModelsList[$i])
		$ailabels.Add($AiLabelsList[$i])
		$almemos.Add($AlMemosList[$i])
		$imglabels.Add($ImgLabelsList[$i])
		$jpgmemos.Add($JpgExifMemos[$i])
		$i++
	}
	
	#Write-Host "$fn_name() ages = $ages"
	#Write-Host ("$fn_name() aimodels type = " + $aimodels.GetType())
	#Write-Host ("$fn_name() aimodels cnt = " + $aimodels.Count)
	#Write-Host "$fn_name() aimodels = $aimodels"
	#Write-Host ("$fn_name() ailabels type = " + $ailabels.GetType())
	#Write-Host ("$fn_name() ailabels cnt = " + $ailabels.Count)
	#Write-Host "$fn_name() ailabels = $ailabels"
	#Write-Host ("$fn_name() almemos cnt = " + $almemos.Count)
	#Write-Host "$fn_name() almemos = $almemos"
	#Write-Host ("$fn_name() imglabels cnt = " + $imglabels.Count)
	#Write-Host "$fn_name() imglabels = $imglabels"
	#Write-Host ("$fn_name() jpgmemos cnt = " + $jpgmemos.Count)
	#Write-Host "$fn_name() jpgmemos = $jpgmemos"
		
	# Convert selected columns ('flags', 'ages', 'images') to left-padded strings.
	# ... for a 'pretty' table, these left-padded strings must be of identical length.
	# ... see also NOTE #3 above.
	$i = 0
	[array]$arr = foreach($val in $flags) { ([string]$val) }
	$max_len = ($arr | Measure-Object -Maximum -Property Length).Maximum
	$col_width = "Flags".length  # Header 'Flags'
	if ($max_len -le $col_width) { $max_len = $col_width }
	foreach ($item in $flags.ToArray()) {
		if ($item) {
			$val = $item.toString()
		} else {
			$val = ""
		}
		$flags[$i] = $val.padLeft($max_len," ")
		$i++
	}
	$i = 0
	[array]$arr = foreach($val in $attribs) { ([string]$val) }
	$max_len = ($arr | Measure-Object -Maximum -Property Length).Maximum
	$col_width = "RO".length  # Header 'RO' [read-only]
	if ($max_len -le $col_width) { $max_len = $col_width }
	foreach ($item in $attribs.ToArray()) {
		if ($item) {
			$val = $item.toString()
		} else {
			$val = ""
		}
		$attribs[$i] = $val.padLeft($max_len," ")
		$i++
	}
	$i = 0
	[array]$arr = foreach($val in $ages) { ([string]$val) }
	$max_len = ($arr | Measure-Object -Maximum -Property Length).Maximum
	$col_width = "AgeHrs".length  # Header 'AgeHrs'
	if ($max_len -le $col_width) { $max_len = $col_width }
	foreach ($item in $ages.ToArray()) {
		if ($item) {
			$val = $item.toString()
		} else {
			$val = ""
		}
		$ages[$i] = $val.padLeft($max_len," ")
		$i++
	}
	$i = 0
	[array]$arr = foreach($val in $images) { ([string]$val) }
	$max_len = ($arr | Measure-Object -Maximum -Property Length).Maximum
	$col_width = "ImgsCnt".length  # Header 'ImgsCnt'
	if ($max_len -le $col_width) { $max_len = $col_width }
	foreach ($item in $images.ToArray()) {
		if ($item) {
			$val = $item.toString()
		} else {
			$val = ""
		}
		$images[$i] = $val.padLeft($max_len," ")
		$i++
	}
	$i = 0
	[array]$arr = foreach($val in $confimgnos) { ([string]$val) }
	$max_len = ($arr | Measure-Object -Maximum -Property Length).Maximum
	$col_width = "ConfImg".length  # Header 'ConfImg'
	if ($max_len -le $col_width) { $max_len = $col_width }
	foreach ($item in $confimgnos.ToArray()) {
		if ($item) {
			$val = $item.toString()
		} else {
			$val = ""
		}
		$confimgnos[$i] = $val.padLeft($max_len," ")
		$i++
	}

	# Create & populate a hashtable with formated entries.
	# ... each element will be a column in the final table.
	# ... a hashtable is required for creating the temporary CSV file.
	$output = [ordered]@{}
	$output.Add("File", $files)
	$output.Add("Flags", $flags)
	$output.Add("RO", $attribs)
	$output.Add("AgeHrs", $ages)
	$output.Add("ImgsCnt", $images)
	$output.Add("ConfImg", $confimgnos)
	$output.Add("ConfImgMemo", $confimgmemos)
	$output.Add("ModelsUsed", $aimodels)
	$output.Add("LabelsFound", $ailabels)
	$output.Add("AlertMemoLabels", $almemos)
	$output.Add("JpgExifMemoLabels", $jpgmemos)
	$output.Add("LabelsByImg", $imglabels)

	# USE A TEMPORARY CSV FILE TO DISPLAY A NICE LOOKING TABLE.

	# EXPORT THE HASHTABLE AS A CSV FILE.
	# REFS: 1. Microsoft everything about hashtables...https://tinyurl.com/3eezjed9
	#       2. https://tommymaynard.com/hash-table-to-csv-revisited/
	#       3. PSObject vs PSCustomObject... https://stackoverflow.com/a/50196654/13499984

	# Get the maximum number of entries ($cnt) from all the columns in the CSV table.
	# ... Note: calculating this is *not* necessary in our case, b/c we already know that all
	#     the columns have the same number of entries; however, it is a good practice in general.
	$cnt  = $output.Values |
			ForEach-Object { $_.Count } |
			Sort-Object |
			Select-Object -Last 1

	# Get the CSV table column headers.
	$keys = $output.Keys

	# For debugging.
	#Write-Host ("column hdrs = " + $output.Keys)
	#Write-Host ("column cnts = " + ($output.Values | ForEach-Object { $_.Count } ))

	# Use hashtable $output to create a custom object for exporting
	# ... this is necessary to save it correctly to CSV
	# ... Export-Csv works with objects. It expects properties and values.
	# Build CSV file, row-by-row. 
	0..($cnt-1) | ForEach-Object {
		$tmp_tbl = [ordered]@{}
		foreach ($key in $keys) {
			$tmp_tbl[$key] = $output[$key][$_]
		}
		New-Object -Type PSObject -Property $tmp_tbl
	} | Export-Csv "$output_path\output.csv" -NoTypeInformation

	return "$output_path\output.csv"
}

function ShowTable() {
# PURPOSE:   To output to the console a 'pretty' table of DAT files showing: 
#            filenames, file ages, JPG counts, AI models used, AI labels found, and Alert memos.
# PARAMS:    -Path       = (string) path for temporary CSV file to be displayed
#            -SortColNo  = (int) column to sort on (first column no = 1)
#            -SortAscFlg = (boolean) sort ascending
#
# RETURNS:  nothing - function creates output to Console only
# NOTES:    1. Using CSV files is very convenient; Powershell automatically handles the table formatting.
#           2. The temporary CSV files are created in directory "$app_path\_output" ($app_path via the user_settings file)
#
	param(
		[string]$Path,
		[int]$SortColNo,
		[boolean]$SortAscFlg
	)
	
	$fn_name = (Get-Variable MyInvocation).Value.MyCommand.Name

	# For debugging.
	#Write-Host "entered function $fn_name()..."
	#Write-Host "$fn_name() Path = $Path"

	# Create directory for temporary CSV file (if necessary).
	# ... CSV file is used to display a hashtable
	If (!(test-path -LiteralPath $Path)) {
		$err_msg = "ERR/nonexistent CSV file '$Path'"
		return $err_msg
	}

	# DISPLAY THE CSV FILE
	# ... NOTE: we sort on specified column, if requested.
	# ... NOTE: we exclude the somes column b/c they makes the table too wide to display nicely

	if ($SortColNo -eq 1) {
		# Perform 'Natural order' sort
		# ... NOTE: Column 1 ('File') is already sorted; see code following use of function 'GetDatFilesRecursive()'
		Import-Csv "$Path" | Select * -ExcludeProperty "LabelsByImg" | Select * -ExcludeProperty "JpgExifMemoLabels" | Select * -ExcludeProperty "ConfImgMemo" | Format-Table 
		
	} elseif ($SortColNo -eq 2) {
		if ($SortAscFlg) {
			Import-Csv "$Path" | Select * -ExcludeProperty "LabelsByImg" | Select * -ExcludeProperty "JpgExifMemoLabels" | Select * -ExcludeProperty "ConfImgMemo" | Sort-Object "AgeHrs" | Format-Table 
		} else {
			Import-Csv "$Path" | Select * -ExcludeProperty "LabelsByImg" | Select * -ExcludeProperty "JpgExifMemoLabels" | Select * -ExcludeProperty "ConfImgMemo""ConfImgMemo" | Sort-Object "AgeHrs" -Descending | Format-Table 
		}		
	} else {
		Import-Csv "$Path" | Select * -ExcludeProperty "LabelsByImg" | Select * -ExcludeProperty "JpgExifMemoLabels" | Select * -ExcludeProperty "ConfImgMemo""ConfImgMemo" | Format-Table 
	}

}

function Get-FileMetaData {
	# SOURCE: https://evotec.xyz/getting-file-metadata-with-powershell-similar-to-what-windows-explorer-provides/
    <#
    .SYNOPSIS
    Small function that gets metadata information from file providing similar output to what Explorer shows when viewing file

    .DESCRIPTION
    Small function that gets metadata information from file providing similar output to what Explorer shows when viewing file

    .PARAMETER File
    FileName or FileObject

    .EXAMPLE
    Get-ChildItem -Path $Env:USERPROFILE\Desktop -Force | Get-FileMetaData | Out-HtmlView -ScrollX -Filtering -AllProperties

    .EXAMPLE
    Get-ChildItem -Path $Env:USERPROFILE\Desktop -Force | Where-Object { $_.Attributes -like '*Hidden*' } | Get-FileMetaData | Out-HtmlView -ScrollX -Filtering -AllProperties

    .NOTES
    #>
    [CmdletBinding()]
    param (
        [Parameter(Position = 0, ValueFromPipeline)][Object] $File,
        [switch] $Signature
    )
    Process {
        foreach ($F in $File) {
            $MetaDataObject = [ordered] @{}
            if ($F -is [string]) {
                $FileInformation = Get-ItemProperty -Path $F
            } elseif ($F -is [System.IO.DirectoryInfo]) {
                #Write-Warning "Get-FileMetaData - Directories are not supported. Skipping $F."
                continue
            } elseif ($F -is [System.IO.FileInfo]) {
                $FileInformation = $F
            } else {
                Write-Warning "Get-FileMetaData - Only files are supported. Skipping $F."
                continue
            }
            $ShellApplication = New-Object -ComObject Shell.Application
            $ShellFolder = $ShellApplication.Namespace($FileInformation.Directory.FullName)
            $ShellFile = $ShellFolder.ParseName($FileInformation.Name)
            $MetaDataProperties = [ordered] @{}
            0..400 | ForEach-Object -Process {
                $DataValue = $ShellFolder.GetDetailsOf($null, $_)
                $PropertyValue = (Get-Culture).TextInfo.ToTitleCase($DataValue.Trim()).Replace(' ', '')
                if ($PropertyValue -ne '') {
                    $MetaDataProperties["$_"] = $PropertyValue
                }
            }
            foreach ($Key in $MetaDataProperties.Keys) {
                $Property = $MetaDataProperties[$Key]
                $Value = $ShellFolder.GetDetailsOf($ShellFile, [int] $Key)
                if ($Property -in 'Attributes', 'Folder', 'Type', 'SpaceFree', 'TotalSize', 'SpaceUsed') {
                    continue
                }
                If (($null -ne $Value) -and ($Value -ne '')) {
                    $MetaDataObject["$Property"] = $Value
                }
            }
            if ($FileInformation.VersionInfo) {
                $SplitInfo = ([string] $FileInformation.VersionInfo).Split([char]13)
                foreach ($Item in $SplitInfo) {
                    $Property = $Item.Split(":").Trim()
                    if ($Property[0] -and $Property[1] -ne '') {
                        $MetaDataObject["$($Property[0])"] = $Property[1]
                    }
                }
            }
            $MetaDataObject["Attributes"] = $FileInformation.Attributes
            $MetaDataObject['IsReadOnly'] = $FileInformation.IsReadOnly
            $MetaDataObject['IsHidden'] = $FileInformation.Attributes -like '*Hidden*'
            $MetaDataObject['IsSystem'] = $FileInformation.Attributes -like '*System*'
            if ($Signature) {
                $DigitalSignature = Get-AuthenticodeSignature -FilePath $FileInformation.Fullname
                $MetaDataObject['SignatureCertificateSubject'] = $DigitalSignature.SignerCertificate.Subject
                $MetaDataObject['SignatureCertificateIssuer'] = $DigitalSignature.SignerCertificate.Issuer
                $MetaDataObject['SignatureCertificateSerialNumber'] = $DigitalSignature.SignerCertificate.SerialNumber
                $MetaDataObject['SignatureCertificateNotBefore'] = $DigitalSignature.SignerCertificate.NotBefore
                $MetaDataObject['SignatureCertificateNotAfter'] = $DigitalSignature.SignerCertificate.NotAfter
                $MetaDataObject['SignatureCertificateThumbprint'] = $DigitalSignature.SignerCertificate.Thumbprint
                $MetaDataObject['SignatureStatus'] = $DigitalSignature.Status
                $MetaDataObject['IsOSBinary'] = $DigitalSignature.IsOSBinary
            }
            [PSCustomObject] $MetaDataObject
        }
    }
}

<# function ConvertPSObjectToHashtable {
# Source: https://github.com/robotechredmond/Azure-PowerShell-Snippets/blob/master/Convert-PSObject-to-Hashtable.ps1

    param (
        [Parameter(ValueFromPipeline)]
        $InputObject
    )

    process
    {
        if ($null -eq $InputObject) { return $null }

        if ($InputObject -is [System.Collections.IEnumerable] -and $InputObject -isnot [string]) {
 
			$collection = @(
                foreach ($object in $InputObject) { ConvertPSObjectToHashtable $object }
            )

            Write-Output -NoEnumerate $collection
			
        } elseif ($InputObject -is [psobject]) {

            $hash = @{}

            foreach ($property in $InputObject.PSObject.Properties) {
                $hash[$property.Name] = ConvertPSObjectToHashtable $property.Value
            }

            $hash
			
        } else {
            $InputObject
        }
    }
} #>

# FEEDBACK UNEXPECTED COMMANDLINE ARGUMENTS
#Write-Host ("params = " + ($PSBoundParameters | ConvertTo-Json))
$cmdline_args_passed = [String[]]$PSBoundParameters.Keys
#Write-Host "Extra Args w/ values = $Args"
$cmdline_args_extra = ($Args | where{$_ -like "-*"}) | ForEach-Object{$_ -Replace '-', ''}
if ($cmdline_args_extra) {
	$cmdline_args_extra = [String[]]$cmdline_args_extra
} else {
	$cmdline_args_extra = @()
}
#Write-Host "Cmdline Args Passed = $cmdline_args_passed"
#Write-Host "Cmdline Args Extra = $cmdline_args_extra"
if ($cmdline_args_extra.Count -gt 0) {
	if ($fromConsole) {
		Write-Host ("HEADS-UP: commandline contains unsupported argument(s): [ " + ($cmdline_args_extra -Join ', ') + " ]") -ForegroundColor Yellow
	}
	
}
if ($cmdline_args_extra -contains 'Cameras' -or $cmdline_args_extra -contains 'Camera') {
	if ($cmdline_args_extra -contains 'Cameras') {
		$err_msg = "ERR/Argument -Camera is not supported; used argument -Patterns instead!"
	} else {
		$err_msg = "ERR/Argument -Cameras is not supported; used argument -Patterns instead!"		
	}
	return $err_msg
}

# SHOW HELP
if ($fromConsole -and $Help -and !$Quiet) {
	Write-Host "======================================================================================================="
	Write-Host "BLUE IRIS ARTIFICIAL INTELLIGENCE (AI) 'DAT' FILE UTILITY"
	Write-Host "-------------------------------------------------------------------------------------------------------"
	Write-Host "Usage: $ScriptName ... (no args) outputs image counts & AI models used for all DAT files"
	Write-Host "Args:  -NoInspect  ... disable auto-inspection for images/JSON in DAT files (FASTER response)"
	Write-Host "       -SourcePath ... alternate path for DAT files (vs default in the user-settings file) [1,2,3]"
	Write-Host "       -Files      ... specify DAT file(s) by filename (comma-delimited) [1,2,4,5,6]"
	Write-Host "       -Patterns   ... filter DAT files by naming pattern(s) (comma-delimited) [2,4]"
	Write-Host "       -Flags      ... filter DAT files for Alerts w/ specified flags, comma-delimited [8]"
	Write-Host "       -AgeHours   ... filter DAT files by age in hours; min[,max] (comma-delimited)"
	Write-Host "       -MinImages  ... filter DAT files with N or more images"
	Write-Host "       -MaxImages  ... filter DAT files with N or fewer images"
	Write-Host "       -AlMemoTags ... filter DAT files based on Alert memo substrings ('tags') (comma-delimited) [2]"
	Write-Host "       -ChgAlMemoTags ... change/clear Alert memo 'tags' (must be used with -AlMemoTags) [2]"
	Write-Host "       -SortAsc    ... show results with DAT file names or ages listed in ascending order"
	Write-Host "       -SortHours  ... show results with DAT files sorted by age (default is descending order)"
	Write-Host "       -NoTable    ... skips display of table showing the DAT files found/processed"
	Write-Host "       -SaveJPGs     ... save filtered JPG images (\DAT\img*.jpg) -- subject to 'IfAi*' filters"
	Write-Host "       -SaveJSON     ... save all AI results (\DAT\*.json files) -- for EVERY JPG in the DAT file"
	Write-Host "       -SingleFolder ... save all JPG/JSON files to one folder (\SingleFolder\*.*)"
	Write-Host "       -Destination  ... alternate path for saved files (vs `$app_path in user-settings file)"
	Write-Host "       -IfAiModel        ... save only JPGs analyzed by a specified AI model (or a partial name)"
	Write-Host "       -IfAiLabels       ... save only JPGs confirmed for specified AI label(s) (comma-delimited)"
	Write-Host "       -IfAiNothingAny   ... save only JPGs w/ 'Nothing found' in ANY AI model used [7]"
	Write-Host "       -IfAiNothingAll   ... save only JPGs w/ 'Nothing found' in EVERY AI model used [7]"
	Write-Host "       -IfAiSomethingAny ... save only JPGs w/ something found (any AI label) in ANY model used [7]"
	Write-Host "       -IfAiSomethingAll ... save only JPGs w/ something found (any AI label) in EVERY model used [7]"
	Write-Host "       -Archive   ... copy as-filtered DAT files to \_archive* subfolder in user-setting $bi_alerts_folder_path"
	Write-Host "       -ReadOnly        ... set read-only attribute for filtered DAT files and their associated JPG files"
	Write-Host "       -FixJpgMetadata  ... force Alert JPG file's metadata to match the Alert's memo (in the database)"
	#Write-Host "       -Delete    ... move as-filtered DAT files from BI storage to the Windows Recycle Bin [9]"
	Write-Host "       -Delete    ... move as-filtered DAT files from BI storage to the Windows Recycle Bin [9]"
	Write-Host "       -NoRecycle ... use w/ -Delete; PERMANENTLY delete as-filtered DAT files"
	Write-Host "       -Force     ... use w/ -Delete; remove both read-only DAT files & protected Alert DAT files"
	Write-Host "       -Quiet   ... disable status messaging EXCEPT results table, warnings, and CLI mode output"
	Write-Host "       -NoTable ... disables display of table of all DAT files found/processed"
	Write-Host "       -NoBiLog ... disables/overrides logging to the Blue Iris logfile"
	Write-Host "       -ShowCLI ... also display the background execution return object (an array of arrays)"
	Write-Host "       -Help ... Show this usage guide"
	Write-Host "NOTES:"
	Write-Host "   [1] Args '-SourcePath' & '-Destination' unneeded if using default locations (user-settings file)"
	Write-Host "   [2] Arg values for these arguments must be quoted if they contain spaces"
	Write-Host "   [3] The folder specified by -SourcePath (`$bi_alerts_folder_path) is recursively inspected for DAT files"
	Write-Host "   [4] Args '-Files' & '-Patterns' must be like 'val1','val2', not 'val1,val2'"
	Write-Host "   [5] Arg '-Files' need not include '.dat' extension, and may include path"
	Write-Host "   [6] Arg '-Files' may be a *.txt file containing one *.dat file per line"
	Write-Host "   [7] These Args may be used with '-IfAiModel' to limit inspection to a specific model"
	Write-Host "   [8] Arg '-Flags' accepts the NOT operator (!), use -Flags '!C','P' for unconfirmed, protected Alerts"
	#Write-Host "   [9] WARNING: '-Delete' is PERMANENT when script is executed from TASK SCHEDULER"
	Write-Host "   [9] WARNING: '-Delete' ALWAYS performs a Blue Iris Database/Regenerate (stops all recording)"
	Write-Host "RETURNS:"
	Write-Host "   Console: Table/CSV (filenames, flags, ages, img_cnts, ai_models_used, ai_labels_found, memos)"
	Write-Host "   CLI mode: array of arrays (filenames, flags, ages, img_cnts, ai_models_used, ai_labels_found, memos)"
	Write-Host "-------------------------------------------------------------------------------------------------------"
	exit
}

#----------------------------------------------
# HANDLE COMMANDLINE ARGS
if (1 -eq 1) {  # Use to collapse this lengthy code section while editing
	
	# ~~~~~~~~~~~~~~~~~~~~~~~~~~~
	# REQUIRED ARGS
	
	if ($SourcePath) {
		$bi_alerts_folder_path = $SourcePath.TrimEnd('\')
	}
	if ($Destination) {
		$app_path = $Destination.TrimEnd('\')
	}
	#Write-Host "source_path = $bi_alerts_folder_path"

	# ~~~~~~~~~~~~~~~~~~~~~~~~~~~
	# OPTIONAL ARGS

	# ... No longer disabled w/ version 1.2
	<# if ($Delete) {
		$err_msg = "SORRY... Argument -Delete currently disabled"
		return $err_msg
	} #>

	if ($NoRegen -and !$DevMode) {
		$err_msg = "ERR/argument -NoRegen must be used with -DevMode"
		return $err_msg
	}

	if ($NoRecycle) {
		if (!$Delete) {
			$err_msg = "ERR/Arg -NoRecycle must be used with Arg -Delete"
			return $err_msg
		}
	}
	if ($Force) {
		if (!$Delete) {
			$err_msg = "ERR/Argument -Force must be used with Argument -Delete"
			return $err_msg
		}
	}
	# ... Legacy support for -AlertMemos
	if ($AlertMemos -and !$AlMemoTags) {
		$AlMemoTags = $AlertMemos 
	}
	#Write-Host ("AlMemoTags cnt = " + $AlMemoTags.Count)
	#Write-Host "AlMemoTags = $AlMemoTags"

	if ($ChgAlMemoTags) {
		if (!$AlMemoTags) {
			$err_msg = "ERR/Argument -ChgAlMemoTags must be used with Argument -AlMemoTags"
			return $err_msg
		} else {
			if ($ChgAlMemoTags.Count -ne $AlMemoTags.Count) {
				$err_msg = "ERR/Arguments -ChgAlMemoTags and -AlMemoTags must have the same number of items"
				return $err_msg
			}
		}
	}
	$if_ai_type_arg_used_flg = `
		( `
			$IfAiModel `
			-or $IfAiLabels `
			-or $IfAiNothingAny   -or $IfAiNothingAll `
			-or $IfAiSomethingAny -or $IfAiSomethingAll `
		)
		
	if ($if_ai_type_arg_used_flg) {
		if ($NoInspect) {
			$err_msg = "ERR/Do not use Arg -NoInspect when using a -IfAi* type Arg"
			return $err_msg
		}
	}
	if (($IfAiSomethingAny -or $IfAiSomethingAll) -and ($IfAiNothingAny -or $IfAiNothingAll)) {
		$err_msg = "ERR/Do not use Args -IfAiSomething* with Args -IfAiNothing*"
		return $err_msg

	}
	if ($IfAiNothingAll -or $IfAiSomethingAll) {
		<# if ($IfAiModel) {
			$err_msg = "ERR/Do not use Arg -IfAiModel with Args -IfAiNothingAll & IfAiSomethingAll"
			return $err_msg
		} #>
		if ($IfAiLabels) {
			$err_msg = "ERR/Do not use Arg -IfAiLabels with Args -IfAiNothingAll & IfAiSomethingAll"
			return $err_msg
		}
	}
	$save_jpgs_flg = $SaveJPGs
	if ($if_ai_type_arg_used_flg) {
		if (!$SaveJPGs) {
			#$save_jpgs_flg = $true
			if ($fromConsole -and !$Quiet) {
				#Write-Host "NOTE: Arg -SaveJPGs is required & auto-enabled when using any -IfAi type Arg"
				#Write-Warning "Arg -SaveJPGs is automatically added when using any -IfAi type Arg"
				#Write-Host ""
			}
			#$err_msg "ERR/Arg -SaveJPGs is required when using any -IfAi type Arg"
			#return $err_msg
		}
	}
	if (!$MinImages) {
		$MinImages = 0
	}
	if (!$MaxImages) {
		$MaxImages = 999
	}
	#Write-Host "Min/MaxImages = $MinImages/$MaxImages"

	if ($Files) {
		if ($Files.Count -eq 1) {
			if ( !($Files[0].EndsWith(".dat") -or $Files[0].EndsWith(".txt")) ) {
				$Files[0] = $Files[0] + ".dat"
			}
		} else {
			$i = 0
			foreach ($f in $Files) {
				if (!$f.EndsWith(".dat")) {
					$Files[$i] = $f + ".dat"
				}
				$i++
			}
		}
	}
	#Write-Host ("Files = " + ($Files | ConvertTo-Json))

	if ($Patterns) {
		$i = 0
		foreach ($p in $Patterns) {
			if ($p.GetType() -ne "string") {
				$Patterns[$i] = $p.ToString()
			}
			$i++
		}
	}
	
	# Simulator Args
	#$Sim1_arg_exists = ($cmdline_args_passed -contains 'Sim1')
	#$Sim2_arg_exists = ($cmdline_args_passed -contains 'Sim2')
	#$Sim3_arg_exists = ($cmdline_args_passed -contains 'Sim3')
	#$Sim4_arg_exists = ($cmdline_args_passed -contains 'Sim4')
	#$Sim5_arg_exists = ($cmdline_args_passed -contains 'Sim5')
}
#----------------------------------------------

# VALIDATE USER SETTINGS
# ... Folder existence tests
if (!(Test-Path -LiteralPath "$bi_alerts_folder_path")) {
	$err_msg = "ERR/nonexistent Blue Iris Alerts folder"
	return $err_msg
}

# ------------------------------------------------------
# MANAGE SCRIPT'S FOLDERS
if (1 -eq 1) {  # Use to collapse this lengthy code section while editing
	# 1. Home folder
	if (!(Test-Path -LiteralPath "$app_path")) {
		New-Item -ItemType Directory -Force -Path $app_path | Out-Null
	}

	# 2. Create subfolder for the script's output CSV file, if necessary.
	$output_path = $app_path + "\_output"
	If (!(test-path -PathType container $output_path)) {
		New-Item -ItemType Directory -Path $output_path | Out-Null
	}
	# ... And add/refresh a README to the folder
	$readme_path = "$output_path\_README.txt"
	if (!(Test-Path -LiteralPath "$readme_path")) {
		New-Item -Path "$readme_path" | Out-Null
		$msg = "Script Output Folder" +
			"`n--------------------" +
			"`n`nWHAT? This folder holds a CSV file representation of the script's output to the PowerShell Console." + 
			"`n`nBENEFITS:" + 
			"`n* These CSV files are not constrained by the size of the Console screen;" + 
			"`n* These CSV files contain additional columns not displayed in the output to the Console." +
			"`n`nTip: To retain a copy of the current output.csv file and prevent its contents from being overwritten, simply rename it to make it unique." + 
			"`n`nNote: This folder and this README.txt file are programmatically created."
		$msg | Out-File -FilePath "$readme_path" -Append
	}

	# 3. Create subfolder for the script's 'SingleFolder' folder, if necessary.
	$jpg_path = $app_path + "\SingleFolder"
	If (!(test-path -PathType container $jpg_path)) {
		New-Item -ItemType Directory -Path $jpg_path | Out-Null
	}
	# ... and add/refresh a README to the folder
	$readme_path = "$jpg_path\_README.txt"
	if (!(Test-Path -LiteralPath "$readme_path")) {
		New-Item -Path "$readme_path" | Out-Null
		$msg = "Script 'SingleFolder' Folder" +
			"`n----------------------------" +
			"`n`nWHAT? This folder holds ALL JPG (& JSON) files created by script '$ScriptName' when using argument '-SingleFolder'." + 
			"`n`nWHY? Without argument '-SingleFolder', the script automatically creates a separate subfolder for EACH DAT file processed. " + 
			"Some users may find more convenient to manage the JPG files from a single location." + 
			"`n`nNote: JPG (& JSON) files saved to this folder have longer, UNIQUE filenames that include reference to the source DAT file." + 
			"`n`nTip: To retain a copy of the current 'SingleFolder' and prevent its contents from being overwritten, simply rename it to make it unique." + 
			"`n`nNote: This folder and this README.txt file are programmatically created."
		$msg | Out-File -FilePath "$readme_path" -Append
	}

	# 4. Create the DAT Archive folder, if necessary
	$archive_path = "$app_path\_archived_dat_files"
	if (!(Test-Path -LiteralPath "$archive_path")) {
		New-Item -ItemType Directory -Force -Path $archive_path | Out-Null
	}
	# ... and add/refresh a README to the folder
	$readme_path = "$archive_path\_README.txt"
	if (!(Test-Path -LiteralPath "$readme_path")) {
		New-Item -Path "$readme_path" | Out-Null
		$msg = "Blue Iris DAT files Archive" +
			"`n---------------------------" +
			"`n`nWHAT? This folder holds archived copies of Blue Iris DAT files." + 
			"`n`nWHY? These archived DAT files can be used to restore the files to the Blue Iris Alerts folder in the event that they become 'lost' due to Blue Iris database glitches, or user error." +
			"`nFor example, if you observe the loss of alerts in alerts list." + 
			"`n`nNote: This folder and this README.txt file are programmatically created."
		$msg | Out-File -FilePath "$readme_path" -Append
	}

	# 5. Create the Background Recycle folder if necessary
	$archive_path = "$app_path\_background_recycle_bin"
	if (!(Test-Path -LiteralPath "$archive_path")) {
		New-Item -ItemType Directory -Force -Path $archive_path | Out-Null
	}
	# ... and add/refresh a README to the folder
	$readme_path = "$archive_path\_README.txt"
	if (!(Test-Path -LiteralPath "$readme_path")) {
		New-Item -Path "$readme_path" | Out-Null
		$msg = "Alternate Recycle Bin folder" +
			"`n----------------------------" +
			"`n`nWHAT? This folder holds DAT files that cannot be moved programmatically to the Windows Recycle Bin" + 
			"`n`nWHY? Powershell is unable to access the Windows Recycle Bin when it runs scripts in the background (e.g., via Task Scheduler)" + 
			"`n`n`Note: This folder and this README.txt file are programmatically created."
		$msg | Out-File -FilePath "$readme_path" -Append
	}
		
	# 6. Create the Blue Iris Database backup folder if necessary
	$backup_path = "$app_path\_backup_db_folders"
	if (!(Test-Path -LiteralPath "$backup_path")) {
		New-Item -ItemType Directory -Force -Path $backup_path | Out-Null
	}
	# ... and add/refresh a README to the folder
	$readme_path = "$backup_path\_README.txt"
	if (!(Test-Path -LiteralPath "$readme_path")) {
		New-Item -Path "$readme_path" | Out-Null
		$msg = "Backups of Blue Iris database folders" +
			"`n-------------------------------------" +
			"`n`nWHAT? This folder holds backup copies of the entire Blue Iris database folder." + 
			"`n`nWHY? These sub-folders can be used to recover the Blue Iris database after using '$ScriptName' w/ the '-Delete' argument." +
			"`nFor example, if you observe the loss of alerts in alerts list." + 
			"`n`nNOTE: To prevent this folder from growing too large, only the 15 most recent backups are retained" + 
			"`n`nNote: This folder and this README.txt file are programmatically created."
		$msg | Out-File -FilePath "$readme_path" -Append
	}
		
	# 7. Create the Script's DevMode folder if necessary
	$devmode_path = "$app_path\_devmode"
	if (!(Test-Path -LiteralPath "$devmode_path")) {
		New-Item -ItemType Directory -Force -Path $devmode_path | Out-Null
	}
	# ... and add/refresh a README to the folder
	if ($DevMode) {
		$readme_path = "$devmode_path\_README.txt"
		if (!(Test-Path -LiteralPath "$readme_path")) {
			New-Item -Path "$readme_path" | Out-Null
			$msg = "Script 'DevMode' Folder" +
				"`n----------------------------" +
				"`n`nWHAT? This folder holds output created when using the -DevMode argument" + 
				"`n`nNote: This folder and this README.txt file are programmatically created."
			$msg | Out-File -FilePath "$readme_path" -Append
		}
	}
}
# ------------------------------------------------------

# Clear return variables (just in case they are not released from previous execution)
$fnames_ary = $null
$imgs_cnt_ary = $null
$dat_al_flags_ary = $null
$dat_ages_ary = $null
$imgs_cnt_ary = $null
$dat_ai_models_ary = $null
$dat_ai_labels_ary = $null
$dat_al_memos_ary = $null

# Build filters
$patterns_filter_ary = @()
if ($Patterns) {
	foreach ($p in $Patterns) {
		$p = ($p.TrimStart("*")).TrimEnd("*")
		$patterns_filter_ary += "*$p*"
	}
}
$flags_filter_ary = @()
if ($FilterFlags) {
	foreach ($f in $FilterFlags) {
		$f = ($f.TrimStart("*")).TrimEnd("*")
		$flags_filter_ary += $f
	}
}

# For debugging
#Write-Host "flags_filter_ary = $flags_filter_ary"
	
# GET ARRAY OF 'DAT' FILES
if ($fromConsole -and !$Quiet) {
	Write-Host "Loading DAT files (this may take awhile)..."
}
if ($Files) {
	$x = $Files[0]

	# From *.txt file
	if ($x.EndsWith('.txt')) {
		if ($x -match ":") {
			[string[]]$dat_filespecs_ary = Get-Content -Path "$x"
		} else {
			[string[]]$dat_filespecs_ary = Get-Content -Path "$app_path\$x"
		}

	# From cmdline arg
	} else {
		$dat_filespecs_ary = $Files
	}
	
	# Add path if missing
	$i = 0
	foreach ($item in $dat_filespecs_ary) {
		if (!($item -match ":\\")) {
			$dat_filespecs_ary[$i] = "$bi_alerts_folder_path\$item"
		}
		$i++
	}
	
} else {
	# From Alerts folder, or -SourcePath arg 
	$dat_filespecs_ary, $dat_files_obj = `
		GetDatFilesRecursive `
		-Path $bi_alerts_folder_path `
		-Patterns $patterns_filter_ary `
		-AgeHours $AgeHours `
}

# Perform 'Natural order' sort (like Window Explorer)
# ... REF: https://gist.github.com/markwragg/e2a9dc05f3464103d6998298fb575d4e
if (!$SortHours) {
	$ToNatural = { [regex]::Replace($_, '\d+', { $args[0].Value.PadLeft(20) }) }
	if ($SortAsc) {
		$dat_filespecs_ary = $dat_filespecs_ary | Sort-Object $ToNatural
	} else {
		$dat_filespecs_ary = $dat_filespecs_ary | Sort-Object $ToNatural -Descending
	}
}

$filespecs_cnt = $dat_filespecs_ary.Count

# For debugging
#Write-Host ("dat_filespecs_ary type = " + $dat_filespecs_ary.GetType())
#Write-Host "dat_filespecs_ary cnt = $filespecs_cnt"
#Write-Host "dat_filespecs_ary = $dat_filespecs_ary"
#Write-Host ("dat_filespecs_ary ORIGINAL ORDER = " + ($dat_filespecs_ary | ConvertTo-Json))
#Write-Host "dat_files_obj = $dat_files_obj"
#Write-Host ("dat_filespecs_ary AFTER NATURAL SORT (SortAsc=" + $SortAsc + ") = " + ($dat_filespecs_ary | ConvertTo-Json))

# Feedback negative result
if ($filespecs_cnt -eq 0) {
	if ($fromConsole) {
		$err_msg = "No DAT files found"
		return $err_msg
	}
}

# PROVIDE FEEDBACK W/ FILTER SELECTIONS REQUESTED
if ($fromConsole -and !$Quiet) {
	if (!$Delete) {
		$verb = "Found"
	} else {
		$verb = "Deleting"
	}
	$addon_str = ""
	if ($Patterns) {
		$addon_str += " matching pattern(s) '$Patterns'"
	}
	if ($AgeHours) {
		if ($Patterns) {
			if ($AgeHours.Count -eq 1) {
				$addon_str += " AND age >=$AgeHours hrs"
			} else {
				$addon_str += (" AND ages " + ($AgeHours -Join "-") + " hrs")
			}
		} else {
			if ($AgeHours.Count -eq 1) {
				$addon_str += " matching Age >=$AgeHours hrs"
			} else {
				$addon_str += (" matching ages " + ($AgeHours -Join "-") + " hrs")
			}
		}
	}
	if ($if_ai_type_arg_used_flg) {
		if ($addon_str.length -gt 0) {
			$addon_str += " AND matching -IfAi* arg"
		} else {
			$addon_str += " matching -IfAi* arg"
		}
	}
	
	if ($MinImages -gt 0 -or $MaxImages -le 999) {
		if ($MinImages -gt 0 -and $MaxImages -eq 999) {
			if ($addon_str.length -gt 0) {
				$addon_str += " AND containing at least $MinImages images"
			} else {
				$addon_str += " containing at least $MinImages images"
			}
		} elseif ($MinImages -eq 0 -and ($MaxImages -gt 0 -and $MaxImages -lt 999)) {
			if ($addon_str.length -gt 0) {
				$addon_str += " AND containing no more than $MaxImages images"
			} else {
				$addon_str += " containing no more than $MaxImages images"
			}
		} elseif ($MinImages -gt 0 -and ($MaxImages -gt 0 -and $MaxImages -lt 999)) {
			if ($addon_str.length -gt 0) {
				$addon_str += " AND containing $MinImages-$MaxImages images"
			} else {
				$addon_str += " containing $MinImages-$MaxImages images"
			}
		}
	}

	# Final output string
	# ... If no filter arguments... like, "Found 2352 DAT files"
	Write-Host "$verb $filespecs_cnt DAT files$addon_str"  
}

# INITIALIZE OUTPUT LISTS
# ... Note: All other output lists are returned by function ProcessDatFiles()
[string[]]$jpg_exif_memos_ary = @()
[string[]]$jpg_exif_memos_match_ary = @()

# CREATE LOOKUP OBJECTS, e.g., @{datfile: memo}
$al_list_paths_obj = @{}      # Initialize hashtable
$al_list_memos_obj = @{}      # Initialize hashtable
$al_list_flags_dec_obj = @{}  # Initialize hashtable (decimal values)
$al_list_flags_bin_obj = @{}  # Initialize hashtable (binary arrays)
$al_list_attribs_obj = @{}    # Initialize hashtable

# Start resize performance timer
$timer_get_cams = [Diagnostics.Stopwatch]::StartNew()

# Initialize collector
$dat_cams_ary = @()

$progress_bar_cntr = 0
$i = 0
foreach ($f in $dat_filespecs_ary) {
	try {
		$fname = (Get-Item -LiteralPath "$f").Name
		$arr = $fname.Split('.')
		$cam = $arr[0]
		#if (!$dat_cams_ary.Contains($cam)) {
		if ($dat_cams_ary -notcontains $cam) {
			$dat_cams_ary += $cam
		}
	}
	catch {
		# Skip this filespec because Blue Iris might have deleted the alert 
		# in the period since we've collected it via GetDatFilesRecursive()
	}
	# Show progress bar if too many DAT files
	if ($filespecs_cnt -gt 5000) {
		if ($i % 100 -eq 0) {
			if ($fromConsole) {
				$progress_bar_cntr++
				$WriteProgressParams = @{
					Activity         = "Parsing DAT filespecs..."
					Status           = "Progress:  $progress_bar_cntr of $cams_cnt cams in database"
					PercentComplete  = (($progress_bar_cntr / $filespecs_cnt) * 100)
				}
				# Note: If loop is too fast, you might need a delay to get the progress bar to update
				#Start-Sleep -Milliseconds 150				
				Write-Progress @WriteProgressParams
			}
		}
	}
	$i++
}
$cams_arg = $dat_cams_ary -Join ","

# Stop performance timer
$timer_get_cams.stop()
$getdatcams_msec = [math]::Round(($timer_get_cams.elapsed.totalmilliseconds),1).ToString("0.00")

# GET BLUE IRIS DB ALERTLIST
# Returns hashtable, like @{ Cam1: @{ prop1:[values], ... , propN:[values] }, ... }
$my_al_props = @('path','file','flags','memo')  # We only need this subset of JSON alertlist params
#$my_al_props = @()  # should cause BIJsonGetAlertList() to return ALL JSON alertlist params
$response_obj = `
	BIJsonGetAlertList `
	-Cameras $cams_arg `
	-AlertProps $my_al_props `
	-AlMemoTags $AlMemoTags `
	-QuietFlg $Quiet `
	-FromConsoleFlg $fromConsole `
	-DevModeFlg $DevMode `
	-DevModePath $devmode_path
			
if ($response_obj.GetType() -match 'string') {
	if ($response_obj.StartsWith('ERR/')) {
		$err_msg = $response_obj	
		if ($fromConsole) {
			Write-Host $err_msg -ForegroundColor Red
			exit
		} else {
			return $err_msg
		}
	} else {
		$err_msg = "ERR/unexpected response from BIJsonGetAlertList()"
		if ($fromConsole) {
			Write-Host $err_msg -ForegroundColor Red
			exit
		} else {
			return $err_msg
		}
	}
}

$alertlist_hashtable = $response_obj
$alertlist_hashtable_cams = $alertlist_hashtable.Keys
		
# For debugging
#Write-Host ("hashtable keys = " + $alertlist_hashtable_cams)
#Write-Host ("hashtable = " + ($alertlist_hashtable | ConvertTo-Json))

foreach ($al_cam in $alertlist_hashtable_cams) {
	
	$al_list_paths_ary = $alertlist_hashtable.$al_cam.path
	$al_list_files_ary = $alertlist_hashtable.$al_cam.file
	$al_list_flags_ary = $alertlist_hashtable.$al_cam.flags
	$al_list_memos_ary = $alertlist_hashtable.$al_cam.memo
	
	# For debugging
	#Write-Host ("all_al_paths_ary type = " + $al_list_paths_ary.GetType())
	#Write-Host ("all_al_paths_ary cnt = " + $al_list_paths_ary.Count)
	#Write-Host ("all_al_paths_ary = " + ($al_list_paths_ary | ConvertTo-Json))
	#Write-Host ("all_al_files_ary = " + ($al_list_files_ary | ConvertTo-Json))
	#Write-Host ("all_al_flags_ary = " + ($al_list_flags_ary | ConvertTo-Json))
	#Write-Host ("all_al_memos_ary = " + ($al_list_memos_ary | ConvertTo-Json))
	
	if ($al_list_paths_ary.Count -ne $al_list_memos_ary.Count) {
		$err_mag = "ERR/problem importing JSON alertlist"
		return $err_msg
	}
	
	# Make Alert property lookup objects (paths, flags, memos)
	$i = 0
	foreach($item in $al_list_files_ary) {

		$dat_fname = $item.Replace(".jpg",".dat")

		# Alert db paths 
		$path_val = $al_list_paths_ary[$i]
		if (!$al_list_paths_obj[$dat_fname]) {
			$al_list_paths_obj.Add($dat_fname, $path_val)
		}

		# Alert db flags 
		$flags_ary = `
			MakeBitArray `
			-DecVal $al_list_flags_ary[$i] `
			-NoBits 32

		# For debugging
		#Write-Host ("flags_ary = " + ($flags_ary -Join "") + " (" + $al_list_flags_ary[$i] + ") " + $item)

		if (!$al_list_flags_bin_obj[$dat_fname]) {
			$al_list_flags_dec_obj.Add($dat_fname, $al_list_flags_ary[$i])
			$al_list_flags_bin_obj.Add($dat_fname, $flags_ary)
		}

		# Alert db memos
		$memo_val = $al_list_memos_ary[$i]
		if (!$al_list_memos_obj[$dat_fname]) {
			$al_list_memos_obj.Add($dat_fname, $memo_val)
		}

		# Alert JPG and DAT file read-only attributes
		$tmp_ary = @()
		$dat_filespec = $bi_alerts_folder_path + "\" + $dat_fname
		if (Test-Path -LiteralPath "$dat_filespec") {
			$obj = Get-ItemProperty -LiteralPath "$dat_filespec" | Select-Object IsReadOnly
			if ($obj.IsReadOnly) {
				$tmp_ary += 'D'	# DAT file is read-only (may be protected by Blue Iris)
			} else {
				$tmp_ary += '-'	
			}
		} else {
			$tmp_ary += "x"
		}
		$jpg_filespec = $bi_alerts_folder_path + "\" + $item
		if (Test-Path -LiteralPath "$jpg_filespec") {
			$obj = Get-ItemProperty -LiteralPath "$jpg_filespec" | Select-Object IsReadOnly
			if ($obj.IsReadOnly) {
				$tmp_ary += 'J'	# JPG file is read-only (may be protected by Blue Iris)
			} else {
				$tmp_ary += '-'	
			}
		} else {
			$tmp_ary += "x"
		}
		$attrib_str = $tmp_ary -Join ''
		
		if (!$al_list_attribs_obj[$dat_fname]) {
			$al_list_attribs_obj.Add($dat_fname, $attrib_str)
		}

		$i++
	}
}
	
# For debugging
#Write-Host ("all_al_memos_obj type = " + $al_list_memos_obj.GetType())
#Write-Host ("all_al_memos_obj cnt = " + $al_list_memos_obj.Count)
#Write-Host ("all_al_memos_obj = " + ($al_list_memos_obj | ConvertTo-Json))
#Write-Host ("al_list_flags_dec_obj type = " + $al_list_flags_dec_obj.GetType())
#Write-Host ("al_list_flags_dec_obj cnt = " + $al_list_flags_dec_obj.Count)
#Write-Host ("al_list_flags_dec_obj = " + ($al_list_flags_dec_obj | ConvertTo-Json))
#Write-Host ("al_list_flags_bin_obj type = " + $al_list_flags_bin_obj.GetType())
#Write-Host ("al_list_flags_bin_obj cnt = " + $al_list_flags_bin_obj.Count)
#Write-Host ("al_list_flags_bin_obj = " + ($al_list_flags_bin_obj | ConvertTo-Json))
#Write-Host ("all_al_attribs_obj cnt = " + $al_list_attribs_obj.Count)
#Write-Host ("all_al_attribs_obj = " + ($al_list_attribs_obj | ConvertTo-Json))

# FILTER FOR ALERT MEMOS
$found_alert_memo_flg = $false
if ($AlMemoTags) {
	$new_dat_filespecs_ary = @()  # Initialize accumulator
	foreach($dat_file in $dat_filespecs_ary) {

		if (Test-Path -LiteralPath "$dat_file") {
			
			# Get Alert's memo

			# NOTE: Considerations with returned object when using CmdLet 'Get-ChildItem'
			# REF: https://stackoverflow.com/questions/55765010/return-array-of-objects-from-get-childitem-path
			$fname = (Get-Item -LiteralPath "$dat_file").Name
	
			$db_al_path       = $al_list_paths_obj[$fname]
			$db_al_memo       = $al_list_memos_obj[$fname]
			$db_al_flags_orig = $al_list_flags_dec_obj[$fname]
			$db_al_flags      = $al_list_flags_bin_obj[$fname]
			$ro_attribs       = $al_list_attribs_obj[$fname]
			
			# For debugging.
			#Write-Host ("fname type = " + $fname.GetType())
			#Write-Host "fname = $fname"
			#Write-Host ("all_al_memos_obj[$fname] = " + $db_al_memo)
			
			if ($db_al_memo) {

				# Handle args -AlMemoTags and -ChgAlMemoTags
				
				$chg_flg = $false
				$tag_idx = 0
				foreach ($cur_tag in $AlMemoTags) {

					$doit_flg = $false
					
					if ($cur_tag.length -eq 1) {
						# Added this single character testing because -match gave following error when trying to replace '+' character
						# ... "Invalid pattern '+' at offset 1. Quantifier '+' following nothing."
						$tmp_ary = $db_al_memo -Split ''
						if ($tmp_ary -contains $cur_tag) {
							$doit_flg = $true
						}
					} else {
						if ($db_al_memo -match $cur_tag) {
							$doit_flg = $true
						}
					}
					
					if ($doit_flg) {

						# Add DAT file to collector - but just once!
						if (!($new_dat_filespecs_ary -contains $dat_file)) { 
							$new_dat_filespecs_ary += $dat_file
						}
						
						# Change dat file's alert memo - if requested
						if ($ChgAlMemoTags.Count -gt 0) {
							$new_tag = $ChgAlMemoTags[$tag_idx]
							if ($new_tag -ne $cur_tag) {
								$chg_flg = $true
								$db_al_memo = $db_al_memo.Replace($cur_tag, $new_tag)
							}
						}
					}
					$tag_idx++
				}

				# Update the alert memo in the Blue Iris database
				if ($chg_flg) {
					# KEY POINT: Alert's flags will be removed if param 'flags' is not included in the JSON 'update' command
					$jsonCmd = @{
						cmd = 'update'
						path = $db_al_path
						memo = $db_al_memo
						flags = $db_al_flags_orig
					}			
					
					# Returns a powershell PSCustomObject
					$json_response_obj = `
						BIJsonCall `
						-JsonCmd $jsonCmd `
						-QuietFlg $Quiet `
						-FromConsoleFlg $FromConsole

					# For debugging
					#Write-Host ("jsonCmd = " + ($jsonCmd | ConvertTo-Json))
					#Write-Host ("json_response_obj = " + ($json_response_obj | ConvertTo-Json))

					if (!($json_response_obj -match 'success')) {
						Write-Host "ERR/unable to remove tag from Alert memo"
					} else {
						$al_list_memos_obj[$fname] = $db_al_memo
					}
				}
			}
		}
	}
	$new_dat_filespecs_ary_cnt = $new_dat_filespecs_ary.Count
	if ($new_dat_filespecs_ary_cnt -gt 0) {
		$found_alert_memo_flg = $true
		$dat_filespecs_ary = $new_dat_filespecs_ary
		if ($fromConsole -and !$Quiet) {
			#if ($new_dat_filespecs_ary_cnt -lt $filespecs_cnt) {
				Write-Host "`nFiltered to $new_dat_filespecs_ary_cnt DAT files matching AlMemoTag(s) '$AlMemoTags'"
			#}
		}
	} else {
		$found_alert_memo_flg = $false
		$dat_filespecs_ary = @()
	}
}
													
# ARCHIVE THE DAT FILES, IF REQUESTED
if ($Archive) {	
	$archive_path = "$app_path\_archived_dat_files"
	$copied_cnt = 0
	foreach ($df in $dat_filespecs_ary) {
		$fname = (Get-Item -LiteralPath "$df").Name
		if (!(Test-Path -LiteralPath "$archive_path\$fname")) {
			Copy-Item -LiteralPath "$df" -Destination $("$archive_path\$fname")
			$copied_cnt++
		}
	}
	
	if ($copied_cnt -gt 0) {
		Write-Host "Archived $copied_cnt new DAT files to '$archive_path'"
	} else {
		Write-Host "DAT files not archived; already exist in '$archive_path'"
	}
	$total_cnt = (Get-ChildItem -Path "$archive_path\*.dat" | Measure-Object).Count
	Write-Host "(archive now contains $total_cnt DAT files)"
	
}								

# PROCESS EACH 'DAT' FILE 
# ... ProcessDATFiles() returns an (array of arrays) 
#     @($fnames_ary, $dat_ages_ary, $imgs_cnt_ary, $imgs_saved_ary, 
#       $dat_ai_models_ary, $dat_ai_labels_ary, $dat_al_memos_ary, $loadats_sec)
$fnames_ary, $dat_al_flags_ary, $dat_al_attribs_ary, $dat_ages_ary, $imgs_cnt_ary, $imgs_saved_ary, $dat_confirmed_img_nos_ary, $dat_confirmed_img_memos_ary, $dat_ai_models_ary, $dat_ai_labels_ary, $dat_al_memos_ary, $loadats_sec, $dat_img_labels_used_ary, $invalid_jpgs_cnt = `
	ProcessDATFiles `
	-Filespecs $dat_filespecs_ary `
	-NoInspectFlg $NoInspect `
	-MinImages $MinImages `
	-MaxImages $MaxImages `
	-FlagsFilter $flags_filter_ary `
	-AlFlagsLookupObj $al_list_flags_bin_obj `
	-AlReadOnlyLookupObj $al_list_attribs_obj `
	-AlMemoLookupObj $al_list_memos_obj `
	-FoundAlertMemoFlg $found_alert_memo_flg `
	-IfAiModel $IfAiModel `
	-IfAiLabels $IfAiLabels `
	-IfAiNothingAnyFlg $IfAiNothingAny `
	-IfAiNothingAllFlg $IfAiNothingAll `
	-IfAiSomethingAnyFlg $IfAiSomethingAny `
	-IfAiSomethingAllFlg $IfAiSomethingAll `
	-SaveJPGsFlg $save_jpgs_flg `
	-Destination $app_path `
	-SingleFolder $SingleFolder `
	-SaveJsonFlg $SaveJSON `
	-DeleteFlg $Delete `
	-NoRecycleFlg $NoRecycle `
	-ForceFlg $Force `
	-FromConsoleFlg $fromConsole `
	-QuietFlg $Quiet `
	-DevModeFlg $DevMode
	
# For debugging
#Write-Host ("fnames_ary type = " + $fnames_ary.GetType())
#Write-Host ("fnames_ary cnt = " + $fnames_ary.Count)
#Write-Host "fnames_ary = $fnames_ary"
#Write-Host ("dat_al_flags_ary type = " + $dat_al_flags_ary.GetType())
#Write-Host ("dat_al_flags_ary cnt = " + $dat_al_flags_ary.Count)
#Write-Host "dat_al_flags_ary = $dat_al_flags_ary"
#Write-Host ("dat_al_attribs_ary type = " + $dat_al_attribs_ary.GetType())
#Write-Host ("dat_al_attribs_ary cnt = " + $dat_al_attribs_ary.Count)
#Write-Host "dat_al_attribs_ary = $dat_al_attribs_ary"
#Write-Host ("dat_ages_ary type = " + $dat_ages_ary.GetType())
#Write-Host ("dat_ages_ary cnt = " + $dat_ages_ary.Count)
#Write-Host "dat_ages_ary = $dat_ages_ary"
#Write-Host ("imgs_cnt_ary type = " + $imgs_cnt_ary.GetType())
#Write-Host ("imgs_cnt_ary cnt = " + $imgs_cnt_ary.Count)
#Write-Host "imgs_cnt_ary = $imgs_cnt_ary"
#Write-Host ("imgs_saved_ary cnt = " + $imgs_saved_ary.Count)
#Write-Host "imgs_saved_ary = $imgs_saved_ary"
#Write-Host ("dat_confirmed_img_nos_ary cnt = " + $dat_confirmed_img_nos_ary.Count)
#Write-Host "dat_confirmed_img_nos_ary = $dat_confirmed_img_nos_ary"
#Write-Host ("dat_ai_models_ary cnt = " + $dat_ai_models_ary.Count)
#Write-Host "dat_ai_models_ary = $dat_ai_models_ary"
#Write-Host ("dat_ai_labels_ary cnt = " + $dat_ai_labels_ary.Count)
#Write-Host "dat_ai_labels_ary = $dat_ai_labels_ary"
#Write-Host ("dat_al_memos_ary cnt = " + $dat_al_memos_ary.Count)
#Write-Host "dat_al_memos_ary = $dat_al_memos_ary"
#Write-Host "dat_img_labels_used_ary = $dat_img_labels_used_ary"

# Toggle off the ProcessDATFiles() progress bar.
# REF: https://stackoverflow.com/a/6651374
# BTW: Get-Variable *preference will list all the preference variables
#$ProgressPreference = "SilentlyContinue"
$ProgressPreference = "Continue"

# Make count of found DAT files
$fnames_ary_cnt = $fnames_ary.Count

# Get count of DAT files with "ERR/" in imgs_cnt_ary
$err_cnt = ([regex]::Matches($imgs_cnt_ary, "ERR" )).count

# Get total counts of images found & saved
$tmp_ary = @()
foreach($item in $imgs_cnt_ary) {
	if ($item -lt 0) {
		$tmp_ary += 0
	} else {
		$tmp_ary += $item
	}
}
$total_jpgs_found = ($tmp_ary | Measure-Object -Sum).Sum
$total_jpgs_saved = ($imgs_saved_ary | Measure-Object -Sum).Sum

# For debugging
#Write-Host "err_cnt = $err_cnt"
#Write-Host "total_jpgs_saved = $total_jpgs_saved"
#Write-Host "invalid_jpgs_cnt = $invalid_jpgs_cnt"

# Provide image counts feedback when using filters
if ($fromConsole) {
	if ($MinImages -ge 0 -or $MaxImages -le 999) {
		if ($MinImages -gt 0 -and $MaxImages -eq 999) {
			Write-Host ("Found " + ($fnames_ary_cnt - $err_cnt) + " DAT file(s) with at least " + $MinImages + " image(s)")
		}
		if ($MinImages -eq 0 -and ($MaxImages -gt 0 -and $MaxImages -lt 999)) {
			Write-Host ("Found " + ($fnames_ary_cnt - $err_cnt) + " DAT file(s) with no more than " + $MaxImages + " image(s)")
		}
		if ($MinImages -gt 0 -and ($MaxImages -gt 0 -and $MaxImages -lt 999)) {
			Write-Host ("Found " + ($fnames_ary_cnt - $err_cnt) + " DAT file(s) with " + $MaxImages + " to " + $MaxImages + " image(s)")
		}
	}
}

# INSPECT JPG EXIF METADATA
if (!$NoInspect) {
	if ($fnames_ary_cnt -gt 0) {
		if ($fromConsole -and !$Quiet) {
			Write-Host "`nInspecting Exif metadata in associated Alert JPG files..."
		}

		$progress_bar_cntr = 0
		$mismatch_cntr = 0
		$i = 0
		foreach($item in $fnames_ary) {
		
			# Show progress bar
			if ($FromConsoleFlg) {
				$progress_bar_cntr++
				$WriteProgressParams = @{
					Activity         = "Inspecting JPG Exif metadata..."
					Status           = "Progress:  $progress_bar_cntr of $fnames_ary_cnt JPG files"
					PercentComplete  = (($progress_bar_cntr / $fnames_ary_cnt) * 100)
				}
				# Note: If loop is too fast, you might need a delay to get the progress bar to update
				#Start-Sleep -Milliseconds 150				
				Write-Progress @WriteProgressParams
			}

			$jpg_filespec = $bi_alerts_folder_path + "\" + $item.Replace('.dat', '.jpg')
			
			if (Test-Path -LiteralPath "$jpg_filespec") {

				# Get Exif metadata as shown by Windows Explorer
				# ... SOURCE: https://evotec.xyz/getting-file-metadata-with-powershell-similar-to-what-windows-explorer-provides/
				$exif_obj = Get-ChildItem -Path $jpg_filespec -Force | Get-FileMetaData

				$exif_title = $exif_obj.Title		
				$exif_subject = $exif_obj.Subject		
				#$exif_comments = $exif_obj.Comments	
				#$exif_attributes = $exif_obj.Attributes	

				# Extract AI labels
				$exif_title = `
					ExtractAiLabels `
					-InputStr $exif_title

				$exif_subject = `
					ExtractAiLabels `
					-InputStr $exif_subject
				
				# For debugging
				#Write-Host "$item - Exif Title = $exif_title"
				#Write-Host "$item - Exif Subject = $exif_subject"
				#Write-Host "$item - Exif Comments = $exif_comments"
				#Write-Host "$item - Exif Attributes = $exif_attributes"
				
				if ($exif_title.length -eq 0) {
					$exif_title = "<blank>"
				}
				if ($exif_subject.length -eq 0) {
					$exif_subject = "<blank>"
				}
				if ($exif_title -eq $exif_subject) {
					$jpg_exif_memos_ary += $exif_title
				} else {
					$jpg_exif_memos_ary += $exif_title + "," + $exif_subject
				}
				
				if ($dat_al_memos_ary[$i].Trim() -eq $exif_title.Trim()) {
					$jpg_exif_memos_match_ary += "match!"
				} else {
					$mismatch_cntr++
					$jpg_exif_memos_match_ary += $jpg_exif_memos_ary[$i]
				}
			} else {
				$jpg_exif_memos_ary += "<no jpg file>"
			}
			
			$i++
		}
		if ($mismatch_cntr -gt 0) {
			if ($fromConsole -and !$Quiet) {
				Write-Host "Found $mismatch_cntr Alert JPG files with unexpected metadata (not matching database alert memo)"
			}
		}
	}
}

# CHANGE ALERT'S JPG FILE'S METADATA TO MATCH ALERT'S DATABASE MEMO
if ($fnames_ary_cnt -gt 0) {
	if ($FixJpgMetadata) {
		if ($fromConsole -and !$Quiet) {
			Write-Host "`nEditing Alert JPG file's metadata to match the database memo..."
		}
		
		$i = 0
		foreach ($item in $fnames_ary) {

			if ($jpg_exif_memos_match_ary[$i] -ne 'match!') {
				
				# PROCEED ONLY IF A JPG FILE EXISTS			
				$jpg_filename = $item.Replace('.dat', '.jpg')
				$jpg_filespec = $bi_alerts_folder_path + "\" + $jpg_filename						
				if (Test-Path -LiteralPath "$jpg_filespec") {

					$db_al_path = $al_list_paths_obj[$item]
					$db_al_memo = $al_list_memos_obj[$item]
					$db_al_flags_orig = $al_list_flags_dec_obj[$item]
					
					# KEY POINTS: 
					# 1. The JPG's metadata will NOT be changed if the Alert's memo is not actually changed
					# 2. Alert's flags will be removed if param 'flags' is not included in the JSON 'update' command

					# TEMPORARILY RESET THE ALERT MEMO
					
					$jsonCmd = @{
						cmd = 'update'
						path = $db_al_path
						memo = '_temp_'
						flags = $db_al_flags_orig
					}			
					
					# Returns a powershell PSCustomObject
					$json_response_obj = `
						BIJsonCall `
						-JsonCmd $jsonCmd `
						-QuietFlg $Quiet `
						-FromConsoleFlg $FromConsole

					# For debugging
					#Write-Host ("jsonCmd = " + ($jsonCmd | ConvertTo-Json))
					#Write-Host ("json_response_obj = " + ($json_response_obj | ConvertTo-Json))

					# RESTORE THE ALERT'S MEMO 

					if ($json_response_obj -match 'success') {

						# Note: This action updates the JPG file's metadata
						# We will verify this change next

						$jsonCmd = @{
							cmd = 'update'
							path = $db_al_path
							memo = $db_al_memo
							flags = $db_al_flags_orig
						}			
						
						# Returns a powershell PSCustomObject
						$json_response_obj = `
							BIJsonCall `
							-JsonCmd $jsonCmd `
							-QuietFlg $Quiet `
							-FromConsoleFlg $FromConsole

						# For debugging
						#Write-Host ("jsonCmd = " + ($jsonCmd | ConvertTo-Json))
						#Write-Host ("json_response_obj = " + ($json_response_obj | ConvertTo-Json))

						if ($json_response_obj -match 'success') {
							
							# VERIFY CHANGE TO JPG'S METADATA 
							
							$exif_obj = Get-ChildItem -Path $jpg_filespec -Force | Get-FileMetaData
							$exif_title = $exif_obj.Title
							if ($exif_title -eq $db_al_memo) {
								if ($fromConsole -and !$Quiet) {
									Write-Host "$item - Alert's JPG metadata changed to '$db_al_memo'"
								}
								$jpg_exif_memos_ary[$i] = $db_al_memo
								$jpg_exif_memos_match_ary[$i] = "match!"
							} else {
								Write-Warning "Unable to verify metadata change to Alert JPG file ($jpg_filename)"
							}
						} else {
							Write-Warning "Unsuccessful attempt to update the Alert memo"
						}
					} else {
						Write-Warning "Unsuccessful attempt to update the Alert memo"
					}
				} else {
					# Nothing to do
					#Write-Warning "Unable to find $jpg_filename"
				}
			}
			$i++
		}
	}
}

# CHANGE FILE ATTRIBUTES TO READ-ONLY
if ($fnames_ary_cnt -gt 0) {
	if ($ReadOnly) {
		if ($fromConsole -and !$Quiet) {
			Write-Host "`nSetting read-only file attributes for both DAT and JPG files"
		}
		
		$i = 0
		foreach ($datfile in $fnames_ary) {

			$cur_attribs_str = $dat_al_attribs_ary[$i]  # like '--', 'D-', '-J', 'DJ', or 'Dx'
			$cur_attribs_ary = $cur_attribs_str -Split ''
			$tmp_ary = @()
			
			# Test DAT file
			if ($cur_attribs_ary[0] -ne 'D') {
				$filespec = "$bi_alerts_folder_path\$datfile"
				if (Test-Path -LiteralPath "$filespec") {
					Set-ItemProperty -LiteralPath "$filespec" -Name IsReadOnly -Value $true
					# Verify
					$obj = Get-ItemProperty -LiteralPath "$filespec" | Select-Object IsReadOnly
					if ($obj.IsReadOnly) {
						$tmp_ary += 'D'
					}
				} else {
					Write-Warning "Could not find file to set read-only attribute: '$filespec'"
				}
			}
			
			# Test JPG file
			if ($cur_attribs_ary[1] -ne 'J') {
				$filespec = "$bi_alerts_folder_path\$datfile".Replace(".dat", ".jpg")
				if (Test-Path -LiteralPath "$filespec") {
					Set-ItemProperty -LiteralPath "$filespec" -Name IsReadOnly -Value $true
					# Verify
					$obj = Get-ItemProperty -LiteralPath "$filespec" | Select-Object IsReadOnly
					if ($obj.IsReadOnly) {
						$tmp_ary += 'J'
					}
				} else {
					Write-Warning "Could not find file to set read-only attribute: '$filespec'"
				}
			}
			
			if ($tmp_ary.Count -gt 0) {
				$dat_al_attribs_ary[$i] = $tmp_ary -Join ''
			} else {
				# Leave value as-is
			}
			$i++
		}
	}
}

# PERFORM DATABASE REPAIR/REGENERATE
if ($fnames_ary_cnt -gt 0) {
	if ($Delete) {
		if (!$NoRegen) {
		
			# BUT FIRST, BACKUP THE BLUE IRIS DATABASE FOLDER
			$backup_path = "$app_path\_backup_db_folders"
			# ... Remove excessive sub-folders to keep folder size in check (15 sub-folders max)
			#     REF: https://stackoverflow.com/a/69656558
			#Get-ChildItem -Directory $backup_path | Sort-Object CreationTime | Select-Object -SkipLast 14 | Remove-Item -Recurse -WhatIf
			Get-ChildItem -Directory $backup_path | Sort-Object CreationTime | Select-Object -SkipLast 14 | Remove-Item -Recurse
			# ... Copy db folder to dated subfolder in $achive_path
			# Using current system time
			#$date_str = [DateTime]::Now.ToString("yyyyMMdd_HHmmss")
			#Copy-Item -LiteralPath "$bi_db_path" -Destination $("$backup_path\$date_str") -Recurse
			# Using clips.dat file's last write time
			$obj = Get-ChildItem -Path "$bi_db_path\clips.dat" | select LastWriteTime 
			$date_str = ($obj.LastWriteTime).ToString("yyyyMMdd_HHmmss")
			Copy-Item -LiteralPath "$bi_db_path" -Destination $("$backup_path\$date_str") -Recurse
			
			if ($fromConsole) {
				Write-Warning "Regenerating Blue Iris database - required when using the -Delete argument"
			}
			
			# DO IT
			$http_response_obj = `
				BIHttpCall `
				-HttpCmd "/admin?db=rebuild"		

		} else {
			if ($fromConsole) {
				Write-Host ""
				Write-Warning "Automatic Database Repair/Regenerate action disabled via -NoRegen argument; YOU ARE RESPONSIBLE"
			}
		}
	}
}

# OUTPUT FINAL RESULTS

# Create CSV file
$csv_filespec = `
	MakeTable `
	-TempPath "$output_path" `
	-SortColNo $sort_col_no `
	-SortAscFlg $SortAsc `
	-FilesList $fnames_ary `
	-AlertFlagsList $dat_al_flags_ary `
	-AlertAttribsList $dat_al_attribs_ary `
	-FileAgesList $dat_ages_ary `
	-ImagesList $imgs_cnt_ary `
	-DatConfImgNosList $dat_confirmed_img_nos_ary `
	-DatConfImgMemosList $dat_confirmed_img_memos_ary `
	-AiModelsList $dat_ai_models_ary `
	-AiLabelsList $dat_ai_labels_ary `
	-AlMemosList $dat_al_memos_ary `
	-ImgLabelsList $dat_img_labels_used_ary `
	-JpgExifMemos $jpg_exif_memos_match_ary
	
# Display to Console
if ($fromConsole) {
	
	if ($fnames_ary_cnt -gt 0) {
		
		if (!$NoTable) {
			
			if ($if_ai_type_arg_used_flg) {
				Write-Host ("`nIFAi* Filtered " + ($fnames_ary_cnt - $err_cnt) + "/" + $filespecs_cnt + " DAT file(s)")
			} else {
				if (!$NoInspect) {
					Write-Host ("`nProcessed " + ($fnames_ary_cnt - $err_cnt) + " DAT file(s)")
				}
			}
			
			if ($save_jpgs_flg) {
				Write-Host ("`nSaved " + ($total_jpgs_saved - $invalid_jpgs_cnt) + "/" + $total_jpgs_found + " available JPG file(s)")
			}

			# Arbitrary table size that triggers a prompt instead of directly showing the results table
			if ($fnames_ary_cnt -gt 20) {  
				Write-Host ""
				<# if ($ParentProcess -ne "explorer") {
					Write-Host "Note: after 'Y', hit space bar to show subsequent pages, or Ctrl-C to abort"
				} #>
				$show_table = Read-Host -Prompt "Show table (Y/N)?"
			} else {
				$show_table = "Y"
			}
			
			if ($show_table -match "Y") {
				
				$csv_filespec  = "$output_path\output.csv"

				if (!$Quiet) {
					#if (!$auto_open_csv_file) {
						Write-Host "`n(Note: the following table is available as '$csv_filespec')"
					#}
					if ($fnames_ary_cnt -gt 20) {
						if ($ParentProcess -ne "explorer") {
							#if ($Host.UI.RawUI.WindowSize.Height -lt 25) {
								Write-Host "(Note: Hit space bar to show subsequent pages, or Ctrl-C to abort)"
							#}
						}
					}
				}

				if ($SortHours) {
					$sort_col_no = 2
				} else {
					$sort_col_no = 1
				}
				
				# For debugging
				#Write-Host "sort_col_no = $sort_col_no"
				
				# Show table
				if ($ParentProcess -eq "explorer") {

					# RUNNING FROM POWERSHELL-ISE
					ShowTable `
						-Path $csv_filespec `
						-SortColNo $sort_col_no `
						-SortAscFlg $SortAsc `
						
				} else {
					# *NOT* RUNNING FROM POWERSHELL-ISE

					# Alternate pagination method
					<# (ShowTable `
						-Path $csv_filespec `
						-SortColNo $sort_col_no `
						-SortAscFlg $SortAsc ) | Out-Host -Paging #>

					# Paginate the output
					(ShowTable `
						-Path $csv_filespec `
						-SortColNo $sort_col_no `
						-SortAscFlg $SortAsc ) | More
				}
				
				if ($auto_open_csv_file) {
					if ($fnames_ary_cnt -gt $auto_open_csv_file_min_rows) {						
						if ($auto_open_csv_file_in_def_app) {
							Invoke-Expression "$csv_filespec"
						} else {
							# Open Out-GridView cmdlet UI
							Import-Csv -LiteralPath "$csv_filespec" | Out-GridView -Title $csv_filespec -Wait
						}
					}
				}
			} else {
				if (!$Quiet) {
					Write-Host "Results saved to file '$output_path\output.csv'"
				}
			}
		} else {
			Write-Host (($fnames_ary_cnt).ToString() + " DAT files found via the requested filters")
		}
	} else {
		Write-Host "No DAT files found via the requested filters"
	}

	# POST MESSAGE TO BLUE IRIS LOGFILE
	if (!$NoBiLog -and $post_to_BI_logfile_flg) {
		
		# Initialize vars
		$doit_flg = $true
		
		# For testing
		#$fromConsole = $false
		#$post_to_BI_logfile_in_background_only_flg = $false
		#$post_to_BI_logfile_in_background_only_flg = $true

		# Optionally, messages are posted only if this script is running in the background  
		# (e.g., via Task Scheduler, or Blue Iris actions)
		if ($post_to_BI_logfile_in_background_only_flg -and $fromConsole) {
			$doit_flg = $false
		}

		# For debugging
		#Write-Host "doit_flg = $doit_flg"
		
		if ($doit_flg) {
			$str1 = ""
			$str2 = ""
			if ($if_ai_type_arg_used_flg) {
				$str1 = " [Filtered " + ($fnames_ary_cnt - $err_cnt) + "/" + $filespecs_cnt + " DAT files]"
			} else {
				$str1 = " [Processed " + ($fnames_ary_cnt - $err_cnt) + " DAT files]"
			}
			<# if ($Delete) {
				$str2 = " [Deleted]"
			} else {
				$str2 = ""
			} #>
			$log_level = 0
			$log_msg = "$ScriptBaseName [$params_str]$str1$str2 [Runtime=$loadats_sec sec]"
			# Remove/replace incompatible substrings
			$msg_str = $log_msg -Replace "`n", "%20" -Replace "\\r",  "%20" -Replace "\\n", "%20" -Replace " ", "%20"
			if ($use_bi_creds) {
				$uri = "http://$bi_webserver/admin?log=$msg_str&level=$Level&user=$bi_user_name&pw=$bi_user_pw"
			} else {
				$uri = "http://$bi_webserver/admin?log=$msg_str&level=$Level"
			}
			$web_response_obj = Invoke-WebRequest -Uri $uri
			
			# For debugging
			#Write-Host "log_msg = $log_msg"
			#Write-Host "msg_str = $msg_str"
			#Write-Host "uri = $uri"
			#Write-Host "web_response: $web_response_obj"	
				
			if ($web_response_obj -match 'signal=' -and $web_response_obj -match 'schedule=' -and $web_response_obj -match 'profile=') {
				# Normal response
				if ($fromConsole -and !$Quiet) {
					Write-Host "`nMessage posted to Blue Iris logfile: '$log_msg'"
				}
			} else {
				# Unexpected response
				if ($fromConsole) {
					Write-Warning "Failed to post message to Blue Iris logfile; $web_response_obj"
				} else {
					msg.exe $server_username /TIME:5 "From script... $ScriptName`n-----`nFailed to post message to Blue Iris logfile"					
				}
			}
		} else {
			if ($fromConsole -and !$Quiet) {
				#Write-Host "No message posted to the Blue Iris logfile (not running in background)"
			}
		}
	} else {
		if ($fromConsole -and !$Quiet) {
			#Write-Host "No message posted to the Blue Iris logfile"
		}
	}

	# SHOW BACKGROUND MODE RESPONSE
	if ($ShowCLI) {
		Write-Host "~~~~~`nOutput as returned from background..."
		@($fnames_ary, $dat_al_flags_ary, $dat_ages_ary, $imgs_cnt_ary, $dat_ai_models_ary, $dat_ai_labels_ary, $dat_al_memos_ary) | ConvertTo-Json
	} 
		
} else {
	return $fnames_ary, $dat_al_flags_ary, $dat_ages_ary, $imgs_cnt_ary, $dat_ai_models_ary, $dat_ai_labels_ary, $dat_al_memos_ary
}

